//******************************************************************************
//** SCATMECH: Polarized Light Scattering C++ Class Library
//**
//** File: focussedbeam.cpp
//**
//** Thomas A. Germer
//** Sensor Science Division, National Institute of Standards and Technology
//** 100 Bureau Dr. Stop 8443; Gaithersburg, MD 20899-8443
//** Phone: (301) 975-2876
//** Email: thomas.germer@nist.gov
//**
//******************************************************************************
#include "scatmech.h"
#include "focussedbeam.h"
#include "askuser.h"
#include <cstdlib>

namespace SCATMECH {

    // Parameters for area integration over a circle obtained from
    // Section 25.4.61 (Multidimensional Integration) of _Handbook_
    // of_Mathematical_Functions_, by M. Abramowitz and I.A. Stegun,
    // (Dover, New York, 1965).  The data shown here is obtained by
    // extending the tables given in Abramowitz and Stegun, using
    // the Zernike polynomials as the basis for Gaussian integration.

    void Circle_Integral::check(int i) const
    {
        if (i<0 ||i>n()) throw SCATMECH_exception("i out of range in Circle_Integral");
    }

    void Circle_Integral::set_order(int _order)
    {
        order = _order;
        if (order>maxorder) throw SCATMECH_exception("order > " + to_string(maxorder) + " in Circle_Integral");
        else if (order<1) throw SCATMECH_exception("order < 1 in Circle_Integral");
        else if (order==1) offset = 0;
        else if (order==2) offset = 3;
        else if (order%2==0) offset = order*(8-9*order+4*order*order)/4;
        else offset = (-9+14*order-9*order*order+4*order*order*order)/4;

        if (order%2==0) nn = order*order;
        else nn = order*order-order+1;
    }

    double Circle_Integral::r(int i) const
    {
        check(i);
        return table[offset+3*i];
    }

    double Circle_Integral::w(int i) const
    {
        check(i);
        return table[offset+3*i+2];
    }

    double Circle_Integral::theta(int i) const
    {
        check(i);
        return table[offset+3*i+1];
    }

    int Circle_Integral::n() const
    {
        return nn;
    }

    //
    // Constructor...
    //
    Focussed_Beam_Instrument_BRDF_Model::
    Focussed_Beam_Instrument_BRDF_Model()
    {
        model_cs = xyxy;
    }

    MuellerMatrix
    Focussed_Beam_Instrument_BRDF_Model::
    mueller()
    {
        SETUP();

        if (lambda!=model->get_lambda()) error("lambda!=model.lambda");
        if (type!=model->get_type()) error("type!=model.type");
        if (substrate.index(lambda)!=model->get_substrate().index(lambda)) error("substrate!=model.substrate");

        if (alpha==0.) return model->Mueller(thetai,thetas,phis,rotation,BRDF_Model::xyxy);

        MuellerMatrix m=MuellerZero();

        Vector x(1,0,0);
        Vector xx(cos(rotation),-sin(rotation),0);
        Vector yy(-xx.y,xx.x,0);
        Vector z(0,0,1);

        Circle_Integral ci(integralmode);

        for (int i=0; i<ci.n(); ++i) {
            double theta = ci.theta(i);
            double r = ci.r(i);
            double w = ci.w(i);

            double ri = r*alpha*deg;
            double rs = ri*focal_point;

            Vector vi = four_angles(thetai,pi-rotation,ri,theta);
            Vector vs = four_angles(thetas,phis-rotation,rs,theta);

            double thetas_ = acos(vs.z);
            double thetai_ = acos(vi.z);

            double rot = atan2(-vi*yy,-vi*xx);
            MuellerMatrix RotIn = JonesRotator(-rot);
            MuellerMatrix RotOut = JonesRotator(-rot);

            double weight = w*cos(thetai_)*cos(thetas_);

            m += RotOut*model->Mueller(vi,vs,z,x,BRDF_Model::xyxy)*RotIn*weight;
        }
        return (m/cos(thetai)/cos(thetas));
    }

    //
    // The following returns a unit vector, defined by the angles theta, phi, alpha, and beta:
    // Adds planar vector (alpha, beta) on unit sphere to vector (theta,phi).
    //
    Vector
    Focussed_Beam_Instrument_BRDF_Model::
    four_angles(double theta,double phi,double alpha,double beta)
    {
        return Vector(
                   cos(beta)*sin(alpha)*sin(phi) +
                   cos(phi)*(cos(theta)*sin(alpha)*sin(beta) + cos(alpha)*sin(theta)),
                   -(cos(beta)*cos(phi)*sin(alpha)) +
                   sin(phi)*(cos(theta)*sin(alpha)*sin(beta) + cos(alpha)*sin(theta)),
                   cos(alpha)*cos(theta) - sin(alpha)*sin(beta)*sin(theta));
    }

    DEFINE_MODEL(Focussed_Beam_Instrument_BRDF_Model,Instrument_BRDF_Model,
                 "A BRDF model measured with a focussed beam.");

    DEFINE_PTRPARAMETER(Focussed_Beam_Instrument_BRDF_Model,BRDF_Model_Ptr,model,"Model to be integrated","Microroughness_BRDF_Model",0xFF);

    DEFINE_PARAMETER(Focussed_Beam_Instrument_BRDF_Model,double,alpha,"Incident beam half-angle [deg]","0",0xFF);
    DEFINE_PARAMETER(Focussed_Beam_Instrument_BRDF_Model,int,integralmode,"Order of Gauss-Zernike integral (1-7)","3",0xFF);

    DEFINE_PARAMETER(Focussed_Beam_Instrument_BRDF_Model,double,focal_point,"Focal point to detector ratio","1",0xFF);

    int Circle_Integral::maxorder = 25;
    double Circle_Integral::table[] =
    {   0.,0.,1.,0.7071067811865476,0.,0.2499999999999999,0.7071067811865476,
        1.5707963267948966,0.24999999999999992,0.7071067811865476,3.141592653589793,
        0.24999999999999978,0.7071067811865476,4.71238898038469,0.24999999999999994,
        0.,0.,0.2499999999999998,0.816496580927726,0.,0.12500000000000008,
        0.816496580927726,1.0471975511965976,0.12500000000000003,0.816496580927726,
        2.0943951023931953,0.12500000000000003,0.816496580927726,3.141592653589793,
        0.12500000000000006,0.816496580927726,4.1887902047863905,
        0.12500000000000008,0.816496580927726,5.235987755982989,0.12500000000000006,
        0.4597008433809831,0.,0.0625,0.4597008433809831,0.7853981633974483,0.0625,
        0.4597008433809831,1.5707963267948966,0.0625,0.4597008433809831,
        2.356194490192345,0.0625,0.4597008433809831,3.141592653589793,0.0625,
        0.4597008433809831,3.9269908169872414,0.0625,0.4597008433809831,
        4.71238898038469,0.0625,0.4597008433809831,5.497787143782138,0.0625,
        0.8880738339771153,0.,0.0625,0.8880738339771153,0.7853981633974483,0.0625,
        0.8880738339771153,1.5707963267948966,0.0625,0.8880738339771153,
        2.356194490192345,0.0625,0.8880738339771153,3.141592653589793,0.0625,
        0.8880738339771153,3.9269908169872414,0.0625,0.8880738339771153,
        4.71238898038469,0.0625,0.8880738339771153,5.497787143782138,0.0625,0.,0.,
        0.11111111111111077,0.5958615826865181,0.,0.0512485826188421,
        0.5958615826865181,0.6283185307179586,0.051248582618842096,
        0.5958615826865181,1.2566370614359172,0.0512485826188421,0.5958615826865181,
        1.8849555921538759,0.05124858261884211,0.5958615826865181,
        2.5132741228718345,0.0512485826188421,0.5958615826865181,3.141592653589793,
        0.05124858261884212,0.5958615826865181,3.7699111843077517,
        0.05124858261884212,0.5958615826865181,4.39822971502571,0.05124858261884212,
        0.5958615826865181,5.026548245743669,0.051248582618842096,
        0.5958615826865181,5.654866776461628,0.05124858261884211,0.9192110607898046,
        0.,0.03764030627004667,0.9192110607898046,0.6283185307179586,
        0.03764030627004668,0.9192110607898046,1.2566370614359172,
        0.037640306270046685,0.9192110607898046,1.8849555921538759,
        0.0376403062700467,0.9192110607898046,2.5132741228718345,
        0.03764030627004671,0.9192110607898046,3.141592653589793,
        0.03764030627004675,0.9192110607898046,3.7699111843077517,
        0.03764030627004673,0.9192110607898046,4.39822971502571,0.03764030627004674,
        0.9192110607898046,5.026548245743669,0.037640306270046706,
        0.9192110607898046,5.654866776461628,0.03764030627004669,0.3357106870197288,
        0.,0.023148148148148164,0.3357106870197288,0.5235987755982988,
        0.02314814814814815,0.3357106870197288,1.0471975511965976,
        0.02314814814814816,0.3357106870197288,1.5707963267948966,
        0.023148148148148168,0.3357106870197288,2.0943951023931953,
        0.023148148148148175,0.3357106870197288,2.6179938779914944,
        0.023148148148148175,0.3357106870197288,3.141592653589793,
        0.02314814814814817,0.3357106870197288,3.6651914291880923,
        0.023148148148148164,0.3357106870197288,4.1887902047863905,
        0.023148148148148157,0.3357106870197288,4.71238898038469,
        0.023148148148148154,0.3357106870197288,5.235987755982989,
        0.02314814814814815,0.3357106870197288,5.759586531581287,
        0.02314814814814815,0.7071067811865476,0.,0.037037037037037056,
        0.7071067811865476,0.5235987755982988,0.03703703703703699,
        0.7071067811865476,1.0471975511965976,0.03703703703703703,
        0.7071067811865476,1.5707963267948966,0.03703703703703705,
        0.7071067811865476,2.0943951023931953,0.037037037037037056,
        0.7071067811865476,2.6179938779914944,0.03703703703703704,
        0.7071067811865476,3.141592653589793,0.037037037037037056,
        0.7071067811865476,3.6651914291880923,0.037037037037037035,
        0.7071067811865476,4.1887902047863905,0.037037037037037014,
        0.7071067811865476,4.71238898038469,0.03703703703703705,0.7071067811865476,
        5.235987755982989,0.03703703703703701,0.7071067811865476,5.759586531581287,
        0.03703703703703703,0.9419651451198934,0.,0.023148148148148237,
        0.9419651451198934,0.5235987755982988,0.023148148148148088,
        0.9419651451198934,1.0471975511965976,0.023148148148148175,
        0.9419651451198934,1.5707963267948966,0.023148148148148168,
        0.9419651451198934,2.0943951023931953,0.02314814814814821,
        0.9419651451198934,2.6179938779914944,0.023148148148148202,
        0.9419651451198934,3.141592653589793,0.023148148148148195,
        0.9419651451198934,3.6651914291880923,0.023148148148148202,
        0.9419651451198934,4.1887902047863905,0.02314814814814812,
        0.9419651451198934,4.71238898038469,0.02314814814814822,0.9419651451198934,
        5.235987755982989,0.02314814814814814,0.9419651451198934,5.759586531581287,
        0.02314814814814816,0.,0.,0.06250000000000008,0.4608042298407784,0.,
        0.023488879998575407,0.4608042298407784,0.4487989505128276,
        0.02348887999857541,0.4608042298407784,0.8975979010256552,
        0.023488879998575414,0.4608042298407784,1.3463968515384828,
        0.023488879998575414,0.4608042298407784,1.7951958020513104,
        0.023488879998575418,0.4608042298407784,2.243994752564138,
        0.023488879998575407,0.4608042298407784,2.6927937030769655,
        0.0234888799985754,0.4608042298407784,3.141592653589793,
        0.023488879998575404,0.4608042298407784,3.5903916041026207,
        0.023488879998575404,0.4608042298407784,4.039190554615448,
        0.023488879998575414,0.4608042298407784,4.487989505128276,
        0.023488879998575407,0.4608042298407784,4.9367884556411035,
        0.023488879998575407,0.4608042298407784,5.385587406153931,
        0.02348887999857541,0.4608042298407784,5.834386356666759,
        0.023488879998575418,0.7684615381131741,0.,0.027728104917369423,
        0.7684615381131741,0.4487989505128276,0.027728104917369406,
        0.7684615381131741,0.8975979010256552,0.02772810491736941,
        0.7684615381131741,1.3463968515384828,0.027728104917369416,
        0.7684615381131741,1.7951958020513104,0.02772810491736941,
        0.7684615381131741,2.243994752564138,0.027728104917369403,
        0.7684615381131741,2.6927937030769655,0.027728104917369406,
        0.7684615381131741,3.141592653589793,0.02772810491736941,0.7684615381131741,
        3.5903916041026207,0.027728104917369413,0.7684615381131741,
        4.039190554615448,0.027728104917369413,0.7684615381131741,4.487989505128276,
        0.027728104917369416,0.7684615381131741,4.9367884556411035,
        0.027728104917369416,0.7684615381131741,5.385587406153931,
        0.027728104917369403,0.7684615381131741,5.834386356666759,
        0.02772810491736942,0.9546790248493449,0.,0.015747300798340857,
        0.9546790248493449,0.4487989505128276,0.015747300798340847,
        0.9546790248493449,0.8975979010256552,0.015747300798340857,
        0.9546790248493449,1.3463968515384828,0.015747300798340854,
        0.9546790248493449,1.7951958020513104,0.01574730079834086,
        0.9546790248493449,2.243994752564138,0.01574730079834085,0.9546790248493449,
        2.6927937030769655,0.015747300798340847,0.9546790248493449,
        3.141592653589793,0.015747300798340854,0.9546790248493449,
        3.5903916041026207,0.015747300798340854,0.9546790248493449,
        4.039190554615448,0.015747300798340854,0.9546790248493449,4.487989505128276,
        0.01574730079834085,0.9546790248493449,4.9367884556411035,
        0.015747300798340857,0.9546790248493449,5.385587406153931,
        0.015747300798340857,0.9546790248493449,5.834386356666759,
        0.015747300798340854,0.26349922998554226,0.,0.010870463910545441,
        0.26349922998554226,0.39269908169872414,0.010870463910545419,
        0.26349922998554226,0.7853981633974483,0.010870463910545414,
        0.26349922998554226,1.1780972450961724,0.010870463910545414,
        0.26349922998554226,1.5707963267948966,0.010870463910545414,
        0.26349922998554226,1.9634954084936207,0.010870463910545412,
        0.26349922998554226,2.356194490192345,0.01087046391054541,
        0.26349922998554226,2.748893571891069,0.010870463910545407,
        0.26349922998554226,3.141592653589793,0.010870463910545405,
        0.26349922998554226,3.5342917352885173,0.010870463910545405,
        0.26349922998554226,3.9269908169872414,0.010870463910545407,
        0.26349922998554226,4.319689898685965,0.01087046391054541,
        0.26349922998554226,4.71238898038469,0.010870463910545412,
        0.26349922998554226,5.105088062083414,0.010870463910545412,
        0.26349922998554226,5.497787143782138,0.01087046391054541,
        0.26349922998554226,5.890486225480862,0.010870463910545414,
        0.5744645143153508,0.,0.020379536089454604,0.5744645143153508,
        0.39269908169872414,0.020379536089454586,0.5744645143153508,
        0.7853981633974483,0.02037953608945458,0.5744645143153508,
        1.1780972450961724,0.020379536089454572,0.5744645143153508,
        1.5707963267948966,0.02037953608945458,0.5744645143153508,
        1.9634954084936207,0.020379536089454586,0.5744645143153508,
        2.356194490192345,0.020379536089454586,0.5744645143153508,2.748893571891069,
        0.020379536089454593,0.5744645143153508,3.141592653589793,
        0.020379536089454593,0.5744645143153508,3.5342917352885173,
        0.020379536089454576,0.5744645143153508,3.9269908169872414,
        0.020379536089454576,0.5744645143153508,4.319689898685965,
        0.020379536089454593,0.5744645143153508,4.71238898038469,
        0.020379536089454597,0.5744645143153508,5.105088062083414,
        0.02037953608945458,0.5744645143153508,5.497787143782138,
        0.02037953608945456,0.5744645143153508,5.890486225480862,
        0.020379536089454576,0.8185294874300059,0.,0.020379536089454576,
        0.8185294874300059,0.39269908169872414,0.020379536089454527,
        0.8185294874300059,0.7853981633974483,0.020379536089454545,
        0.8185294874300059,1.1780972450961724,0.020379536089454534,
        0.8185294874300059,1.5707963267948966,0.02037953608945452,
        0.8185294874300059,1.9634954084936207,0.02037953608945455,
        0.8185294874300059,2.356194490192345,0.020379536089454545,
        0.8185294874300059,2.748893571891069,0.020379536089454538,
        0.8185294874300059,3.141592653589793,0.02037953608945454,0.8185294874300059,
        3.5342917352885173,0.02037953608945452,0.8185294874300059,
        3.9269908169872414,0.020379536089454538,0.8185294874300059,
        4.319689898685965,0.020379536089454545,0.8185294874300059,4.71238898038469,
        0.020379536089454565,0.8185294874300059,5.105088062083414,
        0.020379536089454548,0.8185294874300059,5.497787143782138,
        0.020379536089454493,0.8185294874300059,5.890486225480862,
        0.02037953608945454,0.9646596061808674,0.,0.010870463910545506,
        0.9646596061808674,0.39269908169872414,0.010870463910545476,
        0.9646596061808674,0.7853981633974483,0.010870463910545471,
        0.9646596061808674,1.1780972450961724,0.01087046391054546,
        0.9646596061808674,1.5707963267948966,0.010870463910545447,
        0.9646596061808674,1.9634954084936207,0.010870463910545464,
        0.9646596061808674,2.356194490192345,0.01087046391054547,0.9646596061808674,
        2.748893571891069,0.010870463910545443,0.9646596061808674,3.141592653589793,
        0.010870463910545445,0.9646596061808674,3.5342917352885173,
        0.01087046391054541,0.9646596061808674,3.9269908169872414,
        0.010870463910545438,0.9646596061808674,4.319689898685965,
        0.010870463910545473,0.9646596061808674,4.71238898038469,
        0.01087046391054551,0.9646596061808674,5.105088062083414,
        0.010870463910545467,0.9646596061808674,5.497787143782138,
        0.010870463910545395,0.9646596061808674,5.890486225480862,
        0.010870463910545471,0.,0.,0.03999999999999926,0.3738447061866472,0.,
        0.012394661171309348,0.3738447061866472,0.3490658503988659,
        0.012394661171309341,0.3738447061866472,0.6981317007977318,
        0.012394661171309329,0.3738447061866472,1.0471975511965976,
        0.01239466117130934,0.3738447061866472,1.3962634015954636,
        0.012394661171309343,0.3738447061866472,1.7453292519943295,
        0.01239466117130934,0.3738447061866472,2.0943951023931953,
        0.012394661171309345,0.3738447061866472,2.443460952792061,
        0.012394661171309336,0.3738447061866472,2.792526803190927,
        0.012394661171309334,0.3738447061866472,3.141592653589793,
        0.01239466117130934,0.3738447061866472,3.490658503988659,
        0.012394661171309341,0.3738447061866472,3.839724354387525,
        0.012394661171309341,0.3738447061866472,4.1887902047863905,
        0.012394661171309343,0.3738447061866472,4.537856055185257,
        0.012394661171309341,0.3738447061866472,4.886921905584122,
        0.012394661171309336,0.3738447061866472,5.235987755982989,
        0.012394661171309338,0.3738447061866472,5.585053606381854,
        0.012394661171309345,0.3738447061866472,5.93411945678072,
        0.012394661171309343,0.6452980455813292,0.,0.01732369572087433,
        0.6452980455813292,0.3490658503988659,0.017323695720874305,
        0.6452980455813292,0.6981317007977318,0.017323695720874308,
        0.6452980455813292,1.0471975511965976,0.01732369572087431,
        0.6452980455813292,1.3962634015954636,0.01732369572087432,
        0.6452980455813292,1.7453292519943295,0.017323695720874322,
        0.6452980455813292,2.0943951023931953,0.0173236957208743,0.6452980455813292,
        2.443460952792061,0.017323695720874308,0.6452980455813292,2.792526803190927,
        0.01732369572087431,0.6452980455813292,3.141592653589793,
        0.017323695720874322,0.6452980455813292,3.490658503988659,
        0.01732369572087432,0.6452980455813292,3.839724354387525,
        0.017323695720874298,0.6452980455813292,4.1887902047863905,
        0.017323695720874315,0.6452980455813292,4.537856055185257,
        0.017323695720874315,0.6452980455813292,4.886921905584122,
        0.017323695720874305,0.6452980455813292,5.235987755982989,
        0.017323695720874294,0.6452980455813292,5.585053606381854,
        0.01732369572087429,0.6452980455813292,5.93411945678072,0.01732369572087433,
        0.8503863747508401,0.,0.015630889730525774,0.8503863747508401,
        0.3490658503988659,0.01563088973052573,0.8503863747508401,
        0.6981317007977318,0.015630889730525767,0.8503863747508401,
        1.0471975511965976,0.015630889730525743,0.8503863747508401,
        1.3962634015954636,0.015630889730525753,0.8503863747508401,
        1.7453292519943295,0.015630889730525763,0.8503863747508401,
        2.0943951023931953,0.015630889730525736,0.8503863747508401,
        2.443460952792061,0.01563088973052575,0.8503863747508401,2.792526803190927,
        0.015630889730525743,0.8503863747508401,3.141592653589793,
        0.015630889730525756,0.8503863747508401,3.490658503988659,
        0.015630889730525763,0.8503863747508401,3.839724354387525,
        0.015630889730525732,0.8503863747508401,4.1887902047863905,
        0.01563088973052577,0.8503863747508401,4.537856055185257,
        0.015630889730525743,0.8503863747508401,4.886921905584122,
        0.015630889730525746,0.8503863747508401,5.235987755982989,
        0.015630889730525763,0.8503863747508401,5.585053606381854,
        0.01563088973052571,0.8503863747508401,5.93411945678072,
        0.015630889730525777,0.971028219922306,0.,0.007984086710623886,
        0.971028219922306,0.3490658503988659,0.007984086710623874,0.971028219922306,
        0.6981317007977318,0.007984086710623875,0.971028219922306,
        1.0471975511965976,0.007984086710623867,0.971028219922306,
        1.3962634015954636,0.007984086710623882,0.971028219922306,
        1.7453292519943295,0.00798408671062387,0.971028219922306,2.0943951023931953,
        0.007984086710623887,0.971028219922306,2.443460952792061,
        0.007984086710623867,0.971028219922306,2.792526803190927,
        0.007984086710623886,0.971028219922306,3.141592653589793,
        0.007984086710623874,0.971028219922306,3.490658503988659,
        0.00798408671062388,0.971028219922306,3.839724354387525,0.00798408671062387,
        0.971028219922306,4.1887902047863905,0.007984086710623887,0.971028219922306,
        4.537856055185257,0.007984086710623877,0.971028219922306,4.886921905584122,
        0.007984086710623865,0.971028219922306,5.235987755982989,
        0.007984086710623896,0.971028219922306,5.585053606381854,
        0.007984086710623858,0.971028219922306,5.93411945678072,
        0.007984086710623893,0.2165873427295972,0.,0.005923172126404793,
        0.2165873427295972,0.3141592653589793,0.005923172126404808,
        0.2165873427295972,0.6283185307179586,0.005923172126404804,
        0.2165873427295972,0.9424777960769379,0.005923172126404805,
        0.2165873427295972,1.2566370614359172,0.005923172126404802,
        0.2165873427295972,1.5707963267948966,0.0059231721264048,0.2165873427295972,
        1.8849555921538759,0.0059231721264048015,0.2165873427295972,
        2.199114857512855,0.005923172126404801,0.2165873427295972,
        2.5132741228718345,0.005923172126404799,0.2165873427295972,
        2.827433388230814,0.005923172126404803,0.2165873427295972,3.141592653589793,
        0.005923172126404802,0.2165873427295972,3.455751918948773,
        0.0059231721264048015,0.2165873427295972,3.7699111843077517,
        0.005923172126404802,0.2165873427295972,4.084070449666731,
        0.005923172126404802,0.2165873427295972,4.39822971502571,
        0.005923172126404801,0.2165873427295972,4.71238898038469,
        0.005923172126404802,0.2165873427295972,5.026548245743669,
        0.005923172126404803,0.2165873427295972,5.340707511102648,
        0.005923172126404805,0.2165873427295972,5.654866776461628,
        0.005923172126404805,0.2165873427295972,5.969026041820607,
        0.005923172126404807,0.48038041690639144,0.,0.011965716762484108,
        0.48038041690639144,0.3141592653589793,0.011965716762484094,
        0.48038041690639144,0.6283185307179586,0.011965716762484084,
        0.48038041690639144,0.9424777960769379,0.01196571676248409,
        0.48038041690639144,1.2566370614359172,0.0119657167624841,
        0.48038041690639144,1.5707963267948966,0.011965716762484096,
        0.48038041690639144,1.8849555921538759,0.011965716762484084,
        0.48038041690639144,2.199114857512855,0.01196571676248409,
        0.48038041690639144,2.5132741228718345,0.011965716762484093,
        0.48038041690639144,2.827433388230814,0.011965716762484096,
        0.48038041690639144,3.141592653589793,0.011965716762484093,
        0.48038041690639144,3.455751918948773,0.0119657167624841,
        0.48038041690639144,3.7699111843077517,0.011965716762484091,
        0.48038041690639144,4.084070449666731,0.011965716762484086,
        0.48038041690639144,4.39822971502571,0.011965716762484088,
        0.48038041690639144,4.71238898038469,0.011965716762484094,
        0.48038041690639144,5.026548245743669,0.011965716762484094,
        0.48038041690639144,5.340707511102648,0.011965716762484093,
        0.48038041690639144,5.654866776461628,0.011965716762484098,
        0.48038041690639144,5.969026041820607,0.0119657167624841,0.7071067811865476,
        0.,0.014222222222222155,0.7071067811865476,0.3141592653589793,
        0.014222222222222154,0.7071067811865476,0.6283185307179586,
        0.014222222222222131,0.7071067811865476,0.9424777960769379,
        0.014222222222222141,0.7071067811865476,1.2566370614359172,
        0.01422222222222217,0.7071067811865476,1.5707963267948966,
        0.014222222222222154,0.7071067811865476,1.8849555921538759,
        0.014222222222222124,0.7071067811865476,2.199114857512855,
        0.014222222222222145,0.7071067811865476,2.5132741228718345,
        0.014222222222222157,0.7071067811865476,2.827433388230814,
        0.014222222222222138,0.7071067811865476,3.141592653589793,
        0.014222222222222147,0.7071067811865476,3.455751918948773,
        0.014222222222222154,0.7071067811865476,3.7699111843077517,
        0.014222222222222148,0.7071067811865476,4.084070449666731,
        0.014222222222222138,0.7071067811865476,4.39822971502571,
        0.014222222222222131,0.7071067811865476,4.71238898038469,
        0.014222222222222148,0.7071067811865476,5.026548245743669,
        0.014222222222222152,0.7071067811865476,5.340707511102648,
        0.014222222222222145,0.7071067811865476,5.654866776461628,
        0.014222222222222148,0.7071067811865476,5.969026041820607,
        0.014222222222222148,0.8770602345636481,0.,0.01196571676248413,
        0.8770602345636481,0.3141592653589793,0.011965716762484134,
        0.8770602345636481,0.6283185307179586,0.011965716762484115,
        0.8770602345636481,0.9424777960769379,0.011965716762484115,
        0.8770602345636481,1.2566370614359172,0.011965716762484143,
        0.8770602345636481,1.5707963267948966,0.011965716762484133,
        0.8770602345636481,1.8849555921538759,0.011965716762484115,
        0.8770602345636481,2.199114857512855,0.011965716762484122,
        0.8770602345636481,2.5132741228718345,0.011965716762484141,
        0.8770602345636481,2.827433388230814,0.01196571676248411,0.8770602345636481,
        3.141592653589793,0.011965716762484138,0.8770602345636481,3.455751918948773,
        0.01196571676248413,0.8770602345636481,3.7699111843077517,
        0.011965716762484126,0.8770602345636481,4.084070449666731,
        0.011965716762484134,0.8770602345636481,4.39822971502571,
        0.011965716762484107,0.8770602345636481,4.71238898038469,
        0.011965716762484133,0.8770602345636481,5.026548245743669,
        0.011965716762484124,0.8770602345636481,5.340707511102648,
        0.011965716762484119,0.8770602345636481,5.654866776461628,
        0.011965716762484124,0.8770602345636481,5.969026041820607,
        0.011965716762484134,0.9762632447087886,0.,0.005923172126404789,
        0.9762632447087886,0.3141592653589793,0.005923172126404793,
        0.9762632447087886,0.6283185307179586,0.005923172126404788,
        0.9762632447087886,0.9424777960769379,0.005923172126404781,
        0.9762632447087886,1.2566370614359172,0.005923172126404806,
        0.9762632447087886,1.5707963267948966,0.0059231721264047825,
        0.9762632447087886,1.8849555921538759,0.005923172126404789,
        0.9762632447087886,2.199114857512855,0.0059231721264047755,
        0.9762632447087886,2.5132741228718345,0.005923172126404802,
        0.9762632447087886,2.827433388230814,0.005923172126404776,
        0.9762632447087886,3.141592653589793,0.005923172126404794,
        0.9762632447087886,3.455751918948773,0.005923172126404794,
        0.9762632447087886,3.7699111843077517,0.00592317212640478,
        0.9762632447087886,4.084070449666731,0.00592317212640479,0.9762632447087886,
        4.39822971502571,0.005923172126404774,0.9762632447087886,4.71238898038469,
        0.005923172126404803,0.9762632447087886,5.026548245743669,
        0.005923172126404779,0.9762632447087886,5.340707511102648,
        0.005923172126404801,0.9762632447087886,5.654866776461628,
        0.005923172126404786,0.9762632447087886,5.969026041820607,
        0.005923172126404799,0.,0.,0.027777777777771552,0.31390298787814436,0.,
        0.007264562573193879,0.31390298787814436,0.28559933214452665,
        0.007264562573193885,0.31390298787814436,0.5711986642890533,
        0.007264562573193885,0.31390298787814436,0.8567979964335799,
        0.0072645625731938826,0.31390298787814436,1.1423973285781066,
        0.007264562573193886,0.31390298787814436,1.427996660722633,
        0.007264562573193887,0.31390298787814436,1.7135959928671598,
        0.007264562573193892,0.31390298787814436,1.9991953250116865,
        0.007264562573193889,0.31390298787814436,2.284794657156213,
        0.0072645625731938895,0.31390298787814436,2.57039398930074,
        0.007264562573193887,0.31390298787814436,2.855993321445266,
        0.0072645625731938826,0.31390298787814436,3.141592653589793,
        0.0072645625731938826,0.31390298787814436,3.4271919857343196,
        0.007264562573193885,0.31390298787814436,3.7127913178788465,
        0.007264562573193885,0.31390298787814436,3.998390650023373,
        0.007264562573193886,0.31390298787814436,4.283989982167899,
        0.007264562573193887,0.31390298787814436,4.569589314312426,
        0.007264562573193889,0.31390298787814436,4.855188646456953,
        0.007264562573193889,0.31390298787814436,5.14078797860148,
        0.00726456257319388,0.31390298787814436,5.426387310746007,
        0.007264562573193883,0.31390298787814436,5.711986642890532,
        0.007264562573193887,0.31390298787814436,5.99758597503506,
        0.0072645625731938964,0.5518475574344458,0.,0.01103152701065773,
        0.5518475574344458,0.28559933214452665,0.011031527010657722,
        0.5518475574344458,0.5711986642890533,0.01103152701065772,
        0.5518475574344458,0.8567979964335799,0.01103152701065772,
        0.5518475574344458,1.1423973285781066,0.011031527010657724,
        0.5518475574344458,1.427996660722633,0.011031527010657738,
        0.5518475574344458,1.7135959928671598,0.011031527010657731,
        0.5518475574344458,1.9991953250116865,0.011031527010657722,
        0.5518475574344458,2.284794657156213,0.011031527010657734,
        0.5518475574344458,2.57039398930074,0.011031527010657727,0.5518475574344458,
        2.855993321445266,0.011031527010657715,0.5518475574344458,3.141592653589793,
        0.011031527010657722,0.5518475574344458,3.4271919857343196,
        0.011031527010657738,0.5518475574344458,3.7127913178788465,
        0.011031527010657738,0.5518475574344458,3.998390650023373,
        0.011031527010657714,0.5518475574344458,4.283989982167899,
        0.011031527010657708,0.5518475574344458,4.569589314312426,
        0.011031527010657738,0.5518475574344458,4.855188646456953,
        0.011031527010657759,0.5518475574344458,5.14078797860148,
        0.01103152701065773,0.5518475574344458,5.426387310746007,0.0110315270106577,
        0.5518475574344458,5.711986642890532,0.011031527010657726,
        0.5518475574344458,5.99758597503506,0.011031527010657745,0.7496833930084178,
        0.,0.011839245072490748,0.7496833930084178,0.28559933214452665,
        0.011839245072490765,0.7496833930084178,0.5711986642890533,
        0.011839245072490776,0.7496833930084178,0.8567979964335799,
        0.011839245072490756,0.7496833930084178,1.1423973285781066,
        0.011839245072490755,0.7496833930084178,1.427996660722633,
        0.011839245072490782,0.7496833930084178,1.7135959928671598,
        0.011839245072490784,0.7496833930084178,1.9991953250116865,
        0.01183924507249075,0.7496833930084178,2.284794657156213,
        0.01183924507249078,0.7496833930084178,2.57039398930074,
        0.011839245072490763,0.7496833930084178,2.855993321445266,
        0.011839245072490758,0.7496833930084178,3.141592653589793,
        0.011839245072490756,0.7496833930084178,3.4271919857343196,
        0.011839245072490769,0.7496833930084178,3.7127913178788465,
        0.011839245072490798,0.7496833930084178,3.998390650023373,
        0.011839245072490746,0.7496833930084178,4.283989982167899,
        0.01183924507249076,0.7496833930084178,4.569589314312426,
        0.011839245072490786,0.7496833930084178,4.855188646456953,
        0.011839245072490791,0.7496833930084178,5.14078797860148,
        0.011839245072490791,0.7496833930084178,5.426387310746007,
        0.011839245072490715,0.7496833930084178,5.711986642890532,
        0.011839245072490782,0.7496833930084178,5.99758597503506,0.0118392450724908,
        0.8955370355972956,0.,0.009475030325270391,0.8955370355972956,
        0.28559933214452665,0.009475030325270433,0.8955370355972956,
        0.5711986642890533,0.009475030325270401,0.8955370355972956,
        0.8567979964335799,0.009475030325270415,0.8955370355972956,
        1.1423973285781066,0.009475030325270408,0.8955370355972956,
        1.427996660722633,0.009475030325270415,0.8955370355972956,
        1.7135959928671598,0.009475030325270433,0.8955370355972956,
        1.9991953250116865,0.009475030325270395,0.8955370355972956,
        2.284794657156213,0.009475030325270441,0.8955370355972956,2.57039398930074,
        0.009475030325270403,0.8955370355972956,2.855993321445266,
        0.009475030325270415,0.8955370355972956,3.141592653589793,
        0.009475030325270414,0.8955370355972956,3.4271919857343196,
        0.009475030325270401,0.8955370355972956,3.7127913178788465,
        0.009475030325270457,0.8955370355972956,3.998390650023373,
        0.009475030325270372,0.8955370355972956,4.283989982167899,
        0.009475030325270419,0.8955370355972956,4.569589314312426,
        0.009475030325270424,0.8955370355972956,4.855188646456953,
        0.009475030325270408,0.8955370355972956,5.14078797860148,
        0.009475030325270448,0.8955370355972956,5.426387310746007,
        0.009475030325270353,0.8955370355972956,5.711986642890532,
        0.009475030325270428,0.8955370355972956,5.99758597503506,
        0.009475030325270443,0.9798929242261785,0.,0.004581554210306586,
        0.9798929242261785,0.28559933214452665,0.004581554210306594,
        0.9798929242261785,0.5711986642890533,0.004581554210306595,
        0.9798929242261785,0.8567979964335799,0.004581554210306581,
        0.9798929242261785,1.1423973285781066,0.004581554210306593,
        0.9798929242261785,1.427996660722633,0.004581554210306588,
        0.9798929242261785,1.7135959928671598,0.004581554210306601,
        0.9798929242261785,1.9991953250116865,0.004581554210306574,
        0.9798929242261785,2.284794657156213,0.0045815542103065975,
        0.9798929242261785,2.57039398930074,0.004581554210306587,0.9798929242261785,
        2.855993321445266,0.004581554210306584,0.9798929242261785,3.141592653589793,
        0.004581554210306585,0.9798929242261785,3.4271919857343196,
        0.004581554210306583,0.9798929242261785,3.7127913178788465,
        0.004581554210306613,0.9798929242261785,3.998390650023373,
        0.004581554210306572,0.9798929242261785,4.283989982167899,
        0.004581554210306596,0.9798929242261785,4.569589314312426,
        0.0045815542103065906,0.9798929242261785,4.855188646456953,
        0.004581554210306602,0.9798929242261785,5.14078797860148,
        0.004581554210306593,0.9798929242261785,5.426387310746007,
        0.004581554210306568,0.9798929242261785,5.711986642890532,
        0.004581554210306592,0.9798929242261785,5.99758597503506,
        0.004581554210306601,0.18375321194042835,0.,0.003569260257899532,
        0.18375321194042835,0.2617993877991494,0.003569260257899582,
        0.18375321194042835,0.5235987755982988,0.003569260257899584,
        0.18375321194042835,0.7853981633974483,0.00356926025789958,
        0.18375321194042835,1.0471975511965976,0.003569260257899576,
        0.18375321194042835,1.3089969389957472,0.003569260257899573,
        0.18375321194042835,1.5707963267948966,0.003569260257899572,
        0.18375321194042835,1.8325957145940461,0.00356926025789957,
        0.18375321194042835,2.0943951023931953,0.0035692602578995722,
        0.18375321194042835,2.356194490192345,0.0035692602578995735,
        0.18375321194042835,2.6179938779914944,0.0035692602578995757,
        0.18375321194042835,2.8797932657906435,0.003569260257899576,
        0.18375321194042835,3.141592653589793,0.003569260257899577,
        0.18375321194042835,3.4033920413889422,0.0035692602578995766,
        0.18375321194042835,3.6651914291880923,0.0035692602578995753,
        0.18375321194042835,3.9269908169872414,0.003569260257899573,
        0.18375321194042835,4.1887902047863905,0.0035692602578995714,
        0.18375321194042835,4.4505895925855405,0.0035692602578995714,
        0.18375321194042835,4.71238898038469,0.0035692602578995696,
        0.18375321194042835,4.974188368183839,0.003569260257899572,
        0.18375321194042835,5.235987755982989,0.003569260257899574,
        0.18375321194042835,5.497787143782138,0.0035692602578995787,
        0.18375321194042835,5.759586531581287,0.003569260257899583,
        0.18375321194042835,6.021385919380437,0.0035692602578995857,
        0.4115766110542092,0.,0.00751586610516929,0.4115766110542092,
        0.2617993877991494,0.007515866105169282,0.4115766110542092,
        0.5235987755982988,0.007515866105169279,0.4115766110542092,
        0.7853981633974483,0.007515866105169281,0.4115766110542092,
        1.0471975511965976,0.007515866105169287,0.4115766110542092,
        1.3089969389957472,0.007515866105169285,0.4115766110542092,
        1.5707963267948966,0.0075158661051692825,0.4115766110542092,
        1.8325957145940461,0.0075158661051692765,0.4115766110542092,
        2.0943951023931953,0.007515866105169278,0.4115766110542092,
        2.356194490192345,0.007515866105169284,0.4115766110542092,
        2.6179938779914944,0.007515866105169281,0.4115766110542092,
        2.8797932657906435,0.0075158661051692765,0.4115766110542092,
        3.141592653589793,0.007515866105169277,0.4115766110542092,
        3.4033920413889422,0.007515866105169282,0.4115766110542092,
        3.6651914291880923,0.007515866105169284,0.4115766110542092,
        3.9269908169872414,0.0075158661051692825,0.4115766110542092,
        4.1887902047863905,0.007515866105169278,0.4115766110542092,
        4.4505895925855405,0.007515866105169278,0.4115766110542092,4.71238898038469,
        0.007515866105169279,0.4115766110542092,4.974188368183839,
        0.007515866105169283,0.4115766110542092,5.235987755982989,
        0.007515866105169284,0.4115766110542092,5.497787143782138,
        0.007515866105169281,0.4115766110542092,5.759586531581287,
        0.007515866105169285,0.4115766110542092,6.021385919380437,
        0.007515866105169293,0.6170011401597256,0.,0.009748206970264616,
        0.6170011401597256,0.2617993877991494,0.009748206970264609,
        0.6170011401597256,0.5235987755982988,0.009748206970264607,
        0.6170011401597256,0.7853981633974483,0.009748206970264607,
        0.6170011401597256,1.0471975511965976,0.009748206970264623,
        0.6170011401597256,1.3089969389957472,0.009748206970264626,
        0.6170011401597256,1.5707963267948966,0.00974820697026461,
        0.6170011401597256,1.8325957145940461,0.009748206970264605,
        0.6170011401597256,2.0943951023931953,0.009748206970264607,
        0.6170011401597256,2.356194490192345,0.009748206970264616,
        0.6170011401597256,2.6179938779914944,0.009748206970264612,
        0.6170011401597256,2.8797932657906435,0.009748206970264604,
        0.6170011401597256,3.141592653589793,0.009748206970264604,
        0.6170011401597256,3.4033920413889422,0.009748206970264617,
        0.6170011401597256,3.6651914291880923,0.009748206970264628,
        0.6170011401597256,3.9269908169872414,0.009748206970264609,
        0.6170011401597256,4.1887902047863905,0.00974820697026461,
        0.6170011401597256,4.4505895925855405,0.009748206970264605,
        0.6170011401597256,4.71238898038469,0.009748206970264604,0.6170011401597256,
        4.974188368183839,0.00974820697026463,0.6170011401597256,5.235987755982989,
        0.009748206970264621,0.6170011401597256,5.497787143782138,
        0.009748206970264598,0.6170011401597256,5.759586531581287,
        0.009748206970264616,0.6170011401597256,6.021385919380437,
        0.009748206970264631,0.7869622564275865,0.,0.009748206970263962,
        0.7869622564275865,0.2617993877991494,0.009748206970263955,
        0.7869622564275865,0.5235987755982988,0.009748206970263974,
        0.7869622564275865,0.7853981633974483,0.009748206970263948,
        0.7869622564275865,1.0471975511965976,0.009748206970263976,
        0.7869622564275865,1.3089969389957472,0.009748206970263977,
        0.7869622564275865,1.5707963267948966,0.00974820697026396,
        0.7869622564275865,1.8325957145940461,0.009748206970263965,
        0.7869622564275865,2.0943951023931953,0.009748206970263948,
        0.7869622564275865,2.356194490192345,0.009748206970263972,
        0.7869622564275865,2.6179938779914944,0.00974820697026396,
        0.7869622564275865,2.8797932657906435,0.009748206970263958,
        0.7869622564275865,3.141592653589793,0.009748206970263957,
        0.7869622564275865,3.4033920413889422,0.009748206970263962,
        0.7869622564275865,3.6651914291880923,0.009748206970263991,
        0.7869622564275865,3.9269908169872414,0.009748206970263943,
        0.7869622564275865,4.1887902047863905,0.00974820697026397,
        0.7869622564275865,4.4505895925855405,0.00974820697026397,
        0.7869622564275865,4.71238898038469,0.009748206970263929,0.7869622564275865,
        4.974188368183839,0.009748206970263995,0.7869622564275865,5.235987755982989,
        0.00974820697026397,0.7869622564275865,5.497787143782138,
        0.009748206970263941,0.7869622564275865,5.759586531581287,
        0.009748206970263972,0.7869622564275865,6.021385919380437,
        0.009748206970263984,0.911375166017339,0.,0.0075158661051697075,
        0.911375166017339,0.2617993877991494,0.007515866105169682,0.911375166017339,
        0.5235987755982988,0.007515866105169704,0.911375166017339,
        0.7853981633974483,0.007515866105169679,0.911375166017339,
        1.0471975511965976,0.007515866105169718,0.911375166017339,
        1.3089969389957472,0.0075158661051697015,0.911375166017339,
        1.5707963267948966,0.007515866105169696,0.911375166017339,
        1.8325957145940461,0.007515866105169705,0.911375166017339,
        2.0943951023931953,0.007515866105169673,0.911375166017339,2.356194490192345,
        0.007515866105169722,0.911375166017339,2.6179938779914944,
        0.0075158661051696815,0.911375166017339,2.8797932657906435,
        0.007515866105169698,0.911375166017339,3.141592653589793,
        0.007515866105169704,0.911375166017339,3.4033920413889422,
        0.007515866105169681,0.911375166017339,3.6651914291880923,
        0.0075158661051697336,0.911375166017339,3.9269908169872414,
        0.0075158661051696754,0.911375166017339,4.1887902047863905,
        0.007515866105169697,0.911375166017339,4.4505895925855405,
        0.007515866105169708,0.911375166017339,4.71238898038469,
        0.007515866105169662,0.911375166017339,4.974188368183839,
        0.007515866105169732,0.911375166017339,5.235987755982989,
        0.00751586610516969,0.911375166017339,5.497787143782138,
        0.007515866105169685,0.911375166017339,5.759586531581287,
        0.007515866105169707,0.911375166017339,6.021385919380437,
        0.007515866105169702,0.9829724091252897,0.,0.003569260257899455,
        0.9829724091252897,0.2617993877991494,0.003569260257899443,
        0.9829724091252897,0.5235987755982988,0.0035692602578994586,
        0.9829724091252897,0.7853981633974483,0.0035692602578994365,
        0.9829724091252897,1.0471975511965976,0.0035692602578994556,
        0.9829724091252897,1.3089969389957472,0.0035692602578994495,
        0.9829724091252897,1.5707963267948966,0.003569260257899451,
        0.9829724091252897,1.8325957145940461,0.003569260257899451,
        0.9829724091252897,2.0943951023931953,0.0035692602578994404,
        0.9829724091252897,2.356194490192345,0.0035692602578994564,
        0.9829724091252897,2.6179938779914944,0.0035692602578994417,
        0.9829724091252897,2.8797932657906435,0.003569260257899449,
        0.9829724091252897,3.141592653589793,0.0035692602578994426,
        0.9829724091252897,3.4033920413889422,0.0035692602578994517,
        0.9829724091252897,3.6651914291880923,0.0035692602578994556,
        0.9829724091252897,3.9269908169872414,0.0035692602578994478,
        0.9829724091252897,4.1887902047863905,0.003569260257899444,
        0.9829724091252897,4.4505895925855405,0.003569260257899451,
        0.9829724091252897,4.71238898038469,0.0035692602578994374,
        0.9829724091252897,4.974188368183839,0.0035692602578994608,
        0.9829724091252897,5.235987755982989,0.0035692602578994504,
        0.9829724091252897,5.497787143782138,0.0035692602578994443,
        0.9829724091252897,5.759586531581287,0.0035692602578994577,
        0.9829724091252897,6.021385919380437,0.0035692602578994543,0.,0.,
        0.02040816326531316,0.2702856427564344,0.,0.0046005286389478595,
        0.2702856427564344,0.24166097335306103,0.0046005286389478855,
        0.2702856427564344,0.48332194670612205,0.004600528638947859,
        0.2702856427564344,0.7249829200591831,0.00460052863894786,
        0.2702856427564344,0.9666438934122441,0.004600528638947863,
        0.2702856427564344,1.2083048667653051,0.0046005286389478655,
        0.2702856427564344,1.4499658401183662,0.004600528638947868,
        0.2702856427564344,1.691626813471427,0.004600528638947867,
        0.2702856427564344,1.9332877868244882,0.0046005286389478655,
        0.2702856427564344,2.174948760177549,0.0046005286389478655,
        0.2702856427564344,2.4166097335306103,0.004600528638947863,
        0.2702856427564344,2.658270706883671,0.0046005286389478595,
        0.2702856427564344,2.8999316802367323,0.004600528638947862,
        0.2702856427564344,3.141592653589793,0.0046005286389478595,
        0.2702856427564344,3.383253626942854,0.004600528638947862,
        0.2702856427564344,3.6249146002959147,0.004600528638947865,
        0.2702856427564344,3.8665755736489764,0.004600528638947862,
        0.2702856427564344,4.108236547002037,0.004600528638947861,
        0.2702856427564344,4.349897520355098,0.004600528638947864,
        0.2702856427564344,4.591558493708159,0.004600528638947864,
        0.2702856427564344,4.8332194670612205,0.004600528638947864,
        0.2702856427564344,5.074880440414281,0.0046005286389478655,
        0.2702856427564344,5.316541413767342,0.0046005286389478655,
        0.2702856427564344,5.558202387120403,0.004600528638947868,
        0.2702856427564344,5.799863360473465,0.004600528638947868,
        0.2702856427564344,6.041524333826525,0.004600528638947863,
        0.48038124231691803,0.,0.00732595910854349,0.48038124231691803,
        0.24166097335306103,0.007325959108543486,0.48038124231691803,
        0.48332194670612205,0.007325959108543491,0.48038124231691803,
        0.7249829200591831,0.00732595910854349,0.48038124231691803,
        0.9666438934122441,0.00732595910854349,0.48038124231691803,
        1.2083048667653051,0.007325959108543486,0.48038124231691803,
        1.4499658401183662,0.007325959108543482,0.48038124231691803,
        1.691626813471427,0.007325959108543485,0.48038124231691803,
        1.9332877868244882,0.0073259591085434875,0.48038124231691803,
        2.174948760177549,0.007325959108543487,0.48038124231691803,
        2.4166097335306103,0.007325959108543484,0.48038124231691803,
        2.658270706883671,0.007325959108543488,0.48038124231691803,
        2.8999316802367323,0.007325959108543485,0.48038124231691803,
        3.141592653589793,0.00732595910854348,0.48038124231691803,3.383253626942854,
        0.007325959108543487,0.48038124231691803,3.6249146002959147,
        0.007325959108543492,0.48038124231691803,3.8665755736489764,
        0.007325959108543495,0.48038124231691803,4.108236547002037,
        0.007325959108543488,0.48038124231691803,4.349897520355098,
        0.007325959108543485,0.48038124231691803,4.591558493708159,
        0.007325959108543492,0.48038124231691803,4.8332194670612205,
        0.007325959108543492,0.48038124231691803,5.074880440414281,
        0.0073259591085434875,0.48038124231691803,5.316541413767342,
        0.007325959108543483,0.48038124231691803,5.558202387120403,
        0.007325959108543496,0.48038124231691803,5.799863360473465,
        0.007325959108543498,0.48038124231691803,6.041524333826525,
        0.007325959108543496,0.6643255837527634,0.,0.00859826594258747,
        0.6643255837527634,0.24166097335306103,0.00859826594258746,
        0.6643255837527634,0.48332194670612205,0.00859826594258747,
        0.6643255837527634,0.7249829200591831,0.00859826594258748,
        0.6643255837527634,0.9666438934122441,0.008598265942587464,
        0.6643255837527634,1.2083048667653051,0.008598265942587469,
        0.6643255837527634,1.4499658401183662,0.008598265942587472,
        0.6643255837527634,1.691626813471427,0.008598265942587464,
        0.6643255837527634,1.9332877868244882,0.008598265942587478,
        0.6643255837527634,2.174948760177549,0.00859826594258747,0.6643255837527634,
        2.4166097335306103,0.008598265942587457,0.6643255837527634,
        2.658270706883671,0.008598265942587476,0.6643255837527634,
        2.8999316802367323,0.008598265942587469,0.6643255837527634,
        3.141592653589793,0.008598265942587453,0.6643255837527634,3.383253626942854,
        0.008598265942587464,0.6643255837527634,3.6249146002959147,
        0.00859826594258748,0.6643255837527634,3.8665755736489764,
        0.00859826594258748,0.6643255837527634,4.108236547002037,
        0.008598265942587472,0.6643255837527634,4.349897520355098,
        0.008598265942587455,0.6643255837527634,4.591558493708159,
        0.008598265942587472,0.6643255837527634,4.8332194670612205,
        0.008598265942587493,0.6643255837527634,5.074880440414281,
        0.00859826594258746,0.6643255837527634,5.316541413767342,
        0.008598265942587453,0.6643255837527634,5.558202387120403,
        0.008598265942587481,0.6643255837527634,5.799863360473465,
        0.00859826594258747,0.6643255837527634,6.041524333826525,
        0.008598265942587467,0.8142575205172168,0.,0.008167380365499423,
        0.8142575205172168,0.24166097335306103,0.008167380365499383,
        0.8142575205172168,0.48332194670612205,0.008167380365499403,
        0.8142575205172168,0.7249829200591831,0.008167380365499426,
        0.8142575205172168,0.9666438934122441,0.008167380365499384,
        0.8142575205172168,1.2083048667653051,0.00816738036549941,
        0.8142575205172168,1.4499658401183662,0.008167380365499412,
        0.8142575205172168,1.691626813471427,0.008167380365499386,
        0.8142575205172168,1.9332877868244882,0.00816738036549942,
        0.8142575205172168,2.174948760177549,0.008167380365499405,
        0.8142575205172168,2.4166097335306103,0.008167380365499395,
        0.8142575205172168,2.658270706883671,0.008167380365499414,
        0.8142575205172168,2.8999316802367323,0.008167380365499407,
        0.8142575205172168,3.141592653589793,0.008167380365499388,
        0.8142575205172168,3.383253626942854,0.0081673803654994,0.8142575205172168,
        3.6249146002959147,0.008167380365499416,0.8142575205172168,
        3.8665755736489764,0.008167380365499396,0.8142575205172168,
        4.108236547002037,0.008167380365499416,0.8142575205172168,4.349897520355098,
        0.008167380365499391,0.8142575205172168,4.591558493708159,
        0.008167380365499393,0.8142575205172168,4.8332194670612205,
        0.008167380365499438,0.8142575205172168,5.074880440414281,
        0.008167380365499388,0.8142575205172168,5.316541413767342,
        0.008167380365499388,0.8142575205172168,5.558202387120403,
        0.008167380365499431,0.8142575205172168,5.799863360473465,
        0.0081673803654994,0.8142575205172168,6.041524333826525,
        0.008167380365499405,0.9229958831606541,0.,0.0061193121436017885,
        0.9229958831606541,0.24166097335306103,0.006119312143601767,
        0.9229958831606541,0.48332194670612205,0.006119312143601776,
        0.9229958831606541,0.7249829200591831,0.006119312143601794,
        0.9229958831606541,0.9666438934122441,0.006119312143601761,
        0.9229958831606541,1.2083048667653051,0.006119312143601789,
        0.9229958831606541,1.4499658401183662,0.006119312143601775,
        0.9229958831606541,1.691626813471427,0.006119312143601771,
        0.9229958831606541,1.9332877868244882,0.00611931214360179,
        0.9229958831606541,2.174948760177549,0.006119312143601769,
        0.9229958831606541,2.4166097335306103,0.006119312143601778,
        0.9229958831606541,2.658270706883671,0.006119312143601775,
        0.9229958831606541,2.8999316802367323,0.006119312143601776,
        0.9229958831606541,3.141592653589793,0.006119312143601773,
        0.9229958831606541,3.383253626942854,0.0061193121436017624,
        0.9229958831606541,3.6249146002959147,0.006119312143601794,
        0.9229958831606541,3.8665755736489764,0.006119312143601773,
        0.9229958831606541,4.108236547002037,0.006119312143601777,
        0.9229958831606541,4.349897520355098,0.006119312143601771,
        0.9229958831606541,4.591558493708159,0.006119312143601765,
        0.9229958831606541,4.8332194670612205,0.006119312143601802,
        0.9229958831606541,5.074880440414281,0.006119312143601758,
        0.9229958831606541,5.316541413767342,0.006119312143601765,
        0.9229958831606541,5.558202387120403,0.006119312143601787,
        0.9229958831606541,5.799863360473465,0.006119312143601781,
        0.9229958831606541,6.041524333826525,0.006119312143601772,
        0.9852327505925771,0.,0.002865162906000319,0.9852327505925771,
        0.24166097335306103,0.002865162906000304,0.9852327505925771,
        0.48332194670612205,0.002865162906000312,0.9852327505925771,
        0.7249829200591831,0.0028651629060003174,0.9852327505925771,
        0.9666438934122441,0.0028651629060002996,0.9852327505925771,
        1.2083048667653051,0.002865162906000319,0.9852327505925771,
        1.4499658401183662,0.00286516290600031,0.9852327505925771,1.691626813471427,
        0.0028651629060003118,0.9852327505925771,1.9332877868244882,
        0.002865162906000311,0.9852327505925771,2.174948760177549,
        0.0028651629060003118,0.9852327505925771,2.4166097335306103,
        0.0028651629060002996,0.9852327505925771,2.658270706883671,
        0.0028651629060003165,0.9852327505925771,2.8999316802367323,
        0.0028651629060002996,0.9852327505925771,3.141592653589793,
        0.002865162906000311,0.9852327505925771,3.383253626942854,
        0.002865162906000302,0.9852327505925771,3.6249146002959147,
        0.0028651629060003152,0.9852327505925771,3.8665755736489764,
        0.0028651629060003096,0.9852327505925771,4.108236547002037,
        0.0028651629060003126,0.9852327505925771,4.349897520355098,
        0.002865162906000308,0.9852327505925771,4.591558493708159,
        0.0028651629060003057,0.9852327505925771,4.8332194670612205,
        0.0028651629060003226,0.9852327505925771,5.074880440414281,
        0.0028651629060003026,0.9852327505925771,5.316541413767342,
        0.0028651629060003105,0.9852327505925771,5.558202387120403,
        0.0028651629060003165,0.9852327505925771,5.799863360473465,
        0.002865162906000312,0.9852327505925771,6.041524333826525,
        0.00286516290600031,0.1595181614381909,0.,0.002312231538729596,
        0.1595181614381909,0.2243994752564138,0.0023122315387296196,
        0.1595181614381909,0.4487989505128276,0.002312231538729623,
        0.1595181614381909,0.6731984257692414,0.0023122315387296196,
        0.1595181614381909,0.8975979010256552,0.0023122315387296187,
        0.1595181614381909,1.121997376282069,0.0023122315387296174,
        0.1595181614381909,1.3463968515384828,0.002312231538729616,
        0.1595181614381909,1.5707963267948966,0.002312231538729614,
        0.1595181614381909,1.7951958020513104,0.0023122315387296153,
        0.1595181614381909,2.019595277307724,0.002312231538729614,
        0.1595181614381909,2.243994752564138,0.002312231538729616,
        0.1595181614381909,2.4683942278205517,0.002312231538729617,
        0.1595181614381909,2.6927937030769655,0.0023122315387296166,
        0.1595181614381909,2.9171931783333793,0.002312231538729617,
        0.1595181614381909,3.141592653589793,0.0023122315387296183,
        0.1595181614381909,3.365992128846207,0.002312231538729617,
        0.1595181614381909,3.5903916041026207,0.0023122315387296166,
        0.1595181614381909,3.814791079359034,0.0023122315387296174,
        0.1595181614381909,4.039190554615448,0.002312231538729616,
        0.1595181614381909,4.263590029871862,0.002312231538729615,
        0.1595181614381909,4.487989505128276,0.0023122315387296153,
        0.1595181614381909,4.71238898038469,0.002312231538729615,0.1595181614381909,
        4.9367884556411035,0.0023122315387296157,0.1595181614381909,
        5.161187930897517,0.0023122315387296174,0.1595181614381909,
        5.385587406153931,0.002312231538729619,0.1595181614381909,5.609986881410345,
        0.002312231538729621,0.1595181614381909,5.834386356666759,
        0.002312231538729622,0.1595181614381909,6.058785831923172,
        0.0023122315387296235,0.35949187362206503,0.,0.004994739133737663,
        0.35949187362206503,0.2243994752564138,0.004994739133737661,
        0.35949187362206503,0.4487989505128276,0.004994739133737656,
        0.35949187362206503,0.6731984257692414,0.004994739133737657,
        0.35949187362206503,0.8975979010256552,0.004994739133737659,
        0.35949187362206503,1.121997376282069,0.004994739133737661,
        0.35949187362206503,1.3463968515384828,0.004994739133737658,
        0.35949187362206503,1.5707963267948966,0.004994739133737658,
        0.35949187362206503,1.7951958020513104,0.0049947391337376605,
        0.35949187362206503,2.019595277307724,0.004994739133737661,
        0.35949187362206503,2.243994752564138,0.0049947391337376605,
        0.35949187362206503,2.4683942278205517,0.00499473913373766,
        0.35949187362206503,2.6927937030769655,0.0049947391337376605,
        0.35949187362206503,2.9171931783333793,0.00499473913373766,
        0.35949187362206503,3.141592653589793,0.00499473913373766,
        0.35949187362206503,3.365992128846207,0.004994739133737657,
        0.35949187362206503,3.5903916041026207,0.004994739133737654,
        0.35949187362206503,3.814791079359034,0.004994739133737655,
        0.35949187362206503,4.039190554615448,0.00499473913373766,
        0.35949187362206503,4.263590029871862,0.004994739133737661,
        0.35949187362206503,4.487989505128276,0.004994739133737661,
        0.35949187362206503,4.71238898038469,0.00499473913373766,
        0.35949187362206503,4.9367884556411035,0.004994739133737658,
        0.35949187362206503,5.161187930897517,0.00499473913373766,
        0.35949187362206503,5.385587406153931,0.004994739133737659,
        0.35949187362206503,5.609986881410345,0.004994739133737656,
        0.35949187362206503,5.834386356666759,0.004994739133737658,
        0.35949187362206503,6.058785831923172,0.004994739133737662,
        0.5450480935764306,0.,0.006818393759019002,0.5450480935764306,
        0.2243994752564138,0.006818393759018991,0.5450480935764306,
        0.4487989505128276,0.006818393759018978,0.5450480935764306,
        0.6731984257692414,0.0068183937590189855,0.5450480935764306,
        0.8975979010256552,0.006818393759018996,0.5450480935764306,
        1.121997376282069,0.00681839375901899,0.5450480935764306,1.3463968515384828,
        0.0068183937590189795,0.5450480935764306,1.5707963267948966,
        0.006818393759018978,0.5450480935764306,1.7951958020513104,
        0.006818393759018985,0.5450480935764306,2.019595277307724,
        0.0068183937590189855,0.5450480935764306,2.243994752564138,
        0.006818393759018983,0.5450480935764306,2.4683942278205517,
        0.006818393759018985,0.5450480935764306,2.6927937030769655,
        0.006818393759018984,0.5450480935764306,2.9171931783333793,
        0.006818393759018982,0.5450480935764306,3.141592653589793,
        0.006818393759018983,0.5450480935764306,3.365992128846207,
        0.006818393759018984,0.5450480935764306,3.5903916041026207,
        0.006818393759018981,0.5450480935764306,3.814791079359034,
        0.0068183937590189795,0.5450480935764306,4.039190554615448,
        0.006818393759018986,0.5450480935764306,4.263590029871862,
        0.006818393759018991,0.5450480935764306,4.487989505128276,
        0.006818393759018989,0.5450480935764306,4.71238898038469,
        0.006818393759018982,0.5450480935764306,4.9367884556411035,
        0.00681839375901898,0.5450480935764306,5.161187930897517,
        0.006818393759018991,0.5450480935764306,5.385587406153931,
        0.006818393759018994,0.5450480935764306,5.609986881410345,
        0.006818393759018981,0.5450480935764306,5.834386356666759,
        0.006818393759018976,0.5450480935764306,6.058785831923172,
        0.006818393759018992,0.7071067811865476,0.,0.007463556851313302,
        0.7071067811865476,0.2243994752564138,0.007463556851313285,
        0.7071067811865476,0.4487989505128276,0.007463556851313267,
        0.7071067811865476,0.6731984257692414,0.00746355685131328,
        0.7071067811865476,0.8975979010256552,0.007463556851313291,
        0.7071067811865476,1.121997376282069,0.007463556851313279,
        0.7071067811865476,1.3463968515384828,0.0074635568513132695,
        0.7071067811865476,1.5707963267948966,0.007463556851313275,
        0.7071067811865476,1.7951958020513104,0.007463556851313279,
        0.7071067811865476,2.019595277307724,0.007463556851313278,
        0.7071067811865476,2.243994752564138,0.007463556851313267,
        0.7071067811865476,2.4683942278205517,0.007463556851313275,
        0.7071067811865476,2.6927937030769655,0.007463556851313282,
        0.7071067811865476,2.9171931783333793,0.007463556851313272,
        0.7071067811865476,3.141592653589793,0.007463556851313266,
        0.7071067811865476,3.365992128846207,0.007463556851313276,
        0.7071067811865476,3.5903916041026207,0.0074635568513132695,
        0.7071067811865476,3.814791079359034,0.007463556851313269,
        0.7071067811865476,4.039190554615448,0.007463556851313274,
        0.7071067811865476,4.263590029871862,0.007463556851313279,
        0.7071067811865476,4.487989505128276,0.007463556851313287,
        0.7071067811865476,4.71238898038469,0.007463556851313274,0.7071067811865476,
        4.9367884556411035,0.007463556851313268,0.7071067811865476,
        5.161187930897517,0.00746355685131328,0.7071067811865476,5.385587406153931,
        0.007463556851313288,0.7071067811865476,5.609986881410345,
        0.007463556851313282,0.7071067811865476,5.834386356666759,
        0.007463556851313268,0.7071067811865476,6.058785831923172,
        0.007463556851313283,0.8384047803350709,0.,0.006818393759018854,
        0.8384047803350709,0.2243994752564138,0.006818393759018835,
        0.8384047803350709,0.4487989505128276,0.006818393759018823,
        0.8384047803350709,0.6731984257692414,0.0068183937590188355,
        0.8384047803350709,0.8975979010256552,0.006818393759018847,
        0.8384047803350709,1.121997376282069,0.006818393759018833,
        0.8384047803350709,1.3463968515384828,0.00681839375901883,
        0.8384047803350709,1.5707963267948966,0.006818393759018826,
        0.8384047803350709,1.7951958020513104,0.006818393759018833,
        0.8384047803350709,2.019595277307724,0.006818393759018836,
        0.8384047803350709,2.243994752564138,0.006818393759018831,
        0.8384047803350709,2.4683942278205517,0.006818393759018828,
        0.8384047803350709,2.6927937030769655,0.006818393759018832,
        0.8384047803350709,2.9171931783333793,0.006818393759018832,
        0.8384047803350709,3.141592653589793,0.006818393759018821,
        0.8384047803350709,3.365992128846207,0.006818393759018841,
        0.8384047803350709,3.5903916041026207,0.006818393759018821,
        0.8384047803350709,3.814791079359034,0.006818393759018826,
        0.8384047803350709,4.039190554615448,0.00681839375901884,0.8384047803350709,
        4.263590029871862,0.006818393759018826,0.8384047803350709,4.487989505128276,
        0.00681839375901885,0.8384047803350709,4.71238898038469,
        0.006818393759018824,0.8384047803350709,4.9367884556411035,
        0.0068183937590188285,0.8384047803350709,5.161187930897517,
        0.006818393759018841,0.8384047803350709,5.385587406153931,
        0.0068183937590188355,0.8384047803350709,5.609986881410345,
        0.006818393759018842,0.8384047803350709,5.834386356666759,
        0.006818393759018822,0.8384047803350709,6.058785831923172,
        0.00681839375901884,0.9331482158798232,0.,0.0049947391337378235,
        0.9331482158798232,0.2243994752564138,0.004994739133737807,
        0.9331482158798232,0.4487989505128276,0.004994739133737807,
        0.9331482158798232,0.6731984257692414,0.004994739133737801,
        0.9331482158798232,0.8975979010256552,0.004994739133737818,
        0.9331482158798232,1.121997376282069,0.00499473913373781,0.9331482158798232,
        1.3463968515384828,0.004994739133737802,0.9331482158798232,
        1.5707963267948966,0.004994739133737802,0.9331482158798232,
        1.7951958020513104,0.00499473913373781,0.9331482158798232,2.019595277307724,
        0.004994739133737803,0.9331482158798232,2.243994752564138,
        0.0049947391337378045,0.9331482158798232,2.4683942278205517,
        0.004994739133737803,0.9331482158798232,2.6927937030769655,
        0.004994739133737804,0.9331482158798232,2.9171931783333793,
        0.0049947391337378105,0.9331482158798232,3.141592653589793,
        0.004994739133737789,0.9331482158798232,3.365992128846207,
        0.004994739133737816,0.9331482158798232,3.5903916041026207,
        0.004994739133737793,0.9331482158798232,3.814791079359034,
        0.004994739133737803,0.9331482158798232,4.039190554615448,
        0.004994739133737812,0.9331482158798232,4.263590029871862,
        0.004994739133737794,0.9331482158798232,4.487989505128276,
        0.004994739133737828,0.9331482158798232,4.71238898038469,
        0.004994739133737794,0.9331482158798232,4.9367884556411035,
        0.004994739133737803,0.9331482158798232,5.161187930897517,
        0.0049947391337378105,0.9331482158798232,5.385587406153931,
        0.004994739133737803,0.9331482158798232,5.609986881410345,
        0.00499473913373782,0.9331482158798232,5.834386356666759,
        0.004994739133737791,0.9331482158798232,6.058785831923172,
        0.004994739133737814,0.9871949939963124,0.,0.0023122315387295728,
        0.9871949939963124,0.2243994752564138,0.0023122315387295632,
        0.9871949939963124,0.4487989505128276,0.0023122315387295632,
        0.9871949939963124,0.6731984257692414,0.0023122315387295637,
        0.9871949939963124,0.8975979010256552,0.0023122315387295706,
        0.9871949939963124,1.121997376282069,0.002312231538729565,
        0.9871949939963124,1.3463968515384828,0.002312231538729564,
        0.9871949939963124,1.5707963267948966,0.002312231538729565,
        0.9871949939963124,1.7951958020513104,0.0023122315387295663,
        0.9871949939963124,2.019595277307724,0.0023122315387295667,
        0.9871949939963124,2.243994752564138,0.0023122315387295624,
        0.9871949939963124,2.4683942278205517,0.0023122315387295667,
        0.9871949939963124,2.6927937030769655,0.0023122315387295632,
        0.9871949939963124,2.9171931783333793,0.0023122315387295663,
        0.9871949939963124,3.141592653589793,0.0023122315387295585,
        0.9871949939963124,3.365992128846207,0.002312231538729568,
        0.9871949939963124,3.5903916041026207,0.0023122315387295598,
        0.9871949939963124,3.814791079359034,0.002312231538729563,
        0.9871949939963124,4.039190554615448,0.0023122315387295654,
        0.9871949939963124,4.263590029871862,0.002312231538729565,
        0.9871949939963124,4.487989505128276,0.0023122315387295676,
        0.9871949939963124,4.71238898038469,0.002312231538729561,0.9871949939963124,
        4.9367884556411035,0.002312231538729562,0.9871949939963124,
        5.161187930897517,0.002312231538729567,0.9871949939963124,5.385587406153931,
        0.0023122315387295667,0.9871949939963124,5.609986881410345,
        0.002312231538729564,0.9871949939963124,5.834386356666759,
        0.0023122315387295632,0.9871949939963124,6.058785831923172,
        0.002312231538729565,0.,0.,0.01562500000002843,0.2371973029714338,0.,
        0.003089302580047565,0.2371973029714338,0.20943951023931953,
        0.0030893025800475607,0.2371973029714338,0.41887902047863906,
        0.003089302580047557,0.2371973029714338,0.6283185307179586,
        0.003089302580047558,0.2371973029714338,0.8377580409572781,
        0.0030893025800475585,0.2371973029714338,1.0471975511965976,
        0.003089302580047559,0.2371973029714338,1.2566370614359172,
        0.0030893025800475585,0.2371973029714338,1.4660765716752369,
        0.00308930258004756,0.2371973029714338,1.6755160819145563,
        0.0030893025800475577,0.2371973029714338,1.8849555921538759,
        0.0030893025800475585,0.2371973029714338,2.0943951023931953,
        0.003089302580047557,0.2371973029714338,2.3038346126325147,
        0.0030893025800475577,0.2371973029714338,2.5132741228718345,
        0.0030893025800475577,0.2371973029714338,2.7227136331111543,
        0.0030893025800475607,0.2371973029714338,2.9321531433504737,
        0.0030893025800475603,0.2371973029714338,3.141592653589793,
        0.0030893025800475607,0.2371973029714338,3.3510321638291125,
        0.003089302580047561,0.2371973029714338,3.560471674068432,
        0.003089302580047559,0.2371973029714338,3.7699111843077517,
        0.0030893025800475572,0.2371973029714338,3.979350694547071,
        0.0030893025800475564,0.2371973029714338,4.1887902047863905,
        0.003089302580047555,0.2371973029714338,4.39822971502571,
        0.003089302580047556,0.2371973029714338,4.607669225265029,
        0.003089302580047559,0.2371973029714338,4.81710873550435,
        0.0030893025800475603,0.2371973029714338,5.026548245743669,
        0.0030893025800475607,0.2371973029714338,5.235987755982989,
        0.0030893025800475607,0.2371973029714338,5.445427266222309,
        0.0030893025800475607,0.2371973029714338,5.654866776461628,
        0.003089302580047557,0.2371973029714338,5.8643062867009474,
        0.003089302580047555,0.2371973029714338,6.073745796940266,
        0.003089302580047554,0.42454763188232764,0.,0.005068843677449078,
        0.42454763188232764,0.20943951023931953,0.005068843677449071,
        0.42454763188232764,0.41887902047863906,0.005068843677449068,
        0.42454763188232764,0.6283185307179586,0.005068843677449061,
        0.42454763188232764,0.8377580409572781,0.0050688436774490656,
        0.42454763188232764,1.0471975511965976,0.00506884367744907,
        0.42454763188232764,1.2566370614359172,0.0050688436774490725,
        0.42454763188232764,1.4660765716752369,0.005068843677449069,
        0.42454763188232764,1.6755160819145563,0.0050688436774490656,
        0.42454763188232764,1.8849555921538759,0.005068843677449065,
        0.42454763188232764,2.0943951023931953,0.005068843677449064,
        0.42454763188232764,2.3038346126325147,0.005068843677449069,
        0.42454763188232764,2.5132741228718345,0.005068843677449075,
        0.42454763188232764,2.7227136331111543,0.00506884367744907,
        0.42454763188232764,2.9321531433504737,0.005068843677449064,
        0.42454763188232764,3.141592653589793,0.005068843677449059,
        0.42454763188232764,3.3510321638291125,0.005068843677449063,
        0.42454763188232764,3.560471674068432,0.005068843677449072,
        0.42454763188232764,3.7699111843077517,0.005068843677449074,
        0.42454763188232764,3.979350694547071,0.0050688436774490725,
        0.42454763188232764,4.1887902047863905,0.005068843677449064,
        0.42454763188232764,4.39822971502571,0.005068843677449065,
        0.42454763188232764,4.607669225265029,0.005068843677449068,
        0.42454763188232764,4.81710873550435,0.0050688436774490725,
        0.42454763188232764,5.026548245743669,0.0050688436774490725,
        0.42454763188232764,5.235987755982989,0.005068843677449071,
        0.42454763188232764,5.445427266222309,0.005068843677449067,
        0.42454763188232764,5.654866776461628,0.005068843677449063,
        0.42454763188232764,5.8643062867009474,0.005068843677449065,
        0.42454763188232764,6.073745796940266,0.005068843677449071,
        0.5938221258198195,0.,0.006275292423149464,0.5938221258198195,
        0.20943951023931953,0.006275292423149456,0.5938221258198195,
        0.41887902047863906,0.0062752924231494565,0.5938221258198195,
        0.6283185307179586,0.006275292423149451,0.5938221258198195,
        0.8377580409572781,0.006275292423149449,0.5938221258198195,
        1.0471975511965976,0.00627529242314946,0.5938221258198195,
        1.2566370614359172,0.006275292423149468,0.5938221258198195,
        1.4660765716752369,0.006275292423149455,0.5938221258198195,
        1.6755160819145563,0.006275292423149458,0.5938221258198195,
        1.8849555921538759,0.006275292423149457,0.5938221258198195,
        2.0943951023931953,0.006275292423149445,0.5938221258198195,
        2.3038346126325147,0.006275292423149454,0.5938221258198195,
        2.5132741228718345,0.006275292423149466,0.5938221258198195,
        2.7227136331111543,0.006275292423149461,0.5938221258198195,
        2.9321531433504737,0.006275292423149449,0.5938221258198195,
        3.141592653589793,0.006275292423149442,0.5938221258198195,
        3.3510321638291125,0.0062752924231494495,0.5938221258198195,
        3.560471674068432,0.006275292423149457,0.5938221258198195,
        3.7699111843077517,0.006275292423149462,0.5938221258198195,
        3.979350694547071,0.006275292423149458,0.5938221258198195,
        4.1887902047863905,0.0062752924231494435,0.5938221258198195,
        4.39822971502571,0.006275292423149441,0.5938221258198195,4.607669225265029,
        0.0062752924231494625,0.5938221258198195,4.81710873550435,
        0.0062752924231494625,0.5938221258198195,5.026548245743669,
        0.006275292423149456,0.5938221258198195,5.235987755982989,
        0.006275292423149461,0.5938221258198195,5.445427266222309,
        0.006275292423149459,0.5938221258198195,5.654866776461628,
        0.006275292423149447,0.5938221258198195,5.8643062867009474,
        0.0062752924231494495,0.5938221258198195,6.073745796940266,
        0.006275292423149462,0.7396983346814804,0.,0.006526202790877037,
        0.7396983346814804,0.20943951023931953,0.006526202790877012,
        0.7396983346814804,0.41887902047863906,0.006526202790877018,
        0.7396983346814804,0.6283185307179586,0.006526202790877024,
        0.7396983346814804,0.8377580409572781,0.0065262027908770046,
        0.7396983346814804,1.0471975511965976,0.006526202790877024,
        0.7396983346814804,1.2566370614359172,0.006526202790877038,
        0.7396983346814804,1.4660765716752369,0.006526202790877004,
        0.7396983346814804,1.6755160819145563,0.006526202790877016,
        0.7396983346814804,1.8849555921538759,0.006526202790877025,
        0.7396983346814804,2.0943951023931953,0.006526202790876996,
        0.7396983346814804,2.3038346126325147,0.006526202790877018,
        0.7396983346814804,2.5132741228718345,0.0065262027908770314,
        0.7396983346814804,2.7227136331111543,0.006526202790877015,
        0.7396983346814804,2.9321531433504737,0.006526202790877007,
        0.7396983346814804,3.141592653589793,0.006526202790877002,
        0.7396983346814804,3.3510321638291125,0.006526202790877013,
        0.7396983346814804,3.560471674068432,0.006526202790877016,
        0.7396983346814804,3.7699111843077517,0.006526202790877019,
        0.7396983346814804,3.979350694547071,0.006526202790877029,
        0.7396983346814804,4.1887902047863905,0.00652620279087701,
        0.7396983346814804,4.39822971502571,0.006526202790876998,0.7396983346814804,
        4.607669225265029,0.006526202790877035,0.7396983346814804,4.81710873550435,
        0.006526202790877028,0.7396983346814804,5.026548245743669,
        0.006526202790877009,0.7396983346814804,5.235987755982989,
        0.006526202790877029,0.7396983346814804,5.445427266222309,
        0.006526202790877015,0.7396983346814804,5.654866776461628,
        0.006526202790877008,0.7396983346814804,5.8643062867009474,
        0.006526202790877009,0.7396983346814804,6.073745796940266,
        0.006526202790877021,0.8568606521572866,0.,0.005783579927240265,
        0.8568606521572866,0.20943951023931953,0.005783579927240225,
        0.8568606521572866,0.41887902047863906,0.005783579927240243,
        0.8568606521572866,0.6283185307179586,0.005783579927240239,
        0.8568606521572866,0.8377580409572781,0.005783579927240225,
        0.8568606521572866,1.0471975511965976,0.005783579927240239,
        0.8568606521572866,1.2566370614359172,0.005783579927240256,
        0.8568606521572866,1.4660765716752369,0.0057835799272402235,
        0.8568606521572866,1.6755160819145563,0.0057835799272402365,
        0.8568606521572866,1.8849555921538759,0.0057835799272402495,
        0.8568606521572866,2.0943951023931953,0.005783579927240208,
        0.8568606521572866,2.3038346126325147,0.005783579927240247,
        0.8568606521572866,2.5132741228718345,0.005783579927240246,
        0.8568606521572866,2.7227136331111543,0.0057835799272402365,
        0.8568606521572866,2.9321531433504737,0.005783579927240237,
        0.8568606521572866,3.141592653589793,0.005783579927240226,
        0.8568606521572866,3.3510321638291125,0.005783579927240233,
        0.8568606521572866,3.560471674068432,0.0057835799272402426,
        0.8568606521572866,3.7699111843077517,0.005783579927240245,
        0.8568606521572866,3.979350694547071,0.005783579927240238,
        0.8568606521572866,4.1887902047863905,0.005783579927240237,
        0.8568606521572866,4.39822971502571,0.005783579927240214,0.8568606521572866,
        4.607669225265029,0.0057835799272402556,0.8568606521572866,4.81710873550435,
        0.0057835799272402495,0.8568606521572866,5.026548245743669,
        0.0057835799272402235,0.8568606521572866,5.235987755982989,
        0.005783579927240262,0.8568606521572866,5.445427266222309,
        0.005783579927240221,0.8568606521572866,5.654866776461628,
        0.005783579927240245,0.8568606521572866,5.8643062867009474,
        0.005783579927240234,0.8568606521572866,6.073745796940266,
        0.005783579927240236,0.9409149519691435,0.,0.004160798355498492,
        0.9409149519691435,0.20943951023931953,0.004160798355498457,
        0.9409149519691435,0.41887902047863906,0.004160798355498483,
        0.9409149519691435,0.6283185307179586,0.004160798355498462,
        0.9409149519691435,0.8377580409572781,0.00416079835549847,
        0.9409149519691435,1.0471975511965976,0.004160798355498472,
        0.9409149519691435,1.2566370614359172,0.0041607983554984825,
        0.9409149519691435,1.4660765716752369,0.004160798355498468,
        0.9409149519691435,1.6755160819145563,0.004160798355498467,
        0.9409149519691435,1.8849555921538759,0.0041607983554984825,
        0.9409149519691435,2.0943951023931953,0.004160798355498455,
        0.9409149519691435,2.3038346126325147,0.004160798355498479,
        0.9409149519691435,2.5132741228718345,0.004160798355498477,
        0.9409149519691435,2.7227136331111543,0.004160798355498475,
        0.9409149519691435,2.9321531433504737,0.004160798355498465,
        0.9409149519691435,3.141592653589793,0.004160798355498463,
        0.9409149519691435,3.3510321638291125,0.004160798355498474,
        0.9409149519691435,3.560471674068432,0.004160798355498466,
        0.9409149519691435,3.7699111843077517,0.004160798355498483,
        0.9409149519691435,3.979350694547071,0.004160798355498468,
        0.9409149519691435,4.1887902047863905,0.0041607983554984755,
        0.9409149519691435,4.39822971502571,0.0041607983554984565,
        0.9409149519691435,4.607669225265029,0.004160798355498481,
        0.9409149519691435,4.81710873550435,0.004160798355498486,0.9409149519691435,
        5.026548245743669,0.004160798355498455,0.9409149519691435,5.235987755982989,
        0.004160798355498496,0.9409149519691435,5.445427266222309,
        0.0041607983554984565,0.9409149519691435,5.654866776461628,
        0.004160798355498481,0.9409149519691435,5.8643062867009474,
        0.004160798355498464,0.9409149519691435,6.073745796940266,
        0.004160798355498473,0.9886964213353295,0.,0.0019084802457373054,
        0.9886964213353295,0.20943951023931953,0.0019084802457372894,
        0.9886964213353295,0.41887902047863906,0.0019084802457373013,
        0.9886964213353295,0.6283185307179586,0.0019084802457372961,
        0.9886964213353295,0.8377580409572781,0.001908480245737295,
        0.9886964213353295,1.0471975511965976,0.0019084802457372955,
        0.9886964213353295,1.2566370614359172,0.0019084802457373083,
        0.9886964213353295,1.4660765716752369,0.001908480245737289,
        0.9886964213353295,1.6755160819145563,0.0019084802457373026,
        0.9886964213353295,1.8849555921538759,0.0019084802457373,0.9886964213353295,
        2.0943951023931953,0.001908480245737291,0.9886964213353295,
        2.3038346126325147,0.0019084802457372987,0.9886964213353295,
        2.5132741228718345,0.0019084802457373026,0.9886964213353295,
        2.7227136331111543,0.001908480245737297,0.9886964213353295,
        2.9321531433504737,0.0019084802457372985,0.9886964213353295,
        3.141592653589793,0.0019084802457372918,0.9886964213353295,
        3.3510321638291125,0.0019084802457372957,0.9886964213353295,
        3.560471674068432,0.0019084802457372994,0.9886964213353295,
        3.7699111843077517,0.001908480245737297,0.9886964213353295,
        3.979350694547071,0.0019084802457373011,0.9886964213353295,
        4.1887902047863905,0.0019084802457372927,0.9886964213353295,
        4.39822971502571,0.0019084802457372957,0.9886964213353295,4.607669225265029,
        0.0019084802457372985,0.9886964213353295,4.81710873550435,
        0.0019084802457373078,0.9886964213353295,5.026548245743669,
        0.0019084802457372922,0.9886964213353295,5.235987755982989,
        0.001908480245737308,0.9886964213353295,5.445427266222309,
        0.0019084802457372922,0.9886964213353295,5.654866776461628,
        0.0019084802457373033,0.9886964213353295,5.8643062867009474,
        0.0019084802457372924,0.9886964213353295,6.073745796940266,
        0.0019084802457372992,0.14090802585811713,0.,0.0015816958795371342,
        0.14090802585811713,0.19634954084936207,0.001581695879537084,
        0.14090802585811713,0.39269908169872414,0.0015816958795370878,
        0.14090802585811713,0.5890486225480862,0.0015816958795370868,
        0.14090802585811713,0.7853981633974483,0.0015816958795370894,
        0.14090802585811713,0.9817477042468103,0.0015816958795370891,
        0.14090802585811713,1.1780972450961724,0.0015816958795370894,
        0.14090802585811713,1.3744467859455345,0.0015816958795370894,
        0.14090802585811713,1.5707963267948966,0.0015816958795370894,
        0.14090802585811713,1.7671458676442586,0.0015816958795370868,
        0.14090802585811713,1.9634954084936207,0.0015816958795370894,
        0.14090802585811713,2.1598449493429825,0.0015816958795370883,
        0.14090802585811713,2.356194490192345,0.0015816958795370872,
        0.14090802585811713,2.552544031041707,0.0015816958795370878,
        0.14090802585811713,2.748893571891069,0.0015816958795370863,
        0.14090802585811713,2.945243112740431,0.0015816958795370863,
        0.14090802585811713,3.141592653589793,0.0015816958795370876,
        0.14090802585811713,3.3379421944391554,0.0015816958795370865,
        0.14090802585811713,3.5342917352885173,0.0015816958795370876,
        0.14090802585811713,3.730641276137879,0.001581695879537088,
        0.14090802585811713,3.9269908169872414,0.001581695879537088,
        0.14090802585811713,4.123340357836604,0.0015816958795370896,
        0.14090802585811713,4.319689898685965,0.0015816958795370896,
        0.14090802585811713,4.516039439535327,0.001581695879537091,
        0.14090802585811713,4.71238898038469,0.001581695879537091,
        0.14090802585811713,4.908738521234052,0.0015816958795370898,
        0.14090802585811713,5.105088062083414,0.0015816958795370887,
        0.14090802585811713,5.301437602932776,0.001581695879537088,
        0.14090802585811713,5.497787143782138,0.0015816958795370883,
        0.14090802585811713,5.6941366846315,0.0015816958795370872,
        0.14090802585811713,5.890486225480862,0.0015816958795370872,
        0.14090802585811713,6.086835766330224,0.0015816958795370872,
        0.31885225621467167,0.,0.003474703663334449,0.31885225621467167,
        0.19634954084936207,0.003474703663334447,0.31885225621467167,
        0.39269908169872414,0.0034747036633344434,0.31885225621467167,
        0.5890486225480862,0.0034747036633344434,0.31885225621467167,
        0.7853981633974483,0.0034747036633344442,0.31885225621467167,
        0.9817477042468103,0.003474703663334445,0.31885225621467167,
        1.1780972450961724,0.0034747036633344447,0.31885225621467167,
        1.3744467859455345,0.003474703663334444,0.31885225621467167,
        1.5707963267948966,0.0034747036633344425,0.31885225621467167,
        1.7671458676442586,0.0034747036633344425,0.31885225621467167,
        1.9634954084936207,0.003474703663334445,0.31885225621467167,
        2.1598449493429825,0.0034747036633344447,0.31885225621467167,
        2.356194490192345,0.003474703663334444,0.31885225621467167,
        2.552544031041707,0.0034747036633344408,0.31885225621467167,
        2.748893571891069,0.00347470366333444,0.31885225621467167,2.945243112740431,
        0.003474703663334442,0.31885225621467167,3.141592653589793,
        0.0034747036633344425,0.31885225621467167,3.3379421944391554,
        0.003474703663334441,0.31885225621467167,3.5342917352885173,
        0.00347470366333444,0.31885225621467167,3.730641276137879,
        0.00347470366333444,0.31885225621467167,3.9269908169872414,
        0.0034747036633344408,0.31885225621467167,4.123340357836604,
        0.003474703663334442,0.31885225621467167,4.319689898685965,
        0.003474703663334444,0.31885225621467167,4.516039439535327,
        0.003474703663334445,0.31885225621467167,4.71238898038469,
        0.003474703663334447,0.31885225621467167,4.908738521234052,
        0.0034747036633344473,0.31885225621467167,5.105088062083414,
        0.003474703663334446,0.31885225621467167,5.301437602932776,
        0.003474703663334442,0.31885225621467167,5.497787143782138,
        0.00347470366333444,0.31885225621467167,5.6941366846315,
        0.0034747036633344395,0.31885225621467167,5.890486225480862,
        0.0034747036633344442,0.31885225621467167,6.086835766330224,
        0.0034747036633344473,0.487066520140561,0.,0.00490166634184074,
        0.487066520140561,0.19634954084936207,0.004901666341840732,
        0.487066520140561,0.39269908169872414,0.004901666341840724,
        0.487066520140561,0.5890486225480862,0.004901666341840723,0.487066520140561,
        0.7853981633974483,0.004901666341840727,0.487066520140561,
        0.9817477042468103,0.00490166634184073,0.487066520140561,1.1780972450961724,
        0.004901666341840729,0.487066520140561,1.3744467859455345,
        0.004901666341840725,0.487066520140561,1.5707963267948966,
        0.004901666341840721,0.487066520140561,1.7671458676442586,
        0.004901666341840725,0.487066520140561,1.9634954084936207,
        0.004901666341840731,0.487066520140561,2.1598449493429825,
        0.00490166634184074,0.487066520140561,2.356194490192345,
        0.004901666341840735,0.487066520140561,2.552544031041707,
        0.00490166634184072,0.487066520140561,2.748893571891069,
        0.004901666341840719,0.487066520140561,2.945243112740431,
        0.0049016663418407335,0.487066520140561,3.141592653589793,
        0.00490166634184074,0.487066520140561,3.3379421944391554,
        0.004901666341840726,0.487066520140561,3.5342917352885173,
        0.004901666341840715,0.487066520140561,3.730641276137879,
        0.004901666341840726,0.487066520140561,3.9269908169872414,
        0.004901666341840734,0.487066520140561,4.123340357836604,
        0.004901666341840731,0.487066520140561,4.319689898685965,
        0.004901666341840723,0.487066520140561,4.516039439535327,
        0.004901666341840727,0.487066520140561,4.71238898038469,
        0.004901666341840734,0.487066520140561,4.908738521234052,
        0.004901666341840729,0.487066520140561,5.105088062083414,
        0.004901666341840723,0.487066520140561,5.301437602932776,
        0.004901666341840723,0.487066520140561,5.497787143782138,
        0.004901666341840723,0.487066520140561,5.6941366846315,
        0.0049016663418407205,0.487066520140561,5.890486225480862,
        0.004901666341840722,0.487066520140561,6.086835766330224,
        0.004901666341840734,0.6389700139694936,0.,0.005666934115288891,
        0.6389700139694936,0.19634954084936207,0.005666934115288875,
        0.6389700139694936,0.39269908169872414,0.005666934115288877,
        0.6389700139694936,0.5890486225480862,0.005666934115288877,
        0.6389700139694936,0.7853981633974483,0.005666934115288871,
        0.6389700139694936,0.9817477042468103,0.00566693411528888,
        0.6389700139694936,1.1780972450961724,0.005666934115288881,
        0.6389700139694936,1.3744467859455345,0.00566693411528887,
        0.6389700139694936,1.5707963267948966,0.00566693411528887,
        0.6389700139694936,1.7671458676442586,0.0056669341152888715,
        0.6389700139694936,1.9634954084936207,0.005666934115288871,
        0.6389700139694936,2.1598449493429825,0.005666934115288883,
        0.6389700139694936,2.356194490192345,0.005666934115288885,
        0.6389700139694936,2.552544031041707,0.005666934115288865,
        0.6389700139694936,2.748893571891069,0.005666934115288856,
        0.6389700139694936,2.945243112740431,0.005666934115288881,
        0.6389700139694936,3.141592653589793,0.005666934115288894,
        0.6389700139694936,3.3379421944391554,0.005666934115288869,
        0.6389700139694936,3.5342917352885173,0.005666934115288851,
        0.6389700139694936,3.730641276137879,0.005666934115288872,
        0.6389700139694936,3.9269908169872414,0.005666934115288887,
        0.6389700139694936,4.123340357836604,0.005666934115288871,
        0.6389700139694936,4.319689898685965,0.005666934115288863,
        0.6389700139694936,4.516039439535327,0.005666934115288873,
        0.6389700139694936,4.71238898038469,0.0056669341152888845,
        0.6389700139694936,4.908738521234052,0.005666934115288884,
        0.6389700139694936,5.105088062083414,0.005666934115288864,
        0.6389700139694936,5.301437602932776,0.005666934115288867,
        0.6389700139694936,5.497787143782138,0.005666934115288884,
        0.6389700139694936,5.6941366846315,0.005666934115288866,0.6389700139694936,
        5.890486225480862,0.005666934115288865,0.6389700139694936,6.086835766330224,
        0.0056669341152888915,0.7692316434259743,0.,0.005666934115284598,
        0.7692316434259743,0.19634954084936207,0.0056669341152845755,
        0.7692316434259743,0.39269908169872414,0.00566693411528459,
        0.7692316434259743,0.5890486225480862,0.005666934115284583,
        0.7692316434259743,0.7853981633974483,0.005666934115284572,
        0.7692316434259743,0.9817477042468103,0.005666934115284594,
        0.7692316434259743,1.1780972450961724,0.005666934115284591,
        0.7692316434259743,1.3744467859455345,0.005666934115284575,
        0.7692316434259743,1.5707963267948966,0.005666934115284582,
        0.7692316434259743,1.7671458676442586,0.0056669341152845885,
        0.7692316434259743,1.9634954084936207,0.005666934115284582,
        0.7692316434259743,2.1598449493429825,0.005666934115284595,
        0.7692316434259743,2.356194490192345,0.005666934115284599,
        0.7692316434259743,2.552544031041707,0.005666934115284575,
        0.7692316434259743,2.748893571891069,0.0056669341152845686,
        0.7692316434259743,2.945243112740431,0.005666934115284586,
        0.7692316434259743,3.141592653589793,0.005666934115284596,
        0.7692316434259743,3.3379421944391554,0.0056669341152845824,
        0.7692316434259743,3.5342917352885173,0.00566693411528456,
        0.7692316434259743,3.730641276137879,0.005666934115284582,
        0.7692316434259743,3.9269908169872414,0.005666934115284601,
        0.7692316434259743,4.123340357836604,0.005666934115284573,
        0.7692316434259743,4.319689898685965,0.005666934115284581,
        0.7692316434259743,4.516039439535327,0.0056669341152845885,
        0.7692316434259743,4.71238898038469,0.005666934115284582,0.7692316434259743,
        4.908738521234052,0.005666934115284602,0.7692316434259743,5.105088062083414,
        0.005666934115284576,0.7692316434259743,5.301437602932776,
        0.005666934115284568,0.7692316434259743,5.497787143782138,
        0.005666934115284601,0.7692316434259743,5.6941366846315,
        0.0056669341152845686,0.7692316434259743,5.890486225480862,
        0.0056669341152845686,0.7692316434259743,6.086835766330224,
        0.0056669341152846085,0.8733648750425932,0.,0.0049016663418440095,
        0.8733648750425932,0.19634954084936207,0.004901666341843991,
        0.8733648750425932,0.39269908169872414,0.004901666341844005,
        0.8733648750425932,0.5890486225480862,0.004901666341843995,
        0.8733648750425932,0.7853981633974483,0.004901666341843988,
        0.8733648750425932,0.9817477042468103,0.004901666341844009,
        0.8733648750425932,1.1780972450961724,0.004901666341843997,
        0.8733648750425932,1.3744467859455345,0.004901666341843989,
        0.8733648750425932,1.5707963267948966,0.0049016663418439965,
        0.8733648750425932,1.7671458676442586,0.004901666341843987,
        0.8733648750425932,1.9634954084936207,0.004901666341843988,
        0.8733648750425932,2.1598449493429825,0.004901666341844002,
        0.8733648750425932,2.356194490192345,0.004901666341844002,
        0.8733648750425932,2.552544031041707,0.0049016663418439774,
        0.8733648750425932,2.748893571891069,0.00490166634184398,0.8733648750425932,
        2.945243112740431,0.004901666341843994,0.8733648750425932,3.141592653589793,
        0.004901666341844,0.8733648750425932,3.3379421944391554,
        0.004901666341843995,0.8733648750425932,3.5342917352885173,
        0.004901666341843967,0.8733648750425932,3.730641276137879,
        0.004901666341843988,0.8733648750425932,3.9269908169872414,
        0.004901666341844011,0.8733648750425932,4.123340357836604,
        0.00490166634184398,0.8733648750425932,4.319689898685965,
        0.004901666341843985,0.8733648750425932,4.516039439535327,
        0.004901666341844004,0.8733648750425932,4.71238898038469,
        0.004901666341843985,0.8733648750425932,4.908738521234052,
        0.004901666341844014,0.8733648750425932,5.105088062083414,
        0.00490166634184399,0.8733648750425932,5.301437602932776,
        0.004901666341843979,0.8733648750425932,5.497787143782138,
        0.004901666341844014,0.8733648750425932,5.6941366846315,
        0.0049016663418439835,0.8733648750425932,5.890486225480862,
        0.004901666341843984,0.8733648750425932,6.086835766330224,
        0.004901666341844017,0.9478044306220632,0.,0.0034747036633327325,
        0.9478044306220632,0.19634954084936207,0.003474703663332712,
        0.9478044306220632,0.39269908169872414,0.0034747036633327234,
        0.9478044306220632,0.5890486225480862,0.003474703663332719,
        0.9478044306220632,0.7853981633974483,0.0034747036633327112,
        0.9478044306220632,0.9817477042468103,0.0034747036633327255,
        0.9478044306220632,1.1780972450961724,0.003474703663332721,
        0.9478044306220632,1.3744467859455345,0.003474703663332712,
        0.9478044306220632,1.5707963267948966,0.0034747036633327195,
        0.9478044306220632,1.7671458676442586,0.003474703663332717,
        0.9478044306220632,1.9634954084936207,0.003474703663332723,
        0.9478044306220632,2.1598449493429825,0.003474703663332724,
        0.9478044306220632,2.356194490192345,0.0034747036633327303,
        0.9478044306220632,2.552544031041707,0.003474703663332717,
        0.9478044306220632,2.748893571891069,0.00347470366333271,0.9478044306220632,
        2.945243112740431,0.0034747036633327273,0.9478044306220632,
        3.141592653589793,0.003474703663332729,0.9478044306220632,
        3.3379421944391554,0.0034747036633327255,0.9478044306220632,
        3.5342917352885173,0.003474703663332707,0.9478044306220632,
        3.730641276137879,0.0034747036633327247,0.9478044306220632,
        3.9269908169872414,0.0034747036633327294,0.9478044306220632,
        4.123340357836604,0.0034747036633327208,0.9478044306220632,
        4.319689898685965,0.0034747036633327147,0.9478044306220632,
        4.516039439535327,0.003474703663332729,0.9478044306220632,4.71238898038469,
        0.003474703663332718,0.9478044306220632,4.908738521234052,
        0.0034747036633327347,0.9478044306220632,5.105088062083414,
        0.003474703663332712,0.9478044306220632,5.301437602932776,
        0.003474703663332712,0.9478044306220632,5.497787143782138,
        0.0034747036633327303,0.9478044306220632,5.6941366846315,
        0.003474703663332707,0.9478044306220632,5.890486225480862,
        0.003474703663332718,0.9478044306220632,6.086835766330224,
        0.0034747036633327255,0.9900226907746954,0.,0.0015816958795375504,
        0.9900226907746954,0.19634954084936207,0.0015816958795375332,
        0.9900226907746954,0.39269908169872414,0.0015816958795375514,
        0.9900226907746954,0.5890486225480862,0.0015816958795375348,
        0.9900226907746954,0.7853981633974483,0.0015816958795375447,
        0.9900226907746954,0.9817477042468103,0.0015816958795375406,
        0.9900226907746954,1.1780972450961724,0.001581695879537547,
        0.9900226907746954,1.3744467859455345,0.0015816958795375352,
        0.9900226907746954,1.5707963267948966,0.001581695879537544,
        0.9900226907746954,1.7671458676442586,0.001581695879537536,
        0.9900226907746954,1.9634954084936207,0.0015816958795375426,
        0.9900226907746954,2.1598449493429825,0.0015816958795375436,
        0.9900226907746954,2.356194490192345,0.0015816958795375408,
        0.9900226907746954,2.552544031041707,0.0015816958795375363,
        0.9900226907746954,2.748893571891069,0.001581695879537533,
        0.9900226907746954,2.945243112740431,0.0015816958795375445,
        0.9900226907746954,3.141592653589793,0.0015816958795375367,
        0.9900226907746954,3.3379421944391554,0.0015816958795375445,
        0.9900226907746954,3.5342917352885173,0.0015816958795375259,
        0.9900226907746954,3.730641276137879,0.001581695879537541,
        0.9900226907746954,3.9269908169872414,0.0015816958795375395,
        0.9900226907746954,4.123340357836604,0.0015816958795375423,
        0.9900226907746954,4.319689898685965,0.0015816958795375321,
        0.9900226907746954,4.516039439535327,0.001581695879537548,
        0.9900226907746954,4.71238898038469,0.0015816958795375343,
        0.9900226907746954,4.908738521234052,0.0015816958795375484,
        0.9900226907746954,5.105088062083414,0.001581695879537535,
        0.9900226907746954,5.301437602932776,0.0015816958795375354,
        0.9900226907746954,5.497787143782138,0.0015816958795375465,
        0.9900226907746954,5.6941366846315,0.0015816958795375365,0.9900226907746954,
        5.890486225480862,0.0015816958795375384,0.9900226907746954,
        6.086835766330224,0.0015816958795375445,0.,0.,0.01234567901243055,
        0.21126749700313546,0.,0.0021713826330281875,0.21126749700313546,
        0.18479956785822313,0.0021713826330281598,0.21126749700313546,
        0.36959913571644626,0.0021713826330281905,0.21126749700313546,
        0.5543987035746694,0.002171382633028185,0.21126749700313546,
        0.7391982714328925,0.0021713826330281858,0.21126749700313546,
        0.9239978392911157,0.002171382633028183,0.21126749700313546,
        1.1087974071493387,0.002171382633028182,0.21126749700313546,
        1.2935969750075618,0.002171382633028182,0.21126749700313546,
        1.478396542865785,0.002171382633028181,0.21126749700313546,
        1.663196110724008,0.0021713826330281836,0.21126749700313546,
        1.8479956785822313,0.0021713826330281836,0.21126749700313546,
        2.0327952464404544,0.0021713826330281806,0.21126749700313546,
        2.2175948142986774,0.002171382633028184,0.21126749700313546,
        2.4023943821569005,0.0021713826330281823,0.21126749700313546,
        2.5871939500151235,0.0021713826330281836,0.21126749700313546,
        2.7719935178733466,0.0021713826330281845,0.21126749700313546,
        2.95679308573157,0.0021713826330281866,0.21126749700313546,
        3.141592653589793,0.0021713826330281853,0.21126749700313546,
        3.326392221448016,0.0021713826330281866,0.21126749700313546,
        3.5111917893062397,0.002171382633028186,0.21126749700313546,
        3.6959913571644627,0.002171382633028186,0.21126749700313546,
        3.8807909250226857,0.002171382633028184,0.21126749700313546,
        4.065590492880909,0.002171382633028185,0.21126749700313546,
        4.250390060739132,0.002171382633028184,0.21126749700313546,
        4.435189628597355,0.0021713826330281827,0.21126749700313546,
        4.619989196455578,0.002171382633028181,0.21126749700313546,
        4.804788764313801,0.0021713826330281814,0.21126749700313546,
        4.9895883321720245,0.0021713826330281806,0.21126749700313546,
        5.174387900030247,0.0021713826330281827,0.21126749700313546,
        5.359187467888471,0.0021713826330281827,0.21126749700313546,
        5.543987035746693,0.0021713826330281858,0.21126749700313546,
        5.728786603604917,0.0021713826330281866,0.21126749700313546,
        5.91358617146314,0.002171382633028188,0.21126749700313546,6.098385739321363,
        0.002171382633028188,0.3799555987772065,0.,0.0036351379147799606,
        0.3799555987772065,0.18479956785822313,0.003635137914779959,
        0.3799555987772065,0.36959913571644626,0.0036351379147799585,
        0.3799555987772065,0.5543987035746694,0.003635137914779957,
        0.3799555987772065,0.7391982714328925,0.003635137914779957,
        0.3799555987772065,0.9239978392911157,0.0036351379147799563,
        0.3799555987772065,1.1087974071493387,0.003635137914779955,
        0.3799555987772065,1.2935969750075618,0.003635137914779957,
        0.3799555987772065,1.478396542865785,0.0036351379147799585,
        0.3799555987772065,1.663196110724008,0.0036351379147799598,
        0.3799555987772065,1.8479956785822313,0.003635137914779958,
        0.3799555987772065,2.0327952464404544,0.003635137914779956,
        0.3799555987772065,2.2175948142986774,0.003635137914779955,
        0.3799555987772065,2.4023943821569005,0.0036351379147799537,
        0.3799555987772065,2.5871939500151235,0.003635137914779956,
        0.3799555987772065,2.7719935178733466,0.0036351379147799593,
        0.3799555987772065,2.95679308573157,0.0036351379147799615,
        0.3799555987772065,3.141592653589793,0.0036351379147799606,
        0.3799555987772065,3.326392221448016,0.003635137914779962,
        0.3799555987772065,3.5111917893062397,0.00363513791477996,
        0.3799555987772065,3.6959913571644627,0.00363513791477996,
        0.3799555987772065,3.8807909250226857,0.0036351379147799585,
        0.3799555987772065,4.065590492880909,0.003635137914779958,
        0.3799555987772065,4.250390060739132,0.0036351379147799576,
        0.3799555987772065,4.435189628597355,0.0036351379147799563,
        0.3799555987772065,4.619989196455578,0.003635137914779956,
        0.3799555987772065,4.804788764313801,0.003635137914779957,
        0.3799555987772065,4.9895883321720245,0.0036351379147799554,
        0.3799555987772065,5.174387900030247,0.003635137914779955,
        0.3799555987772065,5.359187467888471,0.0036351379147799567,
        0.3799555987772065,5.543987035746693,0.0036351379147799598,
        0.3799555987772065,5.728786603604917,0.0036351379147799624,
        0.3799555987772065,5.91358617146314,0.0036351379147799624,
        0.3799555987772065,6.098385739321363,0.003635137914779961,
        0.5355602273735705,0.,0.004659467289265113,0.5355602273735705,
        0.18479956785822313,0.004659467289265108,0.5355602273735705,
        0.36959913571644626,0.004659467289265106,0.5355602273735705,
        0.5543987035746694,0.00465946728926511,0.5355602273735705,
        0.7391982714328925,0.0046594672892651115,0.5355602273735705,
        0.9239978392911157,0.004659467289265108,0.5355602273735705,
        1.1087974071493387,0.00465946728926511,0.5355602273735705,
        1.2935969750075618,0.004659467289265111,0.5355602273735705,
        1.478396542865785,0.004659467289265109,0.5355602273735705,1.663196110724008,
        0.0046594672892651115,0.5355602273735705,1.8479956785822313,
        0.004659467289265112,0.5355602273735705,2.0327952464404544,
        0.0046594672892651115,0.5355602273735705,2.2175948142986774,
        0.004659467289265104,0.5355602273735705,2.4023943821569005,
        0.004659467289265101,0.5355602273735705,2.5871939500151235,
        0.004659467289265106,0.5355602273735705,2.7719935178733466,
        0.004659467289265115,0.5355602273735705,2.95679308573157,
        0.004659467289265107,0.5355602273735705,3.141592653589793,
        0.004659467289265106,0.5355602273735705,3.326392221448016,
        0.004659467289265112,0.5355602273735705,3.5111917893062397,
        0.004659467289265111,0.5355602273735705,3.6959913571644627,
        0.004659467289265105,0.5355602273735705,3.8807909250226857,
        0.004659467289265106,0.5355602273735705,4.065590492880909,
        0.0046594672892651115,0.5355602273735705,4.250390060739132,
        0.004659467289265107,0.5355602273735705,4.435189628597355,
        0.004659467289265104,0.5355602273735705,4.619989196455578,
        0.004659467289265109,0.5355602273735705,4.804788764313801,
        0.004659467289265112,0.5355602273735705,4.9895883321720245,
        0.004659467289265105,0.5355602273735705,5.174387900030247,
        0.004659467289265103,0.5355602273735705,5.359187467888471,
        0.004659467289265107,0.5355602273735705,5.543987035746693,
        0.004659467289265114,0.5355602273735705,5.728786603604917,
        0.004659467289265113,0.5355602273735705,5.91358617146314,
        0.004659467289265109,0.5355602273735705,6.098385739321363,
        0.004659467289265111,0.6743984839815207,0.,0.0051216618054894855,
        0.6743984839815207,0.18479956785822313,0.005121661805489471,
        0.6743984839815207,0.36959913571644626,0.0051216618054894724,
        0.6743984839815207,0.5543987035746694,0.005121661805489483,
        0.6743984839815207,0.7391982714328925,0.005121661805489478,
        0.6743984839815207,0.9239978392911157,0.005121661805489473,
        0.6743984839815207,1.1087974071493387,0.0051216618054894785,
        0.6743984839815207,1.2935969750075618,0.005121661805489482,
        0.6743984839815207,1.478396542865785,0.005121661805489475,
        0.6743984839815207,1.663196110724008,0.005121661805489477,
        0.6743984839815207,1.8479956785822313,0.005121661805489485,
        0.6743984839815207,2.0327952464404544,0.005121661805489478,
        0.6743984839815207,2.2175948142986774,0.005121661805489474,
        0.6743984839815207,2.4023943821569005,0.005121661805489469,
        0.6743984839815207,2.5871939500151235,0.005121661805489473,
        0.6743984839815207,2.7719935178733466,0.005121661805489487,
        0.6743984839815207,2.95679308573157,0.005121661805489479,0.6743984839815207,
        3.141592653589793,0.00512166180548947,0.6743984839815207,3.326392221448016,
        0.005121661805489488,0.6743984839815207,3.5111917893062397,
        0.005121661805489486,0.6743984839815207,3.6959913571644627,
        0.005121661805489468,0.6743984839815207,3.8807909250226857,
        0.005121661805489479,0.6743984839815207,4.065590492880909,
        0.005121661805489489,0.6743984839815207,4.250390060739132,
        0.00512166180548947,0.6743984839815207,4.435189628597355,
        0.005121661805489469,0.6743984839815207,4.619989196455578,
        0.005121661805489478,0.6743984839815207,4.804788764313801,
        0.005121661805489478,0.6743984839815207,4.9895883321720245,
        0.0051216618054894724,0.6743984839815207,5.174387900030247,
        0.00512166180548947,0.6743984839815207,5.359187467888471,
        0.005121661805489477,0.6743984839815207,5.543987035746693,
        0.005121661805489484,0.6743984839815207,5.728786603604917,
        0.0051216618054894855,0.6743984839815207,5.91358617146314,
        0.005121661805489473,0.6743984839815207,6.098385739321363,
        0.005121661805489481,0.7925073093774768,0.,0.004966087749642826,
        0.7925073093774768,0.18479956785822313,0.004966087749642808,
        0.7925073093774768,0.36959913571644626,0.004966087749642817,
        0.7925073093774768,0.5543987035746694,0.004966087749642818,
        0.7925073093774768,0.7391982714328925,0.004966087749642813,
        0.7925073093774768,0.9239978392911157,0.004966087749642809,
        0.7925073093774768,1.1087974071493387,0.004966087749642814,
        0.7925073093774768,1.2935969750075618,0.004966087749642814,
        0.7925073093774768,1.478396542865785,0.004966087749642807,
        0.7925073093774768,1.663196110724008,0.004966087749642816,
        0.7925073093774768,1.8479956785822313,0.004966087749642817,
        0.7925073093774768,2.0327952464404544,0.004966087749642806,
        0.7925073093774768,2.2175948142986774,0.004966087749642808,
        0.7925073093774768,2.4023943821569005,0.00496608774964281,
        0.7925073093774768,2.5871939500151235,0.004966087749642799,
        0.7925073093774768,2.7719935178733466,0.004966087749642822,
        0.7925073093774768,2.95679308573157,0.004966087749642823,0.7925073093774768,
        3.141592653589793,0.004966087749642798,0.7925073093774768,3.326392221448016,
        0.0049660877496428245,0.7925073093774768,3.5111917893062397,
        0.004966087749642824,0.7925073093774768,3.6959913571644627,
        0.004966087749642795,0.7925073093774768,3.8807909250226857,
        0.0049660877496428175,0.7925073093774768,4.065590492880909,
        0.004966087749642824,0.7925073093774768,4.250390060739132,
        0.004966087749642801,0.7925073093774768,4.435189628597355,
        0.00496608774964281,0.7925073093774768,4.619989196455578,
        0.004966087749642812,0.7925073093774768,4.804788764313801,
        0.004966087749642811,0.7925073093774768,4.9895883321720245,
        0.004966087749642809,0.7925073093774768,5.174387900030247,
        0.004966087749642807,0.7925073093774768,5.359187467888471,
        0.004966087749642811,0.7925073093774768,5.543987035746693,
        0.004966087749642815,0.7925073093774768,5.728786603604917,
        0.004966087749642827,0.7925073093774768,5.91358617146314,
        0.0049660877496428115,0.7925073093774768,6.098385739321363,
        0.0049660877496428175,0.8863924190810576,0.,0.004211569064078794,
        0.8863924190810576,0.18479956785822313,0.004211569064078773,
        0.8863924190810576,0.36959913571644626,0.0042115690640787936,
        0.8863924190810576,0.5543987035746694,0.004211569064078779,
        0.8863924190810576,0.7391982714328925,0.004211569064078791,
        0.8863924190810576,0.9239978392911157,0.004211569064078781,
        0.8863924190810576,1.1087974071493387,0.004211569064078783,
        0.8863924190810576,1.2935969750075618,0.004211569064078794,
        0.8863924190810576,1.478396542865785,0.0042115690640787806,
        0.8863924190810576,1.663196110724008,0.004211569064078789,
        0.8863924190810576,1.8479956785822313,0.0042115690640787875,
        0.8863924190810576,2.0327952464404544,0.00421156906407879,
        0.8863924190810576,2.2175948142986774,0.004211569064078776,
        0.8863924190810576,2.4023943821569005,0.004211569064078784,
        0.8863924190810576,2.5871939500151235,0.004211569064078775,
        0.8863924190810576,2.7719935178733466,0.004211569064078789,
        0.8863924190810576,2.95679308573157,0.004211569064078789,0.8863924190810576,
        3.141592653589793,0.00421156906407877,0.8863924190810576,3.326392221448016,
        0.004211569064078794,0.8863924190810576,3.5111917893062397,
        0.004211569064078788,0.8863924190810576,3.6959913571644627,
        0.004211569064078771,0.8863924190810576,3.8807909250226857,
        0.004211569064078785,0.8863924190810576,4.065590492880909,
        0.004211569064078795,0.8863924190810576,4.250390060739132,
        0.004211569064078772,0.8863924190810576,4.435189628597355,
        0.004211569064078787,0.8863924190810576,4.619989196455578,
        0.004211569064078779,0.8863924190810576,4.804788764313801,
        0.0042115690640787875,0.8863924190810576,4.9895883321720245,
        0.004211569064078787,0.8863924190810576,5.174387900030247,
        0.004211569064078772,0.8863924190810576,5.359187467888471,
        0.004211569064078793,0.8863924190810576,5.543987035746693,
        0.0042115690640787806,0.8863924190810576,5.728786603604917,
        0.004211569064078801,0.8863924190810576,5.91358617146314,
        0.004211569064078776,0.8863924190810576,6.098385739321363,
        0.004211569064078791,0.9532451899171619,0.,0.00294931320624264,
        0.9532451899171619,0.18479956785822313,0.0029493132062426227,
        0.9532451899171619,0.36959913571644626,0.002949313206242641,
        0.9532451899171619,0.5543987035746694,0.002949313206242625,
        0.9532451899171619,0.7391982714328925,0.0029493132062426396,
        0.9532451899171619,0.9239978392911157,0.0029493132062426257,
        0.9532451899171619,1.1087974071493387,0.0029493132062426344,
        0.9532451899171619,1.2935969750075618,0.0029493132062426383,
        0.9532451899171619,1.478396542865785,0.0029493132062426266,
        0.9532451899171619,1.663196110724008,0.0029493132062426387,
        0.9532451899171619,1.8479956785822313,0.002949313206242632,
        0.9532451899171619,2.0327952464404544,0.0029493132062426335,
        0.9532451899171619,2.2175948142986774,0.002949313206242631,
        0.9532451899171619,2.4023943821569005,0.0029493132062426274,
        0.9532451899171619,2.5871939500151235,0.00294931320624263,
        0.9532451899171619,2.7719935178733466,0.0029493132062426357,
        0.9532451899171619,2.95679308573157,0.0029493132062426396,
        0.9532451899171619,3.141592653589793,0.002949313206242621,
        0.9532451899171619,3.326392221448016,0.0029493132062426396,
        0.9532451899171619,3.5111917893062397,0.002949313206242635,
        0.9532451899171619,3.6959913571644627,0.0029493132062426283,
        0.9532451899171619,3.8807909250226857,0.002949313206242626,
        0.9532451899171619,4.065590492880909,0.002949313206242646,
        0.9532451899171619,4.250390060739132,0.0029493132062426183,
        0.9532451899171619,4.435189628597355,0.002949313206242636,
        0.9532451899171619,4.619989196455578,0.0029493132062426274,
        0.9532451899171619,4.804788764313801,0.0029493132062426335,
        0.9532451899171619,4.9895883321720245,0.0029493132062426313,
        0.9532451899171619,5.174387900030247,0.0029493132062426183,
        0.9532451899171619,5.359187467888471,0.0029493132062426417,
        0.9532451899171619,5.543987035746693,0.0029493132062426214,
        0.9532451899171619,5.728786603604917,0.0029493132062426487,
        0.9532451899171619,5.91358617146314,0.0029493132062426222,
        0.9532451899171619,6.098385739321363,0.0029493132062426365,
        0.9910701715078688,0.,0.0013340368371073871,0.9910701715078688,
        0.18479956785822313,0.0013340368371073943,0.9910701715078688,
        0.36959913571644626,0.0013340368371073873,0.9910701715078688,
        0.5543987035746694,0.001334036837107395,0.9910701715078688,
        0.7391982714328925,0.0013340368371073893,0.9910701715078688,
        0.9239978392911157,0.001334036837107394,0.9910701715078688,
        1.1087974071493387,0.00133403683710739,0.9910701715078688,
        1.2935969750075618,0.001334036837107395,0.9910701715078688,
        1.478396542865785,0.0013340368371073902,0.9910701715078688,
        1.663196110724008,0.0013340368371073917,0.9910701715078688,
        1.8479956785822313,0.0013340368371073945,0.9910701715078688,
        2.0327952464404544,0.0013340368371073884,0.9910701715078688,
        2.2175948142986774,0.0013340368371073939,0.9910701715078688,
        2.4023943821569005,0.0013340368371073852,0.9910701715078688,
        2.5871939500151235,0.0013340368371073917,0.9910701715078688,
        2.7719935178733466,0.0013340368371073889,0.9910701715078688,
        2.95679308573157,0.0013340368371073982,0.9910701715078688,3.141592653589793,
        0.0013340368371073817,0.9910701715078688,3.326392221448016,
        0.0013340368371073982,0.9910701715078688,3.5111917893062397,
        0.0013340368371073886,0.9910701715078688,3.6959913571644627,
        0.0013340368371073902,0.9910701715078688,3.8807909250226857,
        0.0013340368371073889,0.9910701715078688,4.065590492880909,
        0.0013340368371073965,0.9910701715078688,4.250390060739132,
        0.0013340368371073889,0.9910701715078688,4.435189628597355,
        0.0013340368371073904,0.9910701715078688,4.619989196455578,
        0.0013340368371073932,0.9910701715078688,4.804788764313801,
        0.0013340368371073921,0.9910701715078688,4.9895883321720245,
        0.0013340368371073962,0.9910701715078688,5.174387900030247,
        0.0013340368371073856,0.9910701715078688,5.359187467888471,
        0.0013340368371073967,0.9910701715078688,5.543987035746693,
        0.001334036837107388,0.9910701715078688,5.728786603604917,
        0.0013340368371074008,0.9910701715078688,5.91358617146314,
        0.0013340368371073852,0.9910701715078688,6.098385739321363,
        0.0013340368371073967,0.12617400780742027,0.,0.0011288109494654252,
        0.12617400780742027,0.17453292519943295,0.0011288109494654358,
        0.12617400780742027,0.3490658503988659,0.0011288109494654328,
        0.12617400780742027,0.5235987755982988,0.0011288109494654336,
        0.12617400780742027,0.6981317007977318,0.0011288109494654332,
        0.12617400780742027,0.8726646259971648,0.001128810949465434,
        0.12617400780742027,1.0471975511965976,0.0011288109494654334,
        0.12617400780742027,1.2217304763960306,0.0011288109494654343,
        0.12617400780742027,1.3962634015954636,0.0011288109494654345,
        0.12617400780742027,1.5707963267948966,0.0011288109494654336,
        0.12617400780742027,1.7453292519943295,0.001128810949465434,
        0.12617400780742027,1.9198621771937625,0.0011288109494654334,
        0.12617400780742027,2.0943951023931953,0.0011288109494654332,
        0.12617400780742027,2.2689280275926285,0.0011288109494654328,
        0.12617400780742027,2.443460952792061,0.0011288109494654325,
        0.12617400780742027,2.6179938779914944,0.0011288109494654317,
        0.12617400780742027,2.792526803190927,0.0011288109494654325,
        0.12617400780742027,2.96705972839036,0.0011288109494654328,
        0.12617400780742027,3.141592653589793,0.0011288109494654336,
        0.12617400780742027,3.3161255787892263,0.001128810949465434,
        0.12617400780742027,3.490658503988659,0.001128810949465433,
        0.12617400780742027,3.6651914291880923,0.001128810949465434,
        0.12617400780742027,3.839724354387525,0.0011288109494654347,
        0.12617400780742027,4.014257279586958,0.0011288109494654323,
        0.12617400780742027,4.1887902047863905,0.001128810949465435,
        0.12617400780742027,4.363323129985823,0.0011288109494654338,
        0.12617400780742027,4.537856055185257,0.0011288109494654332,
        0.12617400780742027,4.71238898038469,0.0011288109494654343,
        0.12617400780742027,4.886921905584122,0.0011288109494654345,
        0.12617400780742027,5.061454830783556,0.0011288109494654338,
        0.12617400780742027,5.235987755982989,0.001128810949465434,
        0.12617400780742027,5.410520681182422,0.001128810949465434,
        0.12617400780742027,5.585053606381854,0.001128810949465433,
        0.12617400780742027,5.759586531581287,0.0011288109494654338,
        0.12617400780742027,5.93411945678072,0.0011288109494654317,
        0.12617400780742027,6.1086523819801535,0.0011288109494654332,
        0.286329262103408,0.,0.0025090022318760953,0.286329262103408,
        0.17453292519943295,0.0025090022318760945,0.286329262103408,
        0.3490658503988659,0.0025090022318760923,0.286329262103408,
        0.5235987755982988,0.0025090022318760923,0.286329262103408,
        0.6981317007977318,0.002509002231876092,0.286329262103408,
        0.8726646259971648,0.002509002231876093,0.286329262103408,
        1.0471975511965976,0.002509002231876094,0.286329262103408,
        1.2217304763960306,0.002509002231876095,0.286329262103408,
        1.3962634015954636,0.002509002231876096,0.286329262103408,
        1.5707963267948966,0.002509002231876097,0.286329262103408,
        1.7453292519943295,0.0025090022318760966,0.286329262103408,
        1.9198621771937625,0.0025090022318760958,0.286329262103408,
        2.0943951023931953,0.0025090022318760953,0.286329262103408,
        2.2689280275926285,0.0025090022318760945,0.286329262103408,
        2.443460952792061,0.0025090022318760945,0.286329262103408,
        2.6179938779914944,0.0025090022318760945,0.286329262103408,
        2.792526803190927,0.002509002231876096,0.286329262103408,2.96705972839036,
        0.002509002231876098,0.286329262103408,3.141592653589793,
        0.0025090022318760992,0.286329262103408,3.3161255787892263,
        0.0025090022318760984,0.286329262103408,3.490658503988659,
        0.0025090022318760975,0.286329262103408,3.6651914291880923,
        0.0025090022318760958,0.286329262103408,3.839724354387525,
        0.002509002231876094,0.286329262103408,4.014257279586958,
        0.0025090022318760945,0.286329262103408,4.1887902047863905,
        0.002509002231876095,0.286329262103408,4.363323129985823,
        0.0025090022318760958,0.286329262103408,4.537856055185257,
        0.0025090022318760958,0.286329262103408,4.71238898038469,
        0.0025090022318760966,0.286329262103408,4.886921905584122,
        0.0025090022318760958,0.286329262103408,5.061454830783556,
        0.0025090022318760936,0.286329262103408,5.235987755982989,
        0.0025090022318760923,0.286329262103408,5.410520681182422,
        0.002509002231876091,0.286329262103408,5.585053606381854,
        0.0025090022318760927,0.286329262103408,5.759586531581287,
        0.0025090022318760936,0.286329262103408,5.93411945678072,
        0.0025090022318760953,0.286329262103408,6.1086523819801535,
        0.0025090022318760958,0.43967520245029146,0.,0.0036195930055909873,
        0.43967520245029146,0.17453292519943295,0.003619593005590982,
        0.43967520245029146,0.3490658503988659,0.0036195930055909816,
        0.43967520245029146,0.5235987755982988,0.003619593005590985,
        0.43967520245029146,0.6981317007977318,0.0036195930055909864,
        0.43967520245029146,0.8726646259971648,0.003619593005590986,
        0.43967520245029146,1.0471975511965976,0.0036195930055909833,
        0.43967520245029146,1.2217304763960306,0.003619593005590986,
        0.43967520245029146,1.3962634015954636,0.0036195930055909864,
        0.43967520245029146,1.5707963267948966,0.0036195930055909873,
        0.43967520245029146,1.7453292519943295,0.0036195930055909877,
        0.43967520245029146,1.9198621771937625,0.0036195930055909886,
        0.43967520245029146,2.0943951023931953,0.003619593005590989,
        0.43967520245029146,2.2689280275926285,0.00361959300559099,
        0.43967520245029146,2.443460952792061,0.0036195930055909877,
        0.43967520245029146,2.6179938779914944,0.003619593005590987,
        0.43967520245029146,2.792526803190927,0.0036195930055909855,
        0.43967520245029146,2.96705972839036,0.0036195930055909916,
        0.43967520245029146,3.141592653589793,0.003619593005590993,
        0.43967520245029146,3.3161255787892263,0.0036195930055909925,
        0.43967520245029146,3.490658503988659,0.0036195930055909916,
        0.43967520245029146,3.6651914291880923,0.0036195930055909894,
        0.43967520245029146,3.839724354387525,0.003619593005590987,
        0.43967520245029146,4.014257279586958,0.003619593005590985,
        0.43967520245029146,4.1887902047863905,0.0036195930055909877,
        0.43967520245029146,4.363323129985823,0.00361959300559099,
        0.43967520245029146,4.537856055185257,0.003619593005590988,
        0.43967520245029146,4.71238898038469,0.0036195930055909886,
        0.43967520245029146,4.886921905584122,0.0036195930055909894,
        0.43967520245029146,5.061454830783556,0.003619593005590989,
        0.43967520245029146,5.235987755982989,0.0036195930055909855,
        0.43967520245029146,5.410520681182422,0.0036195930055909803,
        0.43967520245029146,5.585053606381854,0.003619593005590981,
        0.43967520245029146,5.759586531581287,0.003619593005590986,
        0.43967520245029146,5.93411945678072,0.0036195930055909916,
        0.43967520245029146,6.1086523819801535,0.0036195930055909916,
        0.5812686885581362,0.,0.004338153847784765,0.5812686885581362,
        0.17453292519943295,0.004338153847784759,0.5812686885581362,
        0.3490658503988659,0.004338153847784762,0.5812686885581362,
        0.5235987755982988,0.004338153847784766,0.5812686885581362,
        0.6981317007977318,0.004338153847784766,0.5812686885581362,
        0.8726646259971648,0.004338153847784763,0.5812686885581362,
        1.0471975511965976,0.0043381538477847625,0.5812686885581362,
        1.2217304763960306,0.004338153847784764,0.5812686885581362,
        1.3962634015954636,0.004338153847784768,0.5812686885581362,
        1.5707963267948966,0.004338153847784768,0.5812686885581362,
        1.7453292519943295,0.004338153847784766,0.5812686885581362,
        1.9198621771937625,0.004338153847784766,0.5812686885581362,
        2.0943951023931953,0.004338153847784764,0.5812686885581362,
        2.2689280275926285,0.004338153847784762,0.5812686885581362,
        2.443460952792061,0.004338153847784764,0.5812686885581362,
        2.6179938779914944,0.004338153847784763,0.5812686885581362,
        2.792526803190927,0.00433815384778476,0.5812686885581362,2.96705972839036,
        0.004338153847784769,0.5812686885581362,3.141592653589793,
        0.004338153847784775,0.5812686885581362,3.3161255787892263,
        0.004338153847784769,0.5812686885581362,3.490658503988659,
        0.0043381538477847625,0.5812686885581362,3.6651914291880923,
        0.004338153847784768,0.5812686885581362,3.839724354387525,
        0.0043381538477847625,0.5812686885581362,4.014257279586958,
        0.004338153847784758,0.5812686885581362,4.1887902047863905,
        0.0043381538477847625,0.5812686885581362,4.363323129985823,
        0.004338153847784771,0.5812686885581362,4.537856055185257,
        0.004338153847784764,0.5812686885581362,4.71238898038469,
        0.0043381538477847564,0.5812686885581362,4.886921905584122,
        0.00433815384778477,0.5812686885581362,5.061454830783556,
        0.0043381538477847755,0.5812686885581362,5.235987755982989,
        0.004338153847784761,0.5812686885581362,5.410520681182422,
        0.004338153847784756,0.5812686885581362,5.585053606381854,
        0.004338153847784759,0.5812686885581362,5.759586531581287,
        0.0043381538477847625,0.5812686885581362,5.93411945678072,
        0.004338153847784774,0.5812686885581362,6.1086523819801535,
        0.004338153847784776,0.7071067811865476,0.,0.004586657708342867,
        0.7071067811865476,0.17453292519943295,0.004586657708342865,
        0.7071067811865476,0.3490658503988659,0.004586657708342871,
        0.7071067811865476,0.5235987755982988,0.004586657708342867,
        0.7071067811865476,0.6981317007977318,0.0045866577083428705,
        0.7071067811865476,0.8726646259971648,0.004586657708342873,
        0.7071067811865476,1.0471975511965976,0.00458665770834287,
        0.7071067811865476,1.2217304763960306,0.004586657708342869,
        0.7071067811865476,1.3962634015954636,0.004586657708342876,
        0.7071067811865476,1.5707963267948966,0.004586657708342876,
        0.7071067811865476,1.7453292519943295,0.004586657708342873,
        0.7071067811865476,1.9198621771937625,0.004586657708342876,
        0.7071067811865476,2.0943951023931953,0.004586657708342877,
        0.7071067811865476,2.2689280275926285,0.004586657708342871,
        0.7071067811865476,2.443460952792061,0.004586657708342875,
        0.7071067811865476,2.6179938779914944,0.0045866577083428775,
        0.7071067811865476,2.792526803190927,0.0045866577083428645,
        0.7071067811865476,2.96705972839036,0.004586657708342875,0.7071067811865476,
        3.141592653589793,0.0045866577083428905,0.7071067811865476,
        3.3161255787892263,0.004586657708342874,0.7071067811865476,
        3.490658503988659,0.004586657708342871,0.7071067811865476,
        3.6651914291880923,0.00458665770834288,0.7071067811865476,3.839724354387525,
        0.004586657708342876,0.7071067811865476,4.014257279586958,
        0.004586657708342867,0.7071067811865476,4.1887902047863905,
        0.004586657708342869,0.7071067811865476,4.363323129985823,
        0.004586657708342887,0.7071067811865476,4.537856055185257,
        0.004586657708342878,0.7071067811865476,4.71238898038469,
        0.004586657708342857,0.7071067811865476,4.886921905584122,
        0.004586657708342882,0.7071067811865476,5.061454830783556,
        0.004586657708342884,0.7071067811865476,5.235987755982989,
        0.0045866577083428575,0.7071067811865476,5.410520681182422,
        0.004586657708342868,0.7071067811865476,5.585053606381854,
        0.004586657708342873,0.7071067811865476,5.759586531581287,
        0.004586657708342864,0.7071067811865476,5.93411945678072,
        0.004586657708342882,0.7071067811865476,6.1086523819801535,
        0.004586657708342885,0.8137116883158951,0.,0.004338153847785623,
        0.8137116883158951,0.17453292519943295,0.004338153847785633,
        0.8137116883158951,0.3490658503988659,0.004338153847785629,
        0.8137116883158951,0.5235987755982988,0.004338153847785631,
        0.8137116883158951,0.6981317007977318,0.004338153847785635,
        0.8137116883158951,0.8726646259971648,0.004338153847785633,
        0.8137116883158951,1.0471975511965976,0.004338153847785634,
        0.8137116883158951,1.2217304763960306,0.004338153847785629,
        0.8137116883158951,1.3962634015954636,0.004338153847785638,
        0.8137116883158951,1.5707963267948966,0.004338153847785642,
        0.8137116883158951,1.7453292519943295,0.0043381538477856325,
        0.8137116883158951,1.9198621771937625,0.004338153847785634,
        0.8137116883158951,2.0943951023931953,0.004338153847785643,
        0.8137116883158951,2.2689280275926285,0.004338153847785632,
        0.8137116883158951,2.443460952792061,0.004338153847785634,
        0.8137116883158951,2.6179938779914944,0.004338153847785646,
        0.8137116883158951,2.792526803190927,0.004338153847785627,
        0.8137116883158951,2.96705972839036,0.0043381538477856385,
        0.8137116883158951,3.141592653589793,0.0043381538477856585,
        0.8137116883158951,3.3161255787892263,0.004338153847785636,
        0.8137116883158951,3.490658503988659,0.004338153847785642,
        0.8137116883158951,3.6651914291880923,0.004338153847785643,
        0.8137116883158951,3.839724354387525,0.004338153847785628,
        0.8137116883158951,4.014257279586958,0.004338153847785635,
        0.8137116883158951,4.1887902047863905,0.004338153847785626,
        0.8137116883158951,4.363323129985823,0.004338153847785643,
        0.8137116883158951,4.537856055185257,0.0043381538477856455,
        0.8137116883158951,4.71238898038469,0.0043381538477856125,
        0.8137116883158951,4.886921905584122,0.004338153847785649,
        0.8137116883158951,5.061454830783556,0.004338153847785648,
        0.8137116883158951,5.235987755982989,0.004338153847785617,
        0.8137116883158951,5.410520681182422,0.004338153847785633,
        0.8137116883158951,5.585053606381854,0.0043381538477856325,
        0.8137116883158951,5.759586531581287,0.004338153847785618,
        0.8137116883158951,5.93411945678072,0.004338153847785649,0.8137116883158951,
        6.1086523819801535,0.004338153847785648,0.8981568439589463,0.,
        0.0036195930055897326,0.8981568439589463,0.17453292519943295,
        0.00361959300558975,0.8981568439589463,0.3490658503988659,
        0.0036195930055897335,0.8981568439589463,0.5235987755982988,
        0.0036195930055897465,0.8981568439589463,0.6981317007977318,
        0.0036195930055897474,0.8981568439589463,0.8726646259971648,
        0.0036195930055897365,0.8981568439589463,1.0471975511965976,
        0.0036195930055897495,0.8981568439589463,1.2217304763960306,
        0.00361959300558974,0.8981568439589463,1.3962634015954636,
        0.0036195930055897487,0.8981568439589463,1.5707963267948966,
        0.0036195930055897495,0.8981568439589463,1.7453292519943295,
        0.003619593005589751,0.8981568439589463,1.9198621771937625,
        0.003619593005589745,0.8981568439589463,2.0943951023931953,
        0.0036195930055897526,0.8981568439589463,2.2689280275926285,
        0.003619593005589747,0.8981568439589463,2.443460952792061,
        0.0036195930055897435,0.8981568439589463,2.6179938779914944,
        0.003619593005589756,0.8981568439589463,2.792526803190927,
        0.0036195930055897348,0.8981568439589463,2.96705972839036,
        0.003619593005589748,0.8981568439589463,3.141592653589793,
        0.0036195930055897656,0.8981568439589463,3.3161255787892263,
        0.0036195930055897404,0.8981568439589463,3.490658503988659,
        0.0036195930055897517,0.8981568439589463,3.6651914291880923,
        0.0036195930055897578,0.8981568439589463,3.839724354387525,
        0.00361959300558974,0.8981568439589463,4.014257279586958,
        0.0036195930055897543,0.8981568439589463,4.1887902047863905,
        0.0036195930055897387,0.8981568439589463,4.363323129985823,
        0.0036195930055897578,0.8981568439589463,4.537856055185257,
        0.0036195930055897586,0.8981568439589463,4.71238898038469,
        0.0036195930055897304,0.8981568439589463,4.886921905584122,
        0.003619593005589759,0.8981568439589463,5.061454830783556,
        0.003619593005589754,0.8981568439589463,5.235987755982989,
        0.0036195930055897365,0.8981568439589463,5.410520681182422,
        0.00361959300558974,0.8981568439589463,5.585053606381854,
        0.0036195930055897465,0.8981568439589463,5.759586531581287,
        0.003619593005589732,0.8981568439589463,5.93411945678072,
        0.0036195930055897565,0.8981568439589463,6.1086523819801535,
        0.0036195930055897565,0.9581312820607194,0.,0.0025090022318770716,
        0.9581312820607194,0.17453292519943295,0.0025090022318770863,
        0.9581312820607194,0.3490658503988659,0.0025090022318770768,
        0.9581312820607194,0.5235987755982988,0.0025090022318770854,
        0.9581312820607194,0.6981317007977318,0.0025090022318770815,
        0.9581312820607194,0.8726646259971648,0.0025090022318770815,
        0.9581312820607194,1.0471975511965976,0.002509002231877086,
        0.9581312820607194,1.2217304763960306,0.002509002231877076,
        0.9581312820607194,1.3962634015954636,0.0025090022318770906,
        0.9581312820607194,1.5707963267948966,0.0025090022318770837,
        0.9581312820607194,1.7453292519943295,0.0025090022318770833,
        0.9581312820607194,1.9198621771937625,0.0025090022318770837,
        0.9581312820607194,2.0943951023931953,0.002509002231877085,
        0.9581312820607194,2.2689280275926285,0.0025090022318770833,
        0.9581312820607194,2.443460952792061,0.002509002231877081,
        0.9581312820607194,2.6179938779914944,0.002509002231877087,
        0.9581312820607194,2.792526803190927,0.002509002231877078,
        0.9581312820607194,2.96705972839036,0.0025090022318770824,
        0.9581312820607194,3.141592653589793,0.002509002231877094,
        0.9581312820607194,3.3161255787892263,0.0025090022318770824,
        0.9581312820607194,3.490658503988659,0.002509002231877082,
        0.9581312820607194,3.6651914291880923,0.002509002231877089,
        0.9581312820607194,3.839724354387525,0.002509002231877078,
        0.9581312820607194,4.014257279586958,0.0025090022318770837,
        0.9581312820607194,4.1887902047863905,0.002509002231877076,
        0.9581312820607194,4.363323129985823,0.0025090022318770924,
        0.9581312820607194,4.537856055185257,0.0025090022318770867,
        0.9581312820607194,4.71238898038469,0.0025090022318770716,
        0.9581312820607194,4.886921905584122,0.0025090022318770945,
        0.9581312820607194,5.061454830783556,0.0025090022318770846,
        0.9581312820607194,5.235987755982989,0.0025090022318770815,
        0.9581312820607194,5.410520681182422,0.002509002231877077,
        0.9581312820607194,5.585053606381854,0.0025090022318770863,
        0.9581312820607194,5.759586531581287,0.0025090022318770755,
        0.9581312820607194,5.93411945678072,0.0025090022318770867,
        0.9581312820607194,6.1086523819801535,0.0025090022318770967,
        0.9920081248426411,0.,0.0011288109494650691,0.9920081248426411,
        0.17453292519943295,0.001128810949465073,0.9920081248426411,
        0.3490658503988659,0.0011288109494650696,0.9920081248426411,
        0.5235987755982988,0.0011288109494650728,0.9920081248426411,
        0.6981317007977318,0.0011288109494650713,0.9920081248426411,
        0.8726646259971648,0.0011288109494650704,0.9920081248426411,
        1.0471975511965976,0.0011288109494650698,0.9920081248426411,
        1.2217304763960306,0.0011288109494650726,0.9920081248426411,
        1.3962634015954636,0.001128810949465071,0.9920081248426411,
        1.5707963267948966,0.0011288109494650754,0.9920081248426411,
        1.7453292519943295,0.0011288109494650722,0.9920081248426411,
        1.9198621771937625,0.0011288109494650709,0.9920081248426411,
        2.0943951023931953,0.0011288109494650732,0.9920081248426411,
        2.2689280275926285,0.001128810949465072,0.9920081248426411,
        2.443460952792061,0.0011288109494650722,0.9920081248426411,
        2.6179938779914944,0.0011288109494650756,0.9920081248426411,
        2.792526803190927,0.0011288109494650702,0.9920081248426411,2.96705972839036,
        0.0011288109494650748,0.9920081248426411,3.141592653589793,
        0.0011288109494650806,0.9920081248426411,3.3161255787892263,
        0.0011288109494650713,0.9920081248426411,3.490658503988659,
        0.0011288109494650758,0.9920081248426411,3.6651914291880923,
        0.0011288109494650728,0.9920081248426411,3.839724354387525,
        0.0011288109494650704,0.9920081248426411,4.014257279586958,
        0.001128810949465072,0.9920081248426411,4.1887902047863905,
        0.0011288109494650685,0.9920081248426411,4.363323129985823,
        0.0011288109494650713,0.9920081248426411,4.537856055185257,
        0.0011288109494650756,0.9920081248426411,4.71238898038469,
        0.0011288109494650657,0.9920081248426411,4.886921905584122,
        0.0011288109494650756,0.9920081248426411,5.061454830783556,
        0.001128810949465074,0.9920081248426411,5.235987755982989,
        0.0011288109494650676,0.9920081248426411,5.410520681182422,
        0.0011288109494650698,0.9920081248426411,5.585053606381854,
        0.0011288109494650704,0.9920081248426411,5.759586531581287,
        0.0011288109494650678,0.9920081248426411,5.93411945678072,
        0.0011288109494650758,0.9920081248426411,6.1086523819801535,
        0.0011288109494650758,0.,0.,0.00999999999981068,0.19041484417767818,0.,
        0.0015828509283983521,0.19041484417767818,0.16534698176788384,
        0.0015828509283983456,0.19041484417767818,0.3306939635357677,
        0.0015828509283983346,0.19041484417767818,0.4960409453036515,
        0.001582850928398341,0.19041484417767818,0.6613879270715354,
        0.001582850928398341,0.19041484417767818,0.8267349088394192,
        0.0015828509283983437,0.19041484417767818,0.992081890607303,
        0.0015828509283983452,0.19041484417767818,1.1574288723751869,
        0.001582850928398344,0.19041484417767818,1.3227758541430708,
        0.0015828509283983443,0.19041484417767818,1.4881228359109546,
        0.0015828509283983437,0.19041484417767818,1.6534698176788385,
        0.0015828509283983428,0.19041484417767818,1.8188167994467224,
        0.0015828509283983432,0.19041484417767818,1.984163781214606,
        0.0015828509283983422,0.19041484417767818,2.14951076298249,
        0.001582850928398341,0.19041484417767818,2.3148577447503738,
        0.001582850928398343,0.19041484417767818,2.4802047265182576,
        0.0015828509283983415,0.19041484417767818,2.6455517082861415,
        0.001582850928398343,0.19041484417767818,2.8108986900540254,
        0.001582850928398343,0.19041484417767818,2.9762456718219092,
        0.0015828509283983406,0.19041484417767818,3.141592653589793,
        0.0015828509283983413,0.19041484417767818,3.306939635357677,
        0.0015828509283983422,0.19041484417767818,3.4722866171255613,
        0.0015828509283983409,0.19041484417767818,3.6376335988934447,
        0.0015828509283983424,0.19041484417767818,3.8029805806613286,
        0.001582850928398342,0.19041484417767818,3.968327562429212,
        0.0015828509283983422,0.19041484417767818,4.133674544197096,
        0.0015828509283983424,0.19041484417767818,4.29902152596498,
        0.001582850928398342,0.19041484417767818,4.464368507732864,
        0.0015828509283983426,0.19041484417767818,4.6297154895007475,
        0.0015828509283983422,0.19041484417767818,4.795062471268632,
        0.001582850928398343,0.19041484417767818,4.960409453036515,
        0.001582850928398345,0.19041484417767818,5.1257564348044,
        0.0015828509283983443,0.19041484417767818,5.291103416572283,
        0.0015828509283983448,0.19041484417767818,5.456450398340167,
        0.0015828509283983437,0.19041484417767818,5.621797380108051,
        0.0015828509283983426,0.19041484417767818,5.787144361875934,
        0.0015828509283983409,0.19041484417767818,5.9524913436438185,
        0.0015828509283983402,0.19041484417767818,6.117838325411703,
        0.0015828509283983383,0.34362621959041295,0.,0.0026877648931357997,
        0.34362621959041295,0.16534698176788384,0.0026877648931357976,
        0.34362621959041295,0.3306939635357677,0.0026877648931357967,
        0.34362621959041295,0.4960409453036515,0.002687764893135797,
        0.34362621959041295,0.6613879270715354,0.0026877648931357984,
        0.34362621959041295,0.8267349088394192,0.0026877648931358,
        0.34362621959041295,0.992081890607303,0.0026877648931358,
        0.34362621959041295,1.1574288723751869,0.0026877648931357997,
        0.34362621959041295,1.3227758541430708,0.002687764893135799,
        0.34362621959041295,1.4881228359109546,0.0026877648931357993,
        0.34362621959041295,1.6534698176788385,0.0026877648931357997,
        0.34362621959041295,1.8188167994467224,0.0026877648931357997,
        0.34362621959041295,1.984163781214606,0.002687764893135799,
        0.34362621959041295,2.14951076298249,0.0026877648931357997,
        0.34362621959041295,2.3148577447503738,0.0026877648931357997,
        0.34362621959041295,2.4802047265182576,0.002687764893135801,
        0.34362621959041295,2.6455517082861415,0.002687764893135801,
        0.34362621959041295,2.8108986900540254,0.0026877648931357993,
        0.34362621959041295,2.9762456718219092,0.002687764893135799,
        0.34362621959041295,3.141592653589793,0.002687764893135801,
        0.34362621959041295,3.306939635357677,0.0026877648931358006,
        0.34362621959041295,3.4722866171255613,0.0026877648931357997,
        0.34362621959041295,3.6376335988934447,0.002687764893135796,
        0.34362621959041295,3.8029805806613286,0.002687764893135795,
        0.34362621959041295,3.968327562429212,0.0026877648931357963,
        0.34362621959041295,4.133674544197096,0.0026877648931357993,
        0.34362621959041295,4.29902152596498,0.002687764893135801,
        0.34362621959041295,4.464368507732864,0.0026877648931358015,
        0.34362621959041295,4.6297154895007475,0.0026877648931358015,
        0.34362621959041295,4.795062471268632,0.002687764893135798,
        0.34362621959041295,4.960409453036515,0.002687764893135799,
        0.34362621959041295,5.1257564348044,0.0026877648931357993,
        0.34362621959041295,5.291103416572283,0.0026877648931357976,
        0.34362621959041295,5.456450398340167,0.002687764893135797,
        0.34362621959041295,5.621797380108051,0.0026877648931357976,
        0.34362621959041295,5.787144361875934,0.0026877648931357984,
        0.34362621959041295,5.9524913436438185,0.0026877648931358,
        0.34362621959041295,6.117838325411703,0.0026877648931358028,
        0.4870081978929722,0.,0.0035288794452830795,0.4870081978929722,
        0.16534698176788384,0.0035288794452830747,0.4870081978929722,
        0.3306939635357677,0.003528879445283073,0.4870081978929722,
        0.4960409453036515,0.0035288794452830743,0.4870081978929722,
        0.6613879270715354,0.003528879445283078,0.4870081978929722,
        0.8267349088394192,0.0035288794452830773,0.4870081978929722,
        0.992081890607303,0.0035288794452830777,0.4870081978929722,
        1.1574288723751869,0.003528879445283076,0.4870081978929722,
        1.3227758541430708,0.0035288794452830756,0.4870081978929722,
        1.4881228359109546,0.003528879445283076,0.4870081978929722,
        1.6534698176788385,0.003528879445283075,0.4870081978929722,
        1.8188167994467224,0.003528879445283075,0.4870081978929722,
        1.984163781214606,0.003528879445283075,0.4870081978929722,2.14951076298249,
        0.003528879445283074,0.4870081978929722,2.3148577447503738,
        0.003528879445283075,0.4870081978929722,2.4802047265182576,
        0.0035288794452830786,0.4870081978929722,2.6455517082861415,
        0.00352887944528308,0.4870081978929722,2.8108986900540254,
        0.0035288794452830756,0.4870081978929722,2.9762456718219092,
        0.0035288794452830743,0.4870081978929722,3.141592653589793,
        0.003528879445283078,0.4870081978929722,3.306939635357677,
        0.0035288794452830816,0.4870081978929722,3.4722866171255613,
        0.0035288794452830803,0.4870081978929722,3.6376335988934447,
        0.003528879445283073,0.4870081978929722,3.8029805806613286,
        0.003528879445283067,0.4870081978929722,3.968327562429212,
        0.0035288794452830686,0.4870081978929722,4.133674544197096,
        0.0035288794452830764,0.4870081978929722,4.29902152596498,
        0.0035288794452830777,0.4870081978929722,4.464368507732864,
        0.0035288794452830756,0.4870081978929722,4.6297154895007475,
        0.003528879445283072,0.4870081978929722,4.795062471268632,
        0.0035288794452830704,0.4870081978929722,4.960409453036515,
        0.0035288794452830717,0.4870081978929722,5.1257564348044,
        0.003528879445283075,0.4870081978929722,5.291103416572283,
        0.003528879445283077,0.4870081978929722,5.456450398340167,
        0.0035288794452830747,0.4870081978929722,5.621797380108051,
        0.0035288794452830695,0.4870081978929722,5.787144361875934,
        0.003528879445283071,0.4870081978929722,5.9524913436438185,
        0.0035288794452830803,0.4870081978929722,6.117838325411703,
        0.003528879445283086,0.61796663769552,0.,0.004024464312163518,
        0.61796663769552,0.16534698176788384,0.004024464312163521,0.61796663769552,
        0.3306939635357677,0.004024464312163519,0.61796663769552,0.4960409453036515,
        0.004024464312163519,0.61796663769552,0.6613879270715354,
        0.004024464312163524,0.61796663769552,0.8267349088394192,
        0.004024464312163526,0.61796663769552,0.992081890607303,
        0.004024464312163525,0.61796663769552,1.1574288723751869,
        0.004024464312163525,0.61796663769552,1.3227758541430708,
        0.004024464312163524,0.61796663769552,1.4881228359109546,
        0.004024464312163525,0.61796663769552,1.6534698176788385,
        0.004024464312163524,0.61796663769552,1.8188167994467224,
        0.004024464312163522,0.61796663769552,1.984163781214606,
        0.004024464312163524,0.61796663769552,2.14951076298249,0.004024464312163527,
        0.61796663769552,2.3148577447503738,0.004024464312163521,0.61796663769552,
        2.4802047265182576,0.0040244643121635235,0.61796663769552,
        2.6455517082861415,0.004024464312163531,0.61796663769552,2.8108986900540254,
        0.0040244643121635235,0.61796663769552,2.9762456718219092,
        0.004024464312163518,0.61796663769552,3.141592653589793,
        0.004024464312163524,0.61796663769552,3.306939635357677,
        0.004024464312163528,0.61796663769552,3.4722866171255613,
        0.004024464312163526,0.61796663769552,3.6376335988934447,
        0.004024464312163517,0.61796663769552,3.8029805806613286,
        0.004024464312163516,0.61796663769552,3.968327562429212,
        0.004024464312163519,0.61796663769552,4.133674544197096,
        0.004024464312163523,0.61796663769552,4.29902152596498,0.004024464312163529,
        0.61796663769552,4.464368507732864,0.004024464312163527,0.61796663769552,
        4.6297154895007475,0.004024464312163519,0.61796663769552,4.795062471268632,
        0.0040244643121635235,0.61796663769552,4.960409453036515,
        0.004024464312163524,0.61796663769552,5.1257564348044,0.004024464312163519,
        0.61796663769552,5.291103416572283,0.004024464312163527,0.61796663769552,
        5.456450398340167,0.004024464312163531,0.61796663769552,5.621797380108051,
        0.004024464312163511,0.61796663769552,5.787144361875934,
        0.004024464312163514,0.61796663769552,5.9524913436438185,
        0.004024464312163534,0.61796663769552,6.117838325411703,
        0.004024464312163531,0.7335050094709572,0.,0.004126084963509918,
        0.7335050094709572,0.16534698176788384,0.004126084963509926,
        0.7335050094709572,0.3306939635357677,0.004126084963509915,
        0.7335050094709572,0.4960409453036515,0.0041260849635099146,
        0.7335050094709572,0.6613879270715354,0.004126084963509924,
        0.7335050094709572,0.8267349088394192,0.0041260849635099215,
        0.7335050094709572,0.992081890607303,0.004126084963509919,
        0.7335050094709572,1.1574288723751869,0.004126084963509924,
        0.7335050094709572,1.3227758541430708,0.004126084963509917,
        0.7335050094709572,1.4881228359109546,0.00412608496350992,
        0.7335050094709572,1.6534698176788385,0.004126084963509925,
        0.7335050094709572,1.8188167994467224,0.004126084963509916,
        0.7335050094709572,1.984163781214606,0.00412608496350992,0.7335050094709572,
        2.14951076298249,0.004126084963509926,0.7335050094709572,2.3148577447503738,
        0.004126084963509915,0.7335050094709572,2.4802047265182576,
        0.0041260849635099215,0.7335050094709572,2.6455517082861415,
        0.004126084963509927,0.7335050094709572,2.8108986900540254,
        0.004126084963509923,0.7335050094709572,2.9762456718219092,
        0.0041260849635099215,0.7335050094709572,3.141592653589793,
        0.004126084963509919,0.7335050094709572,3.306939635357677,
        0.004126084963509932,0.7335050094709572,3.4722866171255613,
        0.00412608496350993,0.7335050094709572,3.6376335988934447,
        0.0041260849635099146,0.7335050094709572,3.8029805806613286,
        0.004126084963509916,0.7335050094709572,3.968327562429212,
        0.004126084963509921,0.7335050094709572,4.133674544197096,
        0.004126084963509918,0.7335050094709572,4.29902152596498,
        0.0041260849635099284,0.7335050094709572,4.464368507732864,
        0.00412608496350993,0.7335050094709572,4.6297154895007475,
        0.004126084963509914,0.7335050094709572,4.795062471268632,
        0.004126084963509919,0.7335050094709572,4.960409453036515,
        0.00412608496350993,0.7335050094709572,5.1257564348044,0.004126084963509911,
        0.7335050094709572,5.291103416572283,0.00412608496350992,0.7335050094709572,
        5.456450398340167,0.0041260849635099345,0.7335050094709572,
        5.621797380108051,0.004126084963509899,0.7335050094709572,5.787144361875934,
        0.00412608496350991,0.7335050094709572,5.9524913436438185,
        0.0041260849635099415,0.7335050094709572,6.117838325411703,
        0.004126084963509925,0.830862455567925,0.,0.003823817958330415,
        0.830862455567925,0.16534698176788384,0.0038238179583304148,
        0.830862455567925,0.3306939635357677,0.003823817958330405,0.830862455567925,
        0.4960409453036515,0.003823817958330409,0.830862455567925,
        0.6613879270715354,0.0038238179583304165,0.830862455567925,
        0.8267349088394192,0.003823817958330413,0.830862455567925,0.992081890607303,
        0.003823817958330411,0.830862455567925,1.1574288723751869,
        0.003823817958330418,0.830862455567925,1.3227758541430708,
        0.0038238179583304117,0.830862455567925,1.4881228359109546,
        0.0038238179583304083,0.830862455567925,1.6534698176788385,
        0.003823817958330419,0.830862455567925,1.8188167994467224,
        0.0038238179583304096,0.830862455567925,1.984163781214606,
        0.0038238179583304104,0.830862455567925,2.14951076298249,
        0.0038238179583304226,0.830862455567925,2.3148577447503738,
        0.0038238179583304035,0.830862455567925,2.4802047265182576,
        0.0038238179583304213,0.830862455567925,2.6455517082861415,
        0.0038238179583304148,0.830862455567925,2.8108986900540254,
        0.0038238179583304143,0.830862455567925,2.9762456718219092,
        0.003823817958330418,0.830862455567925,3.141592653589793,
        0.003823817958330404,0.830862455567925,3.306939635357677,
        0.0038238179583304274,0.830862455567925,3.4722866171255613,
        0.003823817958330418,0.830862455567925,3.6376335988934447,
        0.0038238179583304052,0.830862455567925,3.8029805806613286,
        0.0038238179583304113,0.830862455567925,3.968327562429212,
        0.0038238179583304096,0.830862455567925,4.133674544197096,
        0.0038238179583304126,0.830862455567925,4.29902152596498,
        0.0038238179583304182,0.830862455567925,4.464368507732864,
        0.003823817958330421,0.830862455567925,4.6297154895007475,
        0.0038238179583304096,0.830862455567925,4.795062471268632,
        0.0038238179583304087,0.830862455567925,4.960409453036515,
        0.003823817958330425,0.830862455567925,5.1257564348044,0.003823817958330408,
        0.830862455567925,5.291103416572283,0.0038238179583304083,0.830862455567925,
        5.456450398340167,0.0038238179583304386,0.830862455567925,5.621797380108051,
        0.0038238179583303927,0.830862455567925,5.787144361875934,
        0.0038238179583304057,0.830862455567925,5.9524913436438185,
        0.0038238179583304365,0.830862455567925,6.117838325411703,
        0.003823817958330408,0.907680199099333,0.,0.0031472819962403333,
        0.907680199099333,0.16534698176788384,0.003147281996240322,
        0.907680199099333,0.3306939635357677,0.0031472819962403264,
        0.907680199099333,0.4960409453036515,0.0031472819962403216,
        0.907680199099333,0.6613879270715354,0.0031472819962403255,
        0.907680199099333,0.8267349088394192,0.0031472819962403277,
        0.907680199099333,0.992081890607303,0.003147281996240324,0.907680199099333,
        1.1574288723751869,0.0031472819962403233,0.907680199099333,
        1.3227758541430708,0.0031472819962403255,0.907680199099333,
        1.4881228359109546,0.003147281996240324,0.907680199099333,
        1.6534698176788385,0.003147281996240328,0.907680199099333,
        1.8188167994467224,0.003147281996240325,0.907680199099333,1.984163781214606,
        0.0031472819962403186,0.907680199099333,2.14951076298249,
        0.0031472819962403338,0.907680199099333,2.3148577447503738,
        0.0031472819962403147,0.907680199099333,2.4802047265182576,
        0.0031472819962403316,0.907680199099333,2.6455517082861415,
        0.003147281996240329,0.907680199099333,2.8108986900540254,
        0.0031472819962403264,0.907680199099333,2.9762456718219092,
        0.003147281996240329,0.907680199099333,3.141592653589793,
        0.003147281996240318,0.907680199099333,3.306939635357677,
        0.003147281996240341,0.907680199099333,3.4722866171255613,
        0.003147281996240327,0.907680199099333,3.6376335988934447,
        0.0031472819962403238,0.907680199099333,3.8029805806613286,
        0.0031472819962403233,0.907680199099333,3.968327562429212,
        0.0031472819962403207,0.907680199099333,4.133674544197096,
        0.0031472819962403264,0.907680199099333,4.29902152596498,
        0.0031472819962403303,0.907680199099333,4.464368507732864,
        0.003147281996240328,0.907680199099333,4.6297154895007475,
        0.003147281996240326,0.907680199099333,4.795062471268632,
        0.0031472819962403255,0.907680199099333,4.960409453036515,
        0.0031472819962403277,0.907680199099333,5.1257564348044,0.00314728199624033,
        0.907680199099333,5.291103416572283,0.0031472819962403177,0.907680199099333,
        5.456450398340167,0.0031472819962403485,0.907680199099333,5.621797380108051,
        0.0031472819962403077,0.907680199099333,5.787144361875934,
        0.0031472819962403216,0.907680199099333,5.9524913436438185,
        0.003147281996240343,0.907680199099333,6.117838325411703,
        0.003147281996240323,0.9620876312949896,0.,0.0021628422728547474,
        0.9620876312949896,0.16534698176788384,0.002162842272854746,
        0.9620876312949896,0.3306939635357677,0.0021628422728547443,
        0.9620876312949896,0.4960409453036515,0.00216284227285474,
        0.9620876312949896,0.6613879270715354,0.0021628422728547517,
        0.9620876312949896,0.8267349088394192,0.0021628422728547417,
        0.9620876312949896,0.992081890607303,0.002162842272854745,
        0.9620876312949896,1.1574288723751869,0.0021628422728547487,
        0.9620876312949896,1.3227758541430708,0.0021628422728547435,
        0.9620876312949896,1.4881228359109546,0.002162842272854744,
        0.9620876312949896,1.6534698176788385,0.002162842272854746,
        0.9620876312949896,1.8188167994467224,0.002162842272854745,
        0.9620876312949896,1.984163781214606,0.0021628422728547417,
        0.9620876312949896,2.14951076298249,0.0021628422728547504,
        0.9620876312949896,2.3148577447503738,0.00216284227285474,
        0.9620876312949896,2.4802047265182576,0.0021628422728547482,
        0.9620876312949896,2.6455517082861415,0.002162842272854746,
        0.9620876312949896,2.8108986900540254,0.0021628422728547448,
        0.9620876312949896,2.9762456718219092,0.0021628422728547474,
        0.9620876312949896,3.141592653589793,0.0021628422728547387,
        0.9620876312949896,3.306939635357677,0.002162842272854753,
        0.9620876312949896,3.4722866171255613,0.0021628422728547443,
        0.9620876312949896,3.6376335988934447,0.0021628422728547443,
        0.9620876312949896,3.8029805806613286,0.00216284227285474,
        0.9620876312949896,3.968327562429212,0.0021628422728547474,
        0.9620876312949896,4.133674544197096,0.002162842272854741,
        0.9620876312949896,4.29902152596498,0.002162842272854748,0.9620876312949896,
        4.464368507732864,0.0021628422728547517,0.9620876312949896,
        4.6297154895007475,0.002162842272854737,0.9620876312949896,
        4.795062471268632,0.0021628422728547482,0.9620876312949896,
        4.960409453036515,0.0021628422728547465,0.9620876312949896,5.1257564348044,
        0.0021628422728547474,0.9620876312949896,5.291103416572283,
        0.0021628422728547383,0.9620876312949896,5.456450398340167,
        0.0021628422728547617,0.9620876312949896,5.621797380108051,
        0.002162842272854729,0.9620876312949896,5.787144361875934,
        0.0021628422728547435,0.9620876312949896,5.9524913436438185,
        0.002162842272854756,0.9620876312949896,6.117838325411703,
        0.002162842272854743,0.9927676416720699,0.,0.0009686448090362063,
        0.9927676416720699,0.16534698176788384,0.0009686448090362069,
        0.9927676416720699,0.3306939635357677,0.0009686448090362038,
        0.9927676416720699,0.4960409453036515,0.0009686448090362046,
        0.9927676416720699,0.6613879270715354,0.0009686448090362053,
        0.9927676416720699,0.8267349088394192,0.0009686448090362057,
        0.9927676416720699,0.992081890607303,0.0009686448090362052,
        0.9927676416720699,1.1574288723751869,0.0009686448090362046,
        0.9927676416720699,1.3227758541430708,0.000968644809036209,
        0.9927676416720699,1.4881228359109546,0.0009686448090362029,
        0.9927676416720699,1.6534698176788385,0.0009686448090362102,
        0.9927676416720699,1.8188167994467224,0.0009686448090362017,
        0.9927676416720699,1.984163781214606,0.0009686448090362081,
        0.9927676416720699,2.14951076298249,0.0009686448090362051,
        0.9927676416720699,2.3148577447503738,0.0009686448090362072,
        0.9927676416720699,2.4802047265182576,0.0009686448090362058,
        0.9927676416720699,2.6455517082861415,0.0009686448090362106,
        0.9927676416720699,2.8108986900540254,0.0009686448090362035,
        0.9927676416720699,2.9762456718219092,0.00096864480903621,
        0.9927676416720699,3.141592653589793,0.0009686448090362017,
        0.9927676416720699,3.306939635357677,0.0009686448090362122,
        0.9927676416720699,3.4722866171255613,0.0009686448090362052,
        0.9927676416720699,3.6376335988934447,0.0009686448090362044,
        0.9927676416720699,3.8029805806613286,0.000968644809036206,
        0.9927676416720699,3.968327562429212,0.0009686448090362038,
        0.9927676416720699,4.133674544197096,0.000968644809036207,
        0.9927676416720699,4.29902152596498,0.0009686448090362065,
        0.9927676416720699,4.464368507732864,0.0009686448090362096,
        0.9927676416720699,4.6297154895007475,0.0009686448090362044,
        0.9927676416720699,4.795062471268632,0.0009686448090362067,
        0.9927676416720699,4.960409453036515,0.0009686448090362056,
        0.9927676416720699,5.1257564348044,0.0009686448090362069,0.9927676416720699,
        5.291103416572283,0.0009686448090362009,0.9927676416720699,
        5.456450398340167,0.0009686448090362145,0.9927676416720699,
        5.621797380108051,0.0009686448090361956,0.9927676416720699,
        5.787144361875934,0.0009686448090362043,0.9927676416720699,
        5.9524913436438185,0.0009686448090362096,0.9927676416720699,
        6.117838325411703,0.0009686448090362072,0.1142223084227163,0.,
        0.0008333918038632131,0.1142223084227163,0.15707963267948966,
        0.0008333918038632177,0.1142223084227163,0.3141592653589793,
        0.0008333918038632218,0.1142223084227163,0.47123889803846897,
        0.0008333918038632212,0.1142223084227163,0.6283185307179586,
        0.0008333918038632196,0.1142223084227163,0.7853981633974483,
        0.0008333918038632191,0.1142223084227163,0.9424777960769379,
        0.0008333918038632189,0.1142223084227163,1.0995574287564276,
        0.0008333918038632167,0.1142223084227163,1.2566370614359172,
        0.0008333918038632162,0.1142223084227163,1.413716694115407,
        0.0008333918038632162,0.1142223084227163,1.5707963267948966,
        0.0008333918038632151,0.1142223084227163,1.7278759594743864,
        0.0008333918038632155,0.1142223084227163,1.8849555921538759,
        0.0008333918038632162,0.1142223084227163,2.0420352248333655,
        0.0008333918038632163,0.1142223084227163,2.199114857512855,
        0.000833391803863217,0.1142223084227163,2.356194490192345,
        0.0008333918038632169,0.1142223084227163,2.5132741228718345,
        0.0008333918038632173,0.1142223084227163,2.670353755551324,
        0.0008333918038632183,0.1142223084227163,2.827433388230814,
        0.0008333918038632189,0.1142223084227163,2.9845130209103035,
        0.0008333918038632192,0.1142223084227163,3.141592653589793,
        0.0008333918038632203,0.1142223084227163,3.2986722862692828,
        0.0008333918038632187,0.1142223084227163,3.455751918948773,
        0.0008333918038632182,0.1142223084227163,3.6128315516282616,
        0.0008333918038632179,0.1142223084227163,3.7699111843077517,
        0.0008333918038632178,0.1142223084227163,3.9269908169872414,
        0.0008333918038632169,0.1142223084227163,4.084070449666731,
        0.000833391803863217,0.1142223084227163,4.241150082346221,
        0.0008333918038632163,0.1142223084227163,4.39822971502571,
        0.0008333918038632156,0.1142223084227163,4.5553093477052,
        0.0008333918038632161,0.1142223084227163,4.71238898038469,
        0.0008333918038632149,0.1142223084227163,4.869468613064179,
        0.0008333918038632167,0.1142223084227163,5.026548245743669,
        0.0008333918038632163,0.1142223084227163,5.183627878423159,
        0.0008333918038632166,0.1142223084227163,5.340707511102648,
        0.0008333918038632185,0.1142223084227163,5.497787143782138,
        0.0008333918038632181,0.1142223084227163,5.654866776461628,
        0.00083339180386322,0.1142223084227163,5.811946409141117,
        0.0008333918038632214,0.1142223084227163,5.969026041820607,
        0.0008333918038632215,0.1142223084227163,6.126105674500097,
        0.0008333918038632213,0.2597466393536358,0.,0.0018681418643652515,
        0.2597466393536358,0.15707963267948966,0.0018681418643652513,
        0.2597466393536358,0.3141592653589793,0.0018681418643652502,
        0.2597466393536358,0.47123889803846897,0.0018681418643652498,
        0.2597466393536358,0.6283185307179586,0.0018681418643652487,
        0.2597466393536358,0.7853981633974483,0.0018681418643652487,
        0.2597466393536358,0.9424777960769379,0.0018681418643652476,
        0.2597466393536358,1.0995574287564276,0.0018681418643652482,
        0.2597466393536358,1.2566370614359172,0.001868141864365248,
        0.2597466393536358,1.413716694115407,0.0018681418643652485,
        0.2597466393536358,1.5707963267948966,0.0018681418643652478,
        0.2597466393536358,1.7278759594743864,0.0018681418643652474,
        0.2597466393536358,1.8849555921538759,0.0018681418643652472,
        0.2597466393536358,2.0420352248333655,0.001868141864365247,
        0.2597466393536358,2.199114857512855,0.0018681418643652467,
        0.2597466393536358,2.356194490192345,0.0018681418643652465,
        0.2597466393536358,2.5132741228718345,0.0018681418643652476,
        0.2597466393536358,2.670353755551324,0.0018681418643652467,
        0.2597466393536358,2.827433388230814,0.0018681418643652454,
        0.2597466393536358,2.9845130209103035,0.0018681418643652459,
        0.2597466393536358,3.141592653589793,0.0018681418643652452,
        0.2597466393536358,3.2986722862692828,0.001868141864365245,
        0.2597466393536358,3.455751918948773,0.0018681418643652456,
        0.2597466393536358,3.6128315516282616,0.001868141864365247,
        0.2597466393536358,3.7699111843077517,0.0018681418643652474,
        0.2597466393536358,3.9269908169872414,0.0018681418643652476,
        0.2597466393536358,4.084070449666731,0.0018681418643652476,
        0.2597466393536358,4.241150082346221,0.0018681418643652465,
        0.2597466393536358,4.39822971502571,0.0018681418643652467,
        0.2597466393536358,4.5553093477052,0.0018681418643652472,0.2597466393536358,
        4.71238898038469,0.0018681418643652465,0.2597466393536358,4.869468613064179,
        0.0018681418643652476,0.2597466393536358,5.026548245743669,
        0.001868141864365248,0.2597466393536358,5.183627878423159,
        0.0018681418643652493,0.2597466393536358,5.340707511102648,
        0.0018681418643652493,0.2597466393536358,5.497787143782138,
        0.0018681418643652493,0.2597466393536358,5.654866776461628,
        0.0018681418643652493,0.2597466393536358,5.811946409141117,
        0.0018681418643652502,0.2597466393536358,5.969026041820607,
        0.001868141864365252,0.2597466393536358,6.126105674500097,
        0.0018681418643652521,0.40036884975043674,0.,0.0027385795314851997,
        0.40036884975043674,0.15707963267948966,0.002738579531485198,
        0.40036884975043674,0.3141592653589793,0.0027385795314851975,
        0.40036884975043674,0.47123889803846897,0.002738579531485198,
        0.40036884975043674,0.6283185307179586,0.002738579531485198,
        0.40036884975043674,0.7853981633974483,0.0027385795314851967,
        0.40036884975043674,0.9424777960769379,0.0027385795314851962,
        0.40036884975043674,1.0995574287564276,0.0027385795314852,
        0.40036884975043674,1.2566370614359172,0.0027385795314852027,
        0.40036884975043674,1.413716694115407,0.0027385795314852023,
        0.40036884975043674,1.5707963267948966,0.0027385795314851993,
        0.40036884975043674,1.7278759594743864,0.002738579531485198,
        0.40036884975043674,1.8849555921538759,0.002738579531485198,
        0.40036884975043674,2.0420352248333655,0.0027385795314851962,
        0.40036884975043674,2.199114857512855,0.0027385795314851962,
        0.40036884975043674,2.356194490192345,0.0027385795314851975,
        0.40036884975043674,2.5132741228718345,0.0027385795314851975,
        0.40036884975043674,2.670353755551324,0.002738579531485198,
        0.40036884975043674,2.827433388230814,0.0027385795314851967,
        0.40036884975043674,2.9845130209103035,0.0027385795314851954,
        0.40036884975043674,3.141592653589793,0.0027385795314851967,
        0.40036884975043674,3.2986722862692828,0.0027385795314851954,
        0.40036884975043674,3.455751918948773,0.002738579531485196,
        0.40036884975043674,3.6128315516282616,0.002738579531485195,
        0.40036884975043674,3.7699111843077517,0.0027385795314852,
        0.40036884975043674,3.9269908169872414,0.0027385795314852006,
        0.40036884975043674,4.084070449666731,0.002738579531485197,
        0.40036884975043674,4.241150082346221,0.0027385795314851945,
        0.40036884975043674,4.39822971502571,0.0027385795314851945,
        0.40036884975043674,4.5553093477052,0.0027385795314851967,
        0.40036884975043674,4.71238898038469,0.0027385795314851997,
        0.40036884975043674,4.869468613064179,0.0027385795314852,
        0.40036884975043674,5.026548245743669,0.0027385795314851993,
        0.40036884975043674,5.183627878423159,0.002738579531485197,
        0.40036884975043674,5.340707511102648,0.002738579531485197,
        0.40036884975043674,5.497787143782138,0.0027385795314851997,
        0.40036884975043674,5.654866776461628,0.0027385795314852,
        0.40036884975043674,5.811946409141117,0.0027385795314851984,
        0.40036884975043674,5.969026041820607,0.0027385795314851993,
        0.40036884975043674,6.126105674500097,0.002738579531485199,
        0.5322614986408245,0.,0.003365833991317751,0.5322614986408245,
        0.15707963267948966,0.0033658339913177474,0.5322614986408245,
        0.3141592653589793,0.0033658339913177453,0.5322614986408245,
        0.47123889803846897,0.0033658339913177496,0.5322614986408245,
        0.6283185307179586,0.00336583399131775,0.5322614986408245,
        0.7853981633974483,0.003365833991317742,0.5322614986408245,
        0.9424777960769379,0.0033658339913177383,0.5322614986408245,
        1.0995574287564276,0.003365833991317748,0.5322614986408245,
        1.2566370614359172,0.0033658339913177518,0.5322614986408245,
        1.413716694115407,0.0033658339913177444,0.5322614986408245,
        1.5707963267948966,0.003365833991317738,0.5322614986408245,
        1.7278759594743864,0.0033658339913177422,0.5322614986408245,
        1.8849555921538759,0.003365833991317745,0.5322614986408245,
        2.0420352248333655,0.003365833991317741,0.5322614986408245,
        2.199114857512855,0.0033658339913177375,0.5322614986408245,
        2.356194490192345,0.003365833991317741,0.5322614986408245,
        2.5132741228718345,0.003365833991317747,0.5322614986408245,
        2.670353755551324,0.003365833991317744,0.5322614986408245,2.827433388230814,
        0.003365833991317737,0.5322614986408245,2.9845130209103035,
        0.003365833991317739,0.5322614986408245,3.141592653589793,
        0.003365833991317748,0.5322614986408245,3.2986722862692828,
        0.003365833991317746,0.5322614986408245,3.455751918948773,
        0.0033658339913177336,0.5322614986408245,3.6128315516282616,
        0.0033658339913177366,0.5322614986408245,3.7699111843077517,
        0.0033658339913177496,0.5322614986408245,3.9269908169872414,
        0.0033658339913177505,0.5322614986408245,4.084070449666731,
        0.003365833991317739,0.5322614986408245,4.241150082346221,
        0.0033658339913177353,0.5322614986408245,4.39822971502571,
        0.00336583399131774,0.5322614986408245,4.5553093477052,
        0.0033658339913177427,0.5322614986408245,4.71238898038469,
        0.0033658339913177444,0.5322614986408245,4.869468613064179,
        0.003365833991317746,0.5322614986408245,5.026548245743669,
        0.003365833991317744,0.5322614986408245,5.183627878423159,
        0.003365833991317741,0.5322614986408245,5.340707511102648,
        0.0033658339913177435,0.5322614986408245,5.497787143782138,
        0.0033658339913177483,0.5322614986408245,5.654866776461628,
        0.003365833991317748,0.5322614986408245,5.811946409141117,
        0.0033658339913177453,0.5322614986408245,5.969026041820607,
        0.0033658339913177474,0.5322614986408245,6.126105674500097,
        0.0033658339913177513,0.6523517689936806,0.,0.0036940528090106117,
        0.6523517689936806,0.15707963267948966,0.0036940528090106087,
        0.6523517689936806,0.3141592653589793,0.003694052809010602,
        0.6523517689936806,0.47123889803846897,0.003694052809010608,
        0.6523517689936806,0.6283185307179586,0.003694052809010616,
        0.6523517689936806,0.7853981633974483,0.0036940528090106005,
        0.6523517689936806,0.9424777960769379,0.003694052809010594,
        0.6523517689936806,1.0995574287564276,0.003694052809010613,
        0.6523517689936806,1.2566370614359172,0.003694052809010618,
        0.6523517689936806,1.413716694115407,0.0036940528090106026,
        0.6523517689936806,1.5707963267948966,0.0036940528090105996,
        0.6523517689936806,1.7278759594743864,0.0036940528090106065,
        0.6523517689936806,1.8849555921538759,0.003694052809010603,
        0.6523517689936806,2.0420352248333655,0.003694052809010601,
        0.6523517689936806,2.199114857512855,0.003694052809010595,
        0.6523517689936806,2.356194490192345,0.0036940528090105957,
        0.6523517689936806,2.5132741228718345,0.003694052809010604,
        0.6523517689936806,2.670353755551324,0.0036940528090106052,
        0.6523517689936806,2.827433388230814,0.003694052809010593,
        0.6523517689936806,2.9845130209103035,0.0036940528090105896,
        0.6523517689936806,3.141592653589793,0.0036940528090106052,
        0.6523517689936806,3.2986722862692828,0.003694052809010608,
        0.6523517689936806,3.455751918948773,0.003694052809010586,
        0.6523517689936806,3.6128315516282616,0.00369405280901059,
        0.6523517689936806,3.7699111843077517,0.003694052809010614,
        0.6523517689936806,3.9269908169872414,0.0036940528090106083,
        0.6523517689936806,4.084070449666731,0.0036940528090105935,
        0.6523517689936806,4.241150082346221,0.0036940528090105965,
        0.6523517689936806,4.39822971502571,0.003694052809010605,0.6523517689936806,
        4.5553093477052,0.0036940528090106018,0.6523517689936806,4.71238898038469,
        0.003694052809010601,0.6523517689936806,4.869468613064179,
        0.00369405280901061,0.6523517689936806,5.026548245743669,
        0.003694052809010608,0.6523517689936806,5.183627878423159,
        0.0036940528090105987,0.6523517689936806,5.340707511102648,
        0.003694052809010605,0.6523517689936806,5.497787143782138,
        0.003694052809010612,0.6523517689936806,5.654866776461628,
        0.003694052809010606,0.6523517689936806,5.811946409141117,
        0.0036940528090106044,0.6523517689936806,5.969026041820607,
        0.00369405280901061,0.6523517689936806,6.126105674500097,
        0.00369405280901061,0.757916334096855,0.,0.003694052808849204,
        0.757916334096855,0.15707963267948966,0.003694052808849209,
        0.757916334096855,0.3141592653589793,0.0036940528088492018,
        0.757916334096855,0.47123889803846897,0.003694052808849201,
        0.757916334096855,0.6283185307179586,0.003694052808849212,0.757916334096855,
        0.7853981633974483,0.0036940528088491996,0.757916334096855,
        0.9424777960769379,0.0036940528088491866,0.757916334096855,
        1.0995574287564276,0.0036940528088492087,0.757916334096855,
        1.2566370614359172,0.0036940528088492126,0.757916334096855,
        1.413716694115407,0.003694052808849191,0.757916334096855,1.5707963267948966,
        0.0036940528088491996,0.757916334096855,1.7278759594743864,
        0.003694052808849201,0.757916334096855,1.8849555921538759,
        0.0036940528088491905,0.757916334096855,2.0420352248333655,
        0.003694052808849199,0.757916334096855,2.199114857512855,
        0.003694052808849195,0.757916334096855,2.356194490192345,
        0.0036940528088491896,0.757916334096855,2.5132741228718345,
        0.003694052808849201,0.757916334096855,2.670353755551324,
        0.0036940528088491966,0.757916334096855,2.827433388230814,
        0.0036940528088491883,0.757916334096855,2.9845130209103035,
        0.0036940528088491888,0.757916334096855,3.141592653589793,
        0.0036940528088491957,0.757916334096855,3.2986722862692828,
        0.0036940528088492044,0.757916334096855,3.455751918948773,
        0.003694052808849181,0.757916334096855,3.6128315516282616,
        0.0036940528088491823,0.757916334096855,3.7699111843077517,
        0.003694052808849211,0.757916334096855,3.9269908169872414,
        0.0036940528088491983,0.757916334096855,4.084070449666731,
        0.003694052808849191,0.757916334096855,4.241150082346221,
        0.0036940528088491905,0.757916334096855,4.39822971502571,
        0.0036940528088491944,0.757916334096855,4.5553093477052,
        0.0036940528088491983,0.757916334096855,4.71238898038469,
        0.0036940528088491953,0.757916334096855,4.869468613064179,
        0.003694052808849204,0.757916334096855,5.026548245743669,
        0.0036940528088492035,0.757916334096855,5.183627878423159,
        0.003694052808849189,0.757916334096855,5.340707511102648,
        0.003694052808849199,0.757916334096855,5.497787143782138,
        0.003694052808849211,0.757916334096855,5.654866776461628,
        0.0036940528088491983,0.757916334096855,5.811946409141117,
        0.0036940528088491996,0.757916334096855,5.969026041820607,
        0.0036940528088492096,0.757916334096855,6.126105674500097,
        0.0036940528088492044,0.8465800003925344,0.,0.0033658339914548535,
        0.8465800003925344,0.15707963267948966,0.003365833991454847,
        0.8465800003925344,0.3141592653589793,0.0033658339914548452,
        0.8465800003925344,0.47123889803846897,0.0033658339914548465,
        0.8465800003925344,0.6283185307179586,0.0033658339914548526,
        0.8465800003925344,0.7853981633974483,0.0033658339914548457,
        0.8465800003925344,0.9424777960769379,0.003365833991454832,
        0.8465800003925344,1.0995574287564276,0.0033658339914548535,
        0.8465800003925344,1.2566370614359172,0.0033658339914548613,
        0.8465800003925344,1.413716694115407,0.0033658339914548353,
        0.8465800003925344,1.5707963267948966,0.0033658339914548452,
        0.8465800003925344,1.7278759594743864,0.003365833991454845,
        0.8465800003925344,1.8849555921538759,0.003365833991454838,
        0.8465800003925344,2.0420352248333655,0.0033658339914548474,
        0.8465800003925344,2.199114857512855,0.003365833991454835,
        0.8465800003925344,2.356194490192345,0.0033658339914548344,
        0.8465800003925344,2.5132741228718345,0.0033658339914548513,
        0.8465800003925344,2.670353755551324,0.0033658339914548418,
        0.8465800003925344,2.827433388230814,0.003365833991454831,
        0.8465800003925344,2.9845130209103035,0.003365833991454843,
        0.8465800003925344,3.141592653589793,0.0033658339914548366,
        0.8465800003925344,3.2986722862692828,0.0033658339914548543,
        0.8465800003925344,3.455751918948773,0.003365833991454829,
        0.8465800003925344,3.6128315516282616,0.003365833991454826,
        0.8465800003925344,3.7699111843077517,0.003365833991454863,
        0.8465800003925344,3.9269908169872414,0.003365833991454835,
        0.8465800003925344,4.084070449666731,0.003365833991454844,
        0.8465800003925344,4.241150082346221,0.0033658339914548344,
        0.8465800003925344,4.39822971502571,0.003365833991454836,0.8465800003925344,
        4.5553093477052,0.0033658339914548504,0.8465800003925344,4.71238898038469,
        0.0033658339914548357,0.8465800003925344,4.869468613064179,
        0.0033658339914548483,0.8465800003925344,5.026548245743669,
        0.0033658339914548487,0.8465800003925344,5.183627878423159,
        0.0033658339914548383,0.8465800003925344,5.340707511102648,
        0.0033658339914548418,0.8465800003925344,5.497787143782138,
        0.003365833991454856,0.8465800003925344,5.654866776461628,
        0.0033658339914548435,0.8465800003925344,5.811946409141117,
        0.0033658339914548474,0.8465800003925344,5.969026041820607,
        0.0033658339914548513,0.8465800003925344,6.126105674500097,
        0.003365833991454848,0.916354071388081,0.,0.0027385795313884334,
        0.916354071388081,0.15707963267948966,0.002738579531388424,
        0.916354071388081,0.3141592653589793,0.0027385795313884255,
        0.916354071388081,0.47123889803846897,0.0027385795313884242,
        0.916354071388081,0.6283185307179586,0.002738579531388427,0.916354071388081,
        0.7853981633974483,0.0027385795313884255,0.916354071388081,
        0.9424777960769379,0.0027385795313884112,0.916354071388081,
        1.0995574287564276,0.0027385795313884264,0.916354071388081,
        1.2566370614359172,0.002738579531388435,0.916354071388081,1.413716694115407,
        0.0027385795313884125,0.916354071388081,1.5707963267948966,
        0.0027385795313884234,0.916354071388081,1.7278759594743864,
        0.002738579531388423,0.916354071388081,1.8849555921538759,
        0.0027385795313884173,0.916354071388081,2.0420352248333655,
        0.002738579531388423,0.916354071388081,2.199114857512855,
        0.002738579531388416,0.916354071388081,2.356194490192345,
        0.002738579531388415,0.916354071388081,2.5132741228718345,
        0.0027385795313884203,0.916354071388081,2.670353755551324,
        0.0027385795313884255,0.916354071388081,2.827433388230814,
        0.002738579531388407,0.916354071388081,2.9845130209103035,
        0.002738579531388423,0.916354071388081,3.141592653589793,
        0.0027385795313884112,0.916354071388081,3.2986722862692828,
        0.0027385795313884308,0.916354071388081,3.455751918948773,
        0.0027385795313884104,0.916354071388081,3.6128315516282616,
        0.002738579531388403,0.916354071388081,3.7699111843077517,
        0.002738579531388445,0.916354071388081,3.9269908169872414,
        0.0027385795313884078,0.916354071388081,4.084070449666731,
        0.0027385795313884264,0.916354071388081,4.241150082346221,
        0.002738579531388409,0.916354071388081,4.39822971502571,
        0.0027385795313884208,0.916354071388081,4.5553093477052,
        0.0027385795313884247,0.916354071388081,4.71238898038469,
        0.0027385795313884143,0.916354071388081,4.869468613064179,
        0.0027385795313884316,0.916354071388081,5.026548245743669,
        0.0027385795313884186,0.916354071388081,5.183627878423159,
        0.0027385795313884208,0.916354071388081,5.340707511102648,
        0.0027385795313884177,0.916354071388081,5.497787143782138,
        0.0027385795313884347,0.916354071388081,5.654866776461628,
        0.002738579531388418,0.916354071388081,5.811946409141117,
        0.0027385795313884234,0.916354071388081,5.969026041820607,
        0.002738579531388429,0.916354071388081,6.126105674500097,
        0.0027385795313884203,0.9656768006659849,0.,0.0018681418644176677,
        0.9656768006659849,0.15707963267948966,0.001868141864417661,
        0.9656768006659849,0.3141592653589793,0.0018681418644176623,
        0.9656768006659849,0.47123889803846897,0.001868141864417661,
        0.9656768006659849,0.6283185307179586,0.001868141864417667,
        0.9656768006659849,0.7853981633974483,0.0018681418644176616,
        0.9656768006659849,0.9424777960769379,0.0018681418644176538,
        0.9656768006659849,1.0995574287564276,0.0018681418644176677,
        0.9656768006659849,1.2566370614359172,0.001868141864417671,
        0.9656768006659849,1.413716694115407,0.001868141864417655,
        0.9656768006659849,1.5707963267948966,0.0018681418644176646,
        0.9656768006659849,1.7278759594743864,0.001868141864417658,
        0.9656768006659849,1.8849555921538759,0.0018681418644176603,
        0.9656768006659849,2.0420352248333655,0.001868141864417661,
        0.9656768006659849,2.199114857512855,0.001868141864417654,
        0.9656768006659849,2.356194490192345,0.0018681418644176588,
        0.9656768006659849,2.5132741228718345,0.0018681418644176555,
        0.9656768006659849,2.670353755551324,0.0018681418644176664,
        0.9656768006659849,2.827433388230814,0.0018681418644176462,
        0.9656768006659849,2.9845130209103035,0.001868141864417663,
        0.9656768006659849,3.141592653589793,0.0018681418644176538,
        0.9656768006659849,3.2986722862692828,0.001868141864417663,
        0.9656768006659849,3.455751918948773,0.001868141864417654,
        0.9656768006659849,3.6128315516282616,0.0018681418644176447,
        0.9656768006659849,3.7699111843077517,0.0018681418644176746,
        0.9656768006659849,3.9269908169872414,0.00186814186441765,
        0.9656768006659849,4.084070449666731,0.0018681418644176657,
        0.9656768006659849,4.241150082346221,0.0018681418644176484,
        0.9656768006659849,4.39822971502571,0.0018681418644176599,
        0.9656768006659849,4.5553093477052,0.001868141864417662,0.9656768006659849,
        4.71238898038469,0.0018681418644176538,0.9656768006659849,4.869468613064179,
        0.0018681418644176688,0.9656768006659849,5.026548245743669,
        0.001868141864417655,0.9656768006659849,5.183627878423159,
        0.0018681418644176655,0.9656768006659849,5.340707511102648,
        0.0018681418644176545,0.9656768006659849,5.497787143782138,
        0.0018681418644176699,0.9656768006659849,5.654866776461628,
        0.0018681418644176607,0.9656768006659849,5.811946409141117,
        0.0018681418644176603,0.9656768006659849,5.969026041820607,
        0.001868141864417669,0.9656768006659849,6.126105674500097,
        0.0018681418644176594,0.9934552150241026,0.,0.0008333918038478385,
        0.9934552150241026,0.15707963267948966,0.0008333918038478376,
        0.9934552150241026,0.3141592653589793,0.0008333918038478376,
        0.9934552150241026,0.47123889803846897,0.0008333918038478364,
        0.9934552150241026,0.6283185307179586,0.0008333918038478379,
        0.9934552150241026,0.7853981633974483,0.0008333918038478368,
        0.9934552150241026,0.9424777960769379,0.000833391803847833,
        0.9934552150241026,1.0995574287564276,0.000833391803847838,
        0.9934552150241026,1.2566370614359172,0.00083339180384784,
        0.9934552150241026,1.413716694115407,0.0008333918038478336,
        0.9934552150241026,1.5707963267948966,0.0008333918038478371,
        0.9934552150241026,1.7278759594743864,0.0008333918038478371,
        0.9934552150241026,1.8849555921538759,0.0008333918038478347,
        0.9934552150241026,2.0420352248333655,0.000833391803847838,
        0.9934552150241026,2.199114857512855,0.0008333918038478343,
        0.9934552150241026,2.356194490192345,0.0008333918038478347,
        0.9934552150241026,2.5132741228718345,0.0008333918038478377,
        0.9934552150241026,2.670353755551324,0.0008333918038478356,
        0.9934552150241026,2.827433388230814,0.0008333918038478336,
        0.9934552150241026,2.9845130209103035,0.0008333918038478354,
        0.9934552150241026,3.141592653589793,0.0008333918038478329,
        0.9934552150241026,3.2986722862692828,0.0008333918038478393,
        0.9934552150241026,3.455751918948773,0.0008333918038478317,
        0.9934552150241026,3.6128315516282616,0.000833391803847832,
        0.9934552150241026,3.7699111843077517,0.0008333918038478411,
        0.9934552150241026,3.9269908169872414,0.0008333918038478341,
        0.9934552150241026,4.084070449666731,0.0008333918038478362,
        0.9934552150241026,4.241150082346221,0.000833391803847834,
        0.9934552150241026,4.39822971502571,0.0008333918038478336,
        0.9934552150241026,4.5553093477052,0.000833391803847836,0.9934552150241026,
        4.71238898038469,0.0008333918038478346,0.9934552150241026,4.869468613064179,
        0.0008333918038478379,0.9934552150241026,5.026548245743669,
        0.0008333918038478381,0.9934552150241026,5.183627878423159,
        0.0008333918038478326,0.9934552150241026,5.340707511102648,
        0.0008333918038478368,0.9934552150241026,5.497787143782138,
        0.0008333918038478372,0.9934552150241026,5.654866776461628,
        0.0008333918038478355,0.9934552150241026,5.811946409141117,
        0.000833391803847838,0.9934552150241026,5.969026041820607,
        0.0008333918038478375,0.9934552150241026,6.126105674500097,
        0.0008333918038478359,0.,0.,0.008264462810118969,0.17328886912172548,0.,
        0.0011886438322259638,0.17328886912172548,0.1495996501709425,
        0.0011886438322259614,0.17328886912172548,0.299199300341885,
        0.0011886438322259681,0.17328886912172548,0.4487989505128276,
        0.0011886438322259664,0.17328886912172548,0.59839860068377,
        0.001188643832225965,0.17328886912172548,0.7479982508547126,
        0.0011886438322259642,0.17328886912172548,0.8975979010256552,
        0.0011886438322259642,0.17328886912172548,1.0471975511965976,
        0.001188643832225965,0.17328886912172548,1.19679720136754,
        0.0011886438322259636,0.17328886912172548,1.3463968515384828,
        0.0011886438322259625,0.17328886912172548,1.4959965017094252,
        0.0011886438322259649,0.17328886912172548,1.645596151880368,
        0.0011886438322259647,0.17328886912172548,1.7951958020513104,
        0.001188643832225965,0.17328886912172548,1.944795452222253,
        0.0011886438322259647,0.17328886912172548,2.0943951023931953,
        0.0011886438322259647,0.17328886912172548,2.243994752564138,
        0.0011886438322259653,0.17328886912172548,2.39359440273508,
        0.001188643832225966,0.17328886912172548,2.543194052906023,
        0.0011886438322259647,0.17328886912172548,2.6927937030769655,
        0.0011886438322259642,0.17328886912172548,2.842393353247908,
        0.0011886438322259649,0.17328886912172548,2.9919930034188504,
        0.0011886438322259662,0.17328886912172548,3.141592653589793,
        0.0011886438322259653,0.17328886912172548,3.291192303760736,
        0.0011886438322259647,0.17328886912172548,3.4407919539316785,
        0.0011886438322259653,0.17328886912172548,3.5903916041026207,
        0.0011886438322259649,0.17328886912172548,3.7399912542735634,
        0.0011886438322259657,0.17328886912172548,3.889590904444506,
        0.0011886438322259666,0.17328886912172548,4.039190554615448,
        0.0011886438322259647,0.17328886912172548,4.1887902047863905,
        0.0011886438322259644,0.17328886912172548,4.338389854957334,
        0.0011886438322259653,0.17328886912172548,4.487989505128276,
        0.0011886438322259653,0.17328886912172548,4.637589155299219,
        0.001188643832225964,0.17328886912172548,4.78718880547016,
        0.001188643832225964,0.17328886912172548,4.9367884556411035,
        0.0011886438322259634,0.17328886912172548,5.086388105812046,
        0.001188643832225965,0.17328886912172548,5.235987755982989,
        0.0011886438322259642,0.17328886912172548,5.385587406153931,
        0.0011886438322259644,0.17328886912172548,5.535187056324873,
        0.0011886438322259649,0.17328886912172548,5.684786706495816,
        0.0011886438322259657,0.17328886912172548,5.834386356666759,
        0.0011886438322259655,0.17328886912172548,5.983986006837701,
        0.0011886438322259677,0.17328886912172548,6.133585657008643,
        0.0011886438322259673,0.3135107848381826,0.,0.002039495466762065,
        0.3135107848381826,0.1495996501709425,0.002039495466762065,
        0.3135107848381826,0.299199300341885,0.0020394954667620636,
        0.3135107848381826,0.4487989505128276,0.0020394954667620614,
        0.3135107848381826,0.59839860068377,0.0020394954667620605,
        0.3135107848381826,0.7479982508547126,0.0020394954667620623,
        0.3135107848381826,0.8975979010256552,0.002039495466762062,
        0.3135107848381826,1.0471975511965976,0.0020394954667620627,
        0.3135107848381826,1.19679720136754,0.0020394954667620614,
        0.3135107848381826,1.3463968515384828,0.002039495466762062,
        0.3135107848381826,1.4959965017094252,0.0020394954667620636,
        0.3135107848381826,1.645596151880368,0.002039495466762062,
        0.3135107848381826,1.7951958020513104,0.002039495466762062,
        0.3135107848381826,1.944795452222253,0.002039495466762061,
        0.3135107848381826,2.0943951023931953,0.002039495466762061,
        0.3135107848381826,2.243994752564138,0.00203949546676206,0.3135107848381826,
        2.39359440273508,0.002039495466762062,0.3135107848381826,2.543194052906023,
        0.002039495466762063,0.3135107848381826,2.6927937030769655,
        0.0020394954667620636,0.3135107848381826,2.842393353247908,
        0.0020394954667620636,0.3135107848381826,2.9919930034188504,
        0.0020394954667620614,0.3135107848381826,3.141592653589793,
        0.00203949546676206,0.3135107848381826,3.291192303760736,
        0.002039495466762062,0.3135107848381826,3.4407919539316785,
        0.002039495466762061,0.3135107848381826,3.5903916041026207,
        0.0020394954667620623,0.3135107848381826,3.7399912542735634,
        0.0020394954667620614,0.3135107848381826,3.889590904444506,
        0.0020394954667620597,0.3135107848381826,4.039190554615448,
        0.0020394954667620597,0.3135107848381826,4.1887902047863905,
        0.0020394954667620614,0.3135107848381826,4.338389854957334,
        0.0020394954667620627,0.3135107848381826,4.487989505128276,
        0.0020394954667620623,0.3135107848381826,4.637589155299219,
        0.002039495466762061,0.3135107848381826,4.78718880547016,
        0.0020394954667620614,0.3135107848381826,4.9367884556411035,
        0.0020394954667620623,0.3135107848381826,5.086388105812046,
        0.0020394954667620623,0.3135107848381826,5.235987755982989,
        0.0020394954667620644,0.3135107848381826,5.385587406153931,
        0.0020394954667620623,0.3135107848381826,5.535187056324873,
        0.0020394954667620605,0.3135107848381826,5.684786706495816,
        0.0020394954667620597,0.3135107848381826,5.834386356666759,
        0.002039495466762059,0.3135107848381826,5.983986006837701,
        0.002039495466762063,0.3135107848381826,6.133585657008643,
        0.002039495466762064,0.44611778597484897,0.,0.0027245967124665395,
        0.44611778597484897,0.1495996501709425,0.0027245967124665325,
        0.44611778597484897,0.299199300341885,0.002724596712466525,
        0.44611778597484897,0.4487989505128276,0.0027245967124665256,
        0.44611778597484897,0.59839860068377,0.00272459671246653,
        0.44611778597484897,0.7479982508547126,0.00272459671246653,
        0.44611778597484897,0.8975979010256552,0.00272459671246653,
        0.44611778597484897,1.0471975511965976,0.0027245967124665304,
        0.44611778597484897,1.19679720136754,0.0027245967124665273,
        0.44611778597484897,1.3463968515384828,0.002724596712466528,
        0.44611778597484897,1.4959965017094252,0.0027245967124665295,
        0.44611778597484897,1.645596151880368,0.0027245967124665325,
        0.44611778597484897,1.7951958020513104,0.002724596712466532,
        0.44611778597484897,1.944795452222253,0.002724596712466531,
        0.44611778597484897,2.0943951023931953,0.0027245967124665278,
        0.44611778597484897,2.243994752564138,0.002724596712466526,
        0.44611778597484897,2.39359440273508,0.002724596712466528,
        0.44611778597484897,2.543194052906023,0.002724596712466532,
        0.44611778597484897,2.6927937030769655,0.0027245967124665334,
        0.44611778597484897,2.842393353247908,0.0027245967124665304,
        0.44611778597484897,2.9919930034188504,0.0027245967124665256,
        0.44611778597484897,3.141592653589793,0.002724596712466525,
        0.44611778597484897,3.291192303760736,0.00272459671246653,
        0.44611778597484897,3.4407919539316785,0.0027245967124665312,
        0.44611778597484897,3.5903916041026207,0.002724596712466531,
        0.44611778597484897,3.7399912542735634,0.002724596712466528,
        0.44611778597484897,3.889590904444506,0.002724596712466524,
        0.44611778597484897,4.039190554615448,0.0027245967124665256,
        0.44611778597484897,4.1887902047863905,0.00272459671246653,
        0.44611778597484897,4.338389854957334,0.0027245967124665343,
        0.44611778597484897,4.487989505128276,0.0027245967124665334,
        0.44611778597484897,4.637589155299219,0.0027245967124665247,
        0.44611778597484897,4.78718880547016,0.002724596712466523,
        0.44611778597484897,4.9367884556411035,0.002724596712466529,
        0.44611778597484897,5.086388105812046,0.002724596712466532,
        0.44611778597484897,5.235987755982989,0.0027245967124665295,
        0.44611778597484897,5.385587406153931,0.002724596712466532,
        0.44611778597484897,5.535187056324873,0.002724596712466531,
        0.44611778597484897,5.684786706495816,0.002724596712466527,
        0.44611778597484897,5.834386356666759,0.0027245967124665195,
        0.44611778597484897,5.983986006837701,0.0027245967124665247,
        0.44611778597484897,6.133585657008643,0.002724596712466535,
        0.5692587621840659,0.,0.0031888938832390435,0.5692587621840659,
        0.1495996501709425,0.003188893883239026,0.5692587621840659,
        0.299199300341885,0.0031888938832390183,0.5692587621840659,
        0.4487989505128276,0.0031888938832390283,0.5692587621840659,
        0.59839860068377,0.0031888938832390305,0.5692587621840659,
        0.7479982508547126,0.0031888938832390244,0.5692587621840659,
        0.8975979010256552,0.0031888938832390257,0.5692587621840659,
        1.0471975511965976,0.0031888938832390296,0.5692587621840659,
        1.19679720136754,0.003188893883239026,0.5692587621840659,1.3463968515384828,
        0.0031888938832390253,0.5692587621840659,1.4959965017094252,
        0.0031888938832390274,0.5692587621840659,1.645596151880368,
        0.0031888938832390287,0.5692587621840659,1.7951958020513104,
        0.0031888938832390253,0.5692587621840659,1.944795452222253,
        0.0031888938832390244,0.5692587621840659,2.0943951023931953,
        0.003188893883239025,0.5692587621840659,2.243994752564138,
        0.003188893883239022,0.5692587621840659,2.39359440273508,
        0.003188893883239021,0.5692587621840659,2.543194052906023,
        0.0031888938832390287,0.5692587621840659,2.6927937030769655,
        0.0031888938832390335,0.5692587621840659,2.842393353247908,
        0.0031888938832390257,0.5692587621840659,2.9919930034188504,
        0.0031888938832390205,0.5692587621840659,3.141592653589793,
        0.0031888938832390235,0.5692587621840659,3.291192303760736,
        0.0031888938832390287,0.5692587621840659,3.4407919539316785,
        0.003188893883239026,0.5692587621840659,3.5903916041026207,
        0.0031888938832390222,0.5692587621840659,3.7399912542735634,
        0.0031888938832390287,0.5692587621840659,3.889590904444506,
        0.0031888938832390253,0.5692587621840659,4.039190554615448,
        0.003188893883239015,0.5692587621840659,4.1887902047863905,
        0.00318889388323902,0.5692587621840659,4.338389854957334,
        0.0031888938832390357,0.5692587621840659,4.487989505128276,
        0.003188893883239032,0.5692587621840659,4.637589155299219,
        0.0031888938832390135,0.5692587621840659,4.78718880547016,
        0.003188893883239015,0.5692587621840659,4.9367884556411035,
        0.0031888938832390326,0.5692587621840659,5.086388105812046,
        0.0031888938832390344,0.5692587621840659,5.235987755982989,
        0.003188893883239019,0.5692587621840659,5.385587406153931,
        0.0031888938832390196,0.5692587621840659,5.535187056324873,
        0.0031888938832390365,0.5692587621840659,5.684786706495816,
        0.0031888938832390313,0.5692587621840659,5.834386356666759,
        0.0031888938832390105,0.5692587621840659,5.983986006837701,
        0.0031888938832390127,0.5692587621840659,6.133585657008643,
        0.0031888938832390383,0.6806329659106584,0.,0.0033948281421183994,
        0.6806329659106584,0.1495996501709425,0.003394828142118376,
        0.6806329659106584,0.299199300341885,0.0033948281421183678,
        0.6806329659106584,0.4487989505128276,0.003394828142118385,
        0.6806329659106584,0.59839860068377,0.0033948281421183808,
        0.6806329659106584,0.7479982508547126,0.0033948281421183695,
        0.6806329659106584,0.8975979010256552,0.003394828142118379,
        0.6806329659106584,1.0471975511965976,0.0033948281421183847,
        0.6806329659106584,1.19679720136754,0.0033948281421183747,
        0.6806329659106584,1.3463968515384828,0.003394828142118373,
        0.6806329659106584,1.4959965017094252,0.0033948281421183786,
        0.6806329659106584,1.645596151880368,0.0033948281421183795,
        0.6806329659106584,1.7951958020513104,0.003394828142118376,
        0.6806329659106584,1.944795452222253,0.003394828142118374,
        0.6806329659106584,2.0943951023931953,0.0033948281421183764,
        0.6806329659106584,2.243994752564138,0.0033948281421183725,
        0.6806329659106584,2.39359440273508,0.003394828142118369,0.6806329659106584,
        2.543194052906023,0.0033948281421183816,0.6806329659106584,
        2.6927937030769655,0.0033948281421183847,0.6806329659106584,
        2.842393353247908,0.003394828142118373,0.6806329659106584,
        2.9919930034188504,0.003394828142118371,0.6806329659106584,
        3.141592653589793,0.0033948281421183717,0.6806329659106584,
        3.291192303760736,0.003394828142118378,0.6806329659106584,
        3.4407919539316785,0.0033948281421183773,0.6806329659106584,
        3.5903916041026207,0.003394828142118372,0.6806329659106584,
        3.7399912542735634,0.0033948281421183773,0.6806329659106584,
        3.889590904444506,0.0033948281421183795,0.6806329659106584,
        4.039190554615448,0.003394828142118366,0.6806329659106584,
        4.1887902047863905,0.0033948281421183712,0.6806329659106584,
        4.338389854957334,0.0033948281421183903,0.6806329659106584,
        4.487989505128276,0.0033948281421183886,0.6806329659106584,
        4.637589155299219,0.0033948281421183643,0.6806329659106584,4.78718880547016,
        0.003394828142118364,0.6806329659106584,4.9367884556411035,
        0.0033948281421183855,0.6806329659106584,5.086388105812046,
        0.0033948281421183877,0.6806329659106584,5.235987755982989,
        0.0033948281421183725,0.6806329659106584,5.385587406153931,
        0.0033948281421183704,0.6806329659106584,5.535187056324873,
        0.003394828142118388,0.6806329659106584,5.684786706495816,
        0.0033948281421183847,0.6806329659106584,5.834386356666759,
        0.00339482814211836,0.6806329659106584,5.983986006837701,
        0.003394828142118364,0.6806329659106584,6.133585657008643,
        0.003394828142118394,0.7780489400508256,0.,0.0033257301560348043,
        0.7780489400508256,0.1495996501709425,0.0033257301560347813,
        0.7780489400508256,0.299199300341885,0.0033257301560347735,
        0.7780489400508256,0.4487989505128276,0.0033257301560347895,
        0.7780489400508256,0.59839860068377,0.003325730156034784,0.7780489400508256,
        0.7479982508547126,0.0033257301560347756,0.7780489400508256,
        0.8975979010256552,0.0033257301560347874,0.7780489400508256,
        1.0471975511965976,0.0033257301560347813,0.7780489400508256,
        1.19679720136754,0.0033257301560347782,0.7780489400508256,
        1.3463968515384828,0.0033257301560347813,0.7780489400508256,
        1.4959965017094252,0.0033257301560347826,0.7780489400508256,
        1.645596151880368,0.0033257301560347835,0.7780489400508256,
        1.7951958020513104,0.0033257301560347813,0.7780489400508256,
        1.944795452222253,0.003325730156034779,0.7780489400508256,
        2.0943951023931953,0.00332573015603478,0.7780489400508256,2.243994752564138,
        0.003325730156034779,0.7780489400508256,2.39359440273508,
        0.003325730156034773,0.7780489400508256,2.543194052906023,
        0.003325730156034786,0.7780489400508256,2.6927937030769655,
        0.0033257301560347913,0.7780489400508256,2.842393353247908,
        0.003325730156034776,0.7780489400508256,2.9919930034188504,
        0.0033257301560347826,0.7780489400508256,3.141592653589793,
        0.0033257301560347804,0.7780489400508256,3.291192303760736,
        0.0033257301560347817,0.7780489400508256,3.4407919539316785,
        0.00332573015603479,0.7780489400508256,3.5903916041026207,
        0.0033257301560347782,0.7780489400508256,3.7399912542735634,
        0.003325730156034783,0.7780489400508256,3.889590904444506,
        0.0033257301560347848,0.7780489400508256,4.039190554615448,
        0.0033257301560347717,0.7780489400508256,4.1887902047863905,
        0.003325730156034781,0.7780489400508256,4.338389854957334,
        0.003325730156034789,0.7780489400508256,4.487989505128276,
        0.0033257301560347917,0.7780489400508256,4.637589155299219,
        0.0033257301560347696,0.7780489400508256,4.78718880547016,
        0.003325730156034772,0.7780489400508256,4.9367884556411035,
        0.0033257301560347904,0.7780489400508256,5.086388105812046,
        0.003325730156034785,0.7780489400508256,5.235987755982989,
        0.0033257301560347813,0.7780489400508256,5.385587406153931,
        0.0033257301560347748,0.7780489400508256,5.535187056324873,
        0.0033257301560347926,0.7780489400508256,5.684786706495816,
        0.003325730156034789,0.7780489400508256,5.834386356666759,
        0.0033257301560347665,0.7780489400508256,5.983986006837701,
        0.0033257301560347717,0.7780489400508256,6.133585657008643,
        0.0033257301560347917,0.859558214428519,0.,0.0029872068773049328,
        0.859558214428519,0.1495996501709425,0.0029872068773049085,
        0.859558214428519,0.299199300341885,0.0029872068773049015,0.859558214428519,
        0.4487989505128276,0.002987206877304918,0.859558214428519,0.59839860068377,
        0.0029872068773049137,0.859558214428519,0.7479982508547126,
        0.002987206877304904,0.859558214428519,0.8975979010256552,
        0.0029872068773049132,0.859558214428519,1.0471975511965976,
        0.0029872068773049106,0.859558214428519,1.19679720136754,
        0.0029872068773049106,0.859558214428519,1.3463968515384828,
        0.0029872068773049063,0.859558214428519,1.4959965017094252,
        0.002987206877304911,0.859558214428519,1.645596151880368,
        0.0029872068773049132,0.859558214428519,1.7951958020513104,
        0.0029872068773049106,0.859558214428519,1.944795452222253,
        0.0029872068773049106,0.859558214428519,2.0943951023931953,
        0.0029872068773049063,0.859558214428519,2.243994752564138,
        0.0029872068773049124,0.859558214428519,2.39359440273508,
        0.0029872068773049024,0.859558214428519,2.543194052906023,
        0.002987206877304915,0.859558214428519,2.6927937030769655,
        0.002987206877304922,0.859558214428519,2.842393353247908,
        0.002987206877304902,0.859558214428519,2.9919930034188504,
        0.0029872068773049085,0.859558214428519,3.141592653589793,
        0.002987206877304908,0.859558214428519,3.291192303760736,
        0.0029872068773049076,0.859558214428519,3.4407919539316785,
        0.0029872068773049197,0.859558214428519,3.5903916041026207,
        0.0029872068773049,0.859558214428519,3.7399912542735634,
        0.0029872068773049154,0.859558214428519,3.889590904444506,
        0.0029872068773049154,0.859558214428519,4.039190554615448,
        0.002987206877304895,0.859558214428519,4.1887902047863905,
        0.0029872068773049137,0.859558214428519,4.338389854957334,
        0.002987206877304912,0.859558214428519,4.487989505128276,
        0.002987206877304928,0.859558214428519,4.637589155299219,
        0.002987206877304892,0.859558214428519,4.78718880547016,
        0.0029872068773048976,0.859558214428519,4.9367884556411035,
        0.0029872068773049236,0.859558214428519,5.086388105812046,
        0.0029872068773049085,0.859558214428519,5.235987755982989,
        0.0029872068773049163,0.859558214428519,5.385587406153931,
        0.002987206877304895,0.859558214428519,5.535187056324873,
        0.0029872068773049267,0.859558214428519,5.684786706495816,
        0.0029872068773049167,0.859558214428519,5.834386356666759,
        0.002987206877304896,0.859558214428519,5.983986006837701,
        0.0029872068773049033,0.859558214428519,6.133585657008643,
        0.002987206877304921,0.92351965347627,0.,0.0024067036731296987,
        0.92351965347627,0.1495996501709425,0.0024067036731296727,0.92351965347627,
        0.299199300341885,0.0024067036731296775,0.92351965347627,0.4487989505128276,
        0.002406703673129677,0.92351965347627,0.59839860068377,
        0.0024067036731296844,0.92351965347627,0.7479982508547126,
        0.002406703673129672,0.92351965347627,0.8975979010256552,
        0.0024067036731296836,0.92351965347627,1.0471975511965976,
        0.002406703673129679,0.92351965347627,1.19679720136754,0.002406703673129678,
        0.92351965347627,1.3463968515384828,0.002406703673129678,0.92351965347627,
        1.4959965017094252,0.002406703673129681,0.92351965347627,1.645596151880368,
        0.0024067036731296805,0.92351965347627,1.7951958020513104,
        0.0024067036731296758,0.92351965347627,1.944795452222253,
        0.0024067036731296805,0.92351965347627,2.0943951023931953,
        0.0024067036731296744,0.92351965347627,2.243994752564138,
        0.002406703673129677,0.92351965347627,2.39359440273508,
        0.0024067036731296714,0.92351965347627,2.543194052906023,
        0.002406703673129682,0.92351965347627,2.6927937030769655,
        0.0024067036731296853,0.92351965347627,2.842393353247908,
        0.0024067036731296766,0.92351965347627,2.9919930034188504,
        0.002406703673129676,0.92351965347627,3.141592653589793,0.00240670367312968,
        0.92351965347627,3.291192303760736,0.0024067036731296744,0.92351965347627,
        3.4407919539316785,0.0024067036731296888,0.92351965347627,
        3.5903916041026207,0.002406703673129673,0.92351965347627,3.7399912542735634,
        0.0024067036731296805,0.92351965347627,3.889590904444506,
        0.002406703673129686,0.92351965347627,4.039190554615448,
        0.002406703673129663,0.92351965347627,4.1887902047863905,
        0.002406703673129692,0.92351965347627,4.338389854957334,
        0.0024067036731296723,0.92351965347627,4.487989505128276,
        0.002406703673129698,0.92351965347627,4.637589155299219,
        0.0024067036731296658,0.92351965347627,4.78718880547016,
        0.0024067036731296714,0.92351965347627,4.9367884556411035,
        0.0024067036731296922,0.92351965347627,5.086388105812046,
        0.002406703673129671,0.92351965347627,5.235987755982989,
        0.0024067036731296927,0.92351965347627,5.385587406153931,
        0.0024067036731296614,0.92351965347627,5.535187056324873,
        0.0024067036731296987,0.92351965347627,5.684786706495816,
        0.002406703673129678,0.92351965347627,5.834386356666759,
        0.0024067036731296714,0.92351965347627,5.983986006837701,
        0.002406703673129673,0.92351965347627,6.133585657008643,
        0.002406703673129685,0.9686423117554033,0.,0.0016313533587078495,
        0.9686423117554033,0.1495996501709425,0.0016313533587078305,
        0.9686423117554033,0.299199300341885,0.0016313533587078376,
        0.9686423117554033,0.4487989505128276,0.001631353358707834,
        0.9686423117554033,0.59839860068377,0.0016313533587078424,
        0.9686423117554033,0.7479982508547126,0.0016313533587078296,
        0.9686423117554033,0.8975979010256552,0.0016313533587078398,
        0.9686423117554033,1.0471975511965976,0.0016313533587078348,
        0.9686423117554033,1.19679720136754,0.0016313533587078359,
        0.9686423117554033,1.3463968515384828,0.0016313533587078348,
        0.9686423117554033,1.4959965017094252,0.0016313533587078357,
        0.9686423117554033,1.645596151880368,0.0016313533587078363,
        0.9686423117554033,1.7951958020513104,0.001631353358707839,
        0.9686423117554033,1.944795452222253,0.0016313533587078322,
        0.9686423117554033,2.0943951023931953,0.00163135335870784,
        0.9686423117554033,2.243994752564138,0.0016313533587078329,
        0.9686423117554033,2.39359440273508,0.0016313533587078344,
        0.9686423117554033,2.543194052906023,0.0016313533587078378,
        0.9686423117554033,2.6927937030769655,0.0016313533587078396,
        0.9686423117554033,2.842393353247908,0.001631353358707836,
        0.9686423117554033,2.9919930034188504,0.0016313533587078324,
        0.9686423117554033,3.141592653589793,0.0016313533587078394,
        0.9686423117554033,3.291192303760736,0.0016313533587078329,
        0.9686423117554033,3.4407919539316785,0.0016313533587078396,
        0.9686423117554033,3.5903916041026207,0.0016313533587078348,
        0.9686423117554033,3.7399912542735634,0.001631353358707834,
        0.9686423117554033,3.889590904444506,0.0016313533587078446,
        0.9686423117554033,4.039190554615448,0.0016313533587078233,
        0.9686423117554033,4.1887902047863905,0.0016313533587078424,
        0.9686423117554033,4.338389854957334,0.0016313533587078324,
        0.9686423117554033,4.487989505128276,0.0016313533587078504,
        0.9686423117554033,4.637589155299219,0.0016313533587078261,
        0.9686423117554033,4.78718880547016,0.0016313533587078311,
        0.9686423117554033,4.9367884556411035,0.0016313533587078448,
        0.9686423117554033,5.086388105812046,0.0016313533587078326,
        0.9686423117554033,5.235987755982989,0.0016313533587078467,
        0.9686423117554033,5.385587406153931,0.001631353358707822,
        0.9686423117554033,5.535187056324873,0.0016313533587078543,
        0.9686423117554033,5.684786706495816,0.001631353358707831,
        0.9686423117554033,5.834386356666759,0.0016313533587078346,
        0.9686423117554033,5.983986006837701,0.0016313533587078276,
        0.9686423117554033,6.133585657008643,0.0016313533587078426,
        0.9940233330096353,0.,0.0007252987834842469,0.9940233330096353,
        0.1495996501709425,0.0007252987834842459,0.9940233330096353,
        0.299199300341885,0.0007252987834842402,0.9940233330096353,
        0.4487989505128276,0.0007252987834842464,0.9940233330096353,
        0.59839860068377,0.0007252987834842431,0.9940233330096353,
        0.7479982508547126,0.0007252987834842415,0.9940233330096353,
        0.8975979010256552,0.0007252987834842436,0.9940233330096353,
        1.0471975511965976,0.0007252987834842426,0.9940233330096353,
        1.19679720136754,0.0007252987834842447,0.9940233330096353,
        1.3463968515384828,0.0007252987834842418,0.9940233330096353,
        1.4959965017094252,0.0007252987834842465,0.9940233330096353,
        1.645596151880368,0.000725298783484241,0.9940233330096353,
        1.7951958020513104,0.0007252987834842445,0.9940233330096353,
        1.944795452222253,0.0007252987834842398,0.9940233330096353,
        2.0943951023931953,0.0007252987834842422,0.9940233330096353,
        2.243994752564138,0.0007252987834842391,0.9940233330096353,2.39359440273508,
        0.000725298783484242,0.9940233330096353,2.543194052906023,
        0.0007252987834842402,0.9940233330096353,2.6927937030769655,
        0.0007252987834842466,0.9940233330096353,2.842393353247908,
        0.0007252987834842376,0.9940233330096353,2.9919930034188504,
        0.000725298783484245,0.9940233330096353,3.141592653589793,
        0.0007252987834842388,0.9940233330096353,3.291192303760736,
        0.0007252987834842434,0.9940233330096353,3.4407919539316785,
        0.0007252987834842428,0.9940233330096353,3.5903916041026207,
        0.0007252987834842411,0.9940233330096353,3.7399912542735634,
        0.0007252987834842431,0.9940233330096353,3.889590904444506,
        0.0007252987834842426,0.9940233330096353,4.039190554615448,
        0.00072529878348424,0.9940233330096353,4.1887902047863905,
        0.0007252987834842434,0.9940233330096353,4.338389854957334,
        0.000725298783484245,0.9940233330096353,4.487989505128276,
        0.0007252987834842445,0.9940233330096353,4.637589155299219,
        0.0007252987834842419,0.9940233330096353,4.78718880547016,
        0.0007252987834842363,0.9940233330096353,4.9367884556411035,
        0.0007252987834842497,0.9940233330096353,5.086388105812046,
        0.0007252987834842393,0.9940233330096353,5.235987755982989,
        0.0007252987834842485,0.9940233330096353,5.385587406153931,
        0.0007252987834842382,0.9940233330096353,5.535187056324873,
        0.0007252987834842487,0.9940233330096353,5.684786706495816,
        0.000725298783484243,0.9940233330096353,5.834386356666759,
        0.0007252987834842428,0.9940233330096353,5.983986006837701,
        0.0007252987834842405,0.9940233330096353,6.133585657008643,
        0.0007252987834842485,0.10433441870721044,0.,0.0006325973535851173,
        0.10433441870721044,0.14279966607226333,0.0006325973535851252,
        0.10433441870721044,0.28559933214452665,0.0006325973535851211,
        0.10433441870721044,0.42839899821678995,0.0006325973535851201,
        0.10433441870721044,0.5711986642890533,0.00063259735358512,
        0.10433441870721044,0.7139983303613165,0.0006325973535851209,
        0.10433441870721044,0.8567979964335799,0.0006325973535851206,
        0.10433441870721044,0.9995976625058433,0.0006325973535851205,
        0.10433441870721044,1.1423973285781066,0.0006325973535851217,
        0.10433441870721044,1.28519699465037,0.0006325973535851216,
        0.10433441870721044,1.427996660722633,0.0006325973535851219,
        0.10433441870721044,1.5707963267948966,0.0006325973535851219,
        0.10433441870721044,1.7135959928671598,0.0006325973535851229,
        0.10433441870721044,1.8563956589394233,0.0006325973535851234,
        0.10433441870721044,1.9991953250116865,0.0006325973535851226,
        0.10433441870721044,2.1419949910839495,0.0006325973535851231,
        0.10433441870721044,2.284794657156213,0.0006325973535851236,
        0.10433441870721044,2.4275943232284765,0.0006325973535851229,
        0.10433441870721044,2.57039398930074,0.000632597353585123,
        0.10433441870721044,2.7131936553730034,0.0006325973535851223,
        0.10433441870721044,2.855993321445266,0.0006325973535851241,
        0.10433441870721044,2.99879298751753,0.0006325973535851229,
        0.10433441870721044,3.141592653589793,0.0006325973535851235,
        0.10433441870721044,3.2843923196620564,0.0006325973535851225,
        0.10433441870721044,3.4271919857343196,0.0006325973535851231,
        0.10433441870721044,3.5699916518065833,0.0006325973535851228,
        0.10433441870721044,3.7127913178788465,0.0006325973535851225,
        0.10433441870721044,3.8555909839511098,0.000632597353585123,
        0.10433441870721044,3.998390650023373,0.0006325973535851219,
        0.10433441870721044,4.141190316095636,0.0006325973535851229,
        0.10433441870721044,4.283989982167899,0.0006325973535851235,
        0.10433441870721044,4.426789648240163,0.0006325973535851231,
        0.10433441870721044,4.569589314312426,0.0006325973535851231,
        0.10433441870721044,4.71238898038469,0.0006325973535851225,
        0.10433441870721044,4.855188646456953,0.0006325973535851224,
        0.10433441870721044,4.997988312529216,0.0006325973535851225,
        0.10433441870721044,5.14078797860148,0.0006325973535851224,
        0.10433441870721044,5.2835876446737435,0.0006325973535851223,
        0.10433441870721044,5.426387310746007,0.0006325973535851224,
        0.10433441870721044,5.569186976818269,0.0006325973535851222,
        0.10433441870721044,5.711986642890532,0.0006325973535851215,
        0.10433441870721044,5.854786308962796,0.0006325973535851203,
        0.10433441870721044,5.99758597503506,0.0006325973535851218,
        0.10433441870721044,6.140385641107323,0.0006325973535851208,
        0.23763143755814875,0.,0.001427049653038027,0.23763143755814875,
        0.14279966607226333,0.001427049653038027,0.23763143755814875,
        0.28559933214452665,0.0014270496530380255,0.23763143755814875,
        0.42839899821678995,0.0014270496530380252,0.23763143755814875,
        0.5711986642890533,0.001427049653038025,0.23763143755814875,
        0.7139983303613165,0.001427049653038025,0.23763143755814875,
        0.8567979964335799,0.0014270496530380257,0.23763143755814875,
        0.9995976625058433,0.001427049653038026,0.23763143755814875,
        1.1423973285781066,0.001427049653038027,0.23763143755814875,
        1.28519699465037,0.001427049653038027,0.23763143755814875,1.427996660722633,
        0.0014270496530380276,0.23763143755814875,1.5707963267948966,
        0.001427049653038028,0.23763143755814875,1.7135959928671598,
        0.0014270496530380274,0.23763143755814875,1.8563956589394233,
        0.001427049653038027,0.23763143755814875,1.9991953250116865,
        0.0014270496530380265,0.23763143755814875,2.1419949910839495,
        0.0014270496530380268,0.23763143755814875,2.284794657156213,
        0.001427049653038027,0.23763143755814875,2.4275943232284765,
        0.0014270496530380283,0.23763143755814875,2.57039398930074,
        0.0014270496530380278,0.23763143755814875,2.7131936553730034,
        0.0014270496530380278,0.23763143755814875,2.855993321445266,
        0.0014270496530380276,0.23763143755814875,2.99879298751753,
        0.0014270496530380283,0.23763143755814875,3.141592653589793,
        0.0014270496530380283,0.23763143755814875,3.2843923196620564,
        0.001427049653038028,0.23763143755814875,3.4271919857343196,
        0.0014270496530380294,0.23763143755814875,3.5699916518065833,
        0.0014270496530380298,0.23763143755814875,3.7127913178788465,
        0.0014270496530380291,0.23763143755814875,3.8555909839511098,
        0.0014270496530380276,0.23763143755814875,3.998390650023373,
        0.0014270496530380268,0.23763143755814875,4.141190316095636,
        0.0014270496530380261,0.23763143755814875,4.283989982167899,
        0.0014270496530380263,0.23763143755814875,4.426789648240163,
        0.0014270496530380274,0.23763143755814875,4.569589314312426,
        0.0014270496530380274,0.23763143755814875,4.71238898038469,
        0.0014270496530380285,0.23763143755814875,4.855188646456953,
        0.001427049653038028,0.23763143755814875,4.997988312529216,
        0.0014270496530380268,0.23763143755814875,5.14078797860148,
        0.001427049653038025,0.23763143755814875,5.2835876446737435,
        0.001427049653038024,0.23763143755814875,5.426387310746007,
        0.001427049653038024,0.23763143755814875,5.569186976818269,
        0.0014270496530380242,0.23763143755814875,5.711986642890532,
        0.001427049653038025,0.23763143755814875,5.854786308962796,
        0.0014270496530380272,0.23763143755814875,5.99758597503506,
        0.0014270496530380274,0.23763143755814875,6.140385641107323,
        0.0014270496530380276,0.36732002016358345,0.,0.002116934215033443,
        0.36732002016358345,0.14279966607226333,0.002116934215033441,
        0.36732002016358345,0.28559933214452665,0.002116934215033443,
        0.36732002016358345,0.42839899821678995,0.0021169342150334437,
        0.36732002016358345,0.5711986642890533,0.002116934215033444,
        0.36732002016358345,0.7139983303613165,0.002116934215033442,
        0.36732002016358345,0.8567979964335799,0.002116934215033443,
        0.36732002016358345,0.9995976625058433,0.002116934215033443,
        0.36732002016358345,1.1423973285781066,0.002116934215033446,
        0.36732002016358345,1.28519699465037,0.0021169342150334455,
        0.36732002016358345,1.427996660722633,0.0021169342150334455,
        0.36732002016358345,1.5707963267948966,0.002116934215033445,
        0.36732002016358345,1.7135959928671598,0.002116934215033445,
        0.36732002016358345,1.8563956589394233,0.0021169342150334437,
        0.36732002016358345,1.9991953250116865,0.002116934215033442,
        0.36732002016358345,2.1419949910839495,0.0021169342150334433,
        0.36732002016358345,2.284794657156213,0.0021169342150334468,
        0.36732002016358345,2.4275943232284765,0.0021169342150334485,
        0.36732002016358345,2.57039398930074,0.0021169342150334455,
        0.36732002016358345,2.7131936553730034,0.002116934215033446,
        0.36732002016358345,2.855993321445266,0.002116934215033443,
        0.36732002016358345,2.99879298751753,0.0021169342150334437,
        0.36732002016358345,3.141592653589793,0.0021169342150334424,
        0.36732002016358345,3.2843923196620564,0.002116934215033444,
        0.36732002016358345,3.4271919857343196,0.0021169342150334468,
        0.36732002016358345,3.5699916518065833,0.0021169342150334476,
        0.36732002016358345,3.7127913178788465,0.0021169342150334476,
        0.36732002016358345,3.8555909839511098,0.002116934215033445,
        0.36732002016358345,3.998390650023373,0.0021169342150334424,
        0.36732002016358345,4.141190316095636,0.002116934215033442,
        0.36732002016358345,4.283989982167899,0.0021169342150334433,
        0.36732002016358345,4.426789648240163,0.0021169342150334455,
        0.36732002016358345,4.569589314312426,0.002116934215033445,
        0.36732002016358345,4.71238898038469,0.0021169342150334455,
        0.36732002016358345,4.855188646456953,0.0021169342150334468,
        0.36732002016358345,4.997988312529216,0.002116934215033449,
        0.36732002016358345,5.14078797860148,0.002116934215033446,
        0.36732002016358345,5.2835876446737435,0.002116934215033441,
        0.36732002016358345,5.426387310746007,0.002116934215033436,
        0.36732002016358345,5.569186976818269,0.002116934215033438,
        0.36732002016358345,5.711986642890532,0.0021169342150334437,
        0.36732002016358345,5.854786308962796,0.0021169342150334494,
        0.36732002016358345,5.99758597503506,0.0021169342150334494,
        0.36732002016358345,6.140385641107323,0.0021169342150334468,
        0.4903589862504756,0.,0.0026499291431740708,0.4903589862504756,
        0.14279966607226333,0.002649929143174071,0.4903589862504756,
        0.28559933214452665,0.0026499291431740755,0.4903589862504756,
        0.42839899821678995,0.002649929143174078,0.4903589862504756,
        0.5711986642890533,0.002649929143174077,0.4903589862504756,
        0.7139983303613165,0.002649929143174072,0.4903589862504756,
        0.8567979964335799,0.0026499291431740708,0.4903589862504756,
        0.9995976625058433,0.0026499291431740755,0.4903589862504756,
        1.1423973285781066,0.0026499291431740803,0.4903589862504756,
        1.28519699465037,0.002649929143174079,0.4903589862504756,1.427996660722633,
        0.0026499291431740755,0.4903589862504756,1.5707963267948966,
        0.002649929143174079,0.4903589862504756,1.7135959928671598,
        0.002649929143174083,0.4903589862504756,1.8563956589394233,
        0.00264992914317408,0.4903589862504756,1.9991953250116865,
        0.002649929143174072,0.4903589862504756,2.1419949910839495,
        0.0026499291431740734,0.4903589862504756,2.284794657156213,
        0.002649929143174083,0.4903589862504756,2.4275943232284765,
        0.002649929143174087,0.4903589862504756,2.57039398930074,
        0.0026499291431740803,0.4903589862504756,2.7131936553730034,
        0.0026499291431740755,0.4903589862504756,2.855993321445266,
        0.002649929143174079,0.4903589862504756,2.99879298751753,
        0.002649929143174082,0.4903589862504756,3.141592653589793,
        0.0026499291431740786,0.4903589862504756,3.2843923196620564,
        0.002649929143174078,0.4903589862504756,3.4271919857343196,
        0.002649929143174083,0.4903589862504756,3.5699916518065833,
        0.0026499291431740847,0.4903589862504756,3.7127913178788465,
        0.0026499291431740847,0.4903589862504756,3.8555909839511098,
        0.002649929143174078,0.4903589862504756,3.998390650023373,
        0.0026499291431740725,0.4903589862504756,4.141190316095636,
        0.0026499291431740742,0.4903589862504756,4.283989982167899,
        0.0026499291431740834,0.4903589862504756,4.426789648240163,
        0.0026499291431740842,0.4903589862504756,4.569589314312426,
        0.0026499291431740777,0.4903589862504756,4.71238898038469,
        0.002649929143174071,0.4903589862504756,4.855188646456953,
        0.0026499291431740764,0.4903589862504756,4.997988312529216,
        0.0026499291431740842,0.4903589862504756,5.14078797860148,
        0.0026499291431740847,0.4903589862504756,5.2835876446737435,
        0.002649929143174071,0.4903589862504756,5.426387310746007,
        0.0026499291431740625,0.4903589862504756,5.569186976818269,
        0.002649929143174065,0.4903589862504756,5.711986642890532,
        0.002649929143174076,0.4903589862504756,5.854786308962796,
        0.0026499291431740834,0.4903589862504756,5.99758597503506,
        0.0026499291431740834,0.4903589862504756,6.140385641107323,
        0.002649929143174077,0.6043413125244935,0.,0.002986415278416712,
        0.6043413125244935,0.14279966607226333,0.002986415278416713,
        0.6043413125244935,0.28559933214452665,0.0029864152784167142,
        0.6043413125244935,0.42839899821678995,0.002986415278416715,
        0.6043413125244935,0.5711986642890533,0.002986415278416718,
        0.6043413125244935,0.7139983303613165,0.0029864152784167142,
        0.6043413125244935,0.8567979964335799,0.002986415278416709,
        0.6043413125244935,0.9995976625058433,0.0029864152784167173,
        0.6043413125244935,1.1423973285781066,0.0029864152784167264,
        0.6043413125244935,1.28519699465037,0.00298641527841672,0.6043413125244935,
        1.427996660722633,0.0029864152784167116,0.6043413125244935,
        1.5707963267948966,0.002986415278416719,0.6043413125244935,
        1.7135959928671598,0.0029864152784167272,0.6043413125244935,
        1.8563956589394233,0.002986415278416721,0.6043413125244935,
        1.9991953250116865,0.002986415278416712,0.6043413125244935,
        2.1419949910839495,0.002986415278416713,0.6043413125244935,
        2.284794657156213,0.002986415278416727,0.6043413125244935,
        2.4275943232284765,0.0029864152784167333,0.6043413125244935,
        2.57039398930074,0.0029864152784167203,0.6043413125244935,
        2.7131936553730034,0.002986415278416713,0.6043413125244935,
        2.855993321445266,0.0029864152784167238,0.6043413125244935,2.99879298751753,
        0.0029864152784167277,0.6043413125244935,3.141592653589793,
        0.002986415278416717,0.6043413125244935,3.2843923196620564,
        0.0029864152784167186,0.6043413125244935,3.4271919857343196,
        0.002986415278416728,0.6043413125244935,3.5699916518065833,
        0.002986415278416726,0.6043413125244935,3.7127913178788465,
        0.0029864152784167246,0.6043413125244935,3.8555909839511098,
        0.0029864152784167255,0.6043413125244935,3.998390650023373,
        0.0029864152784167164,0.6043413125244935,4.141190316095636,
        0.002986415278416712,0.6043413125244935,4.283989982167899,
        0.002986415278416722,0.6043413125244935,4.426789648240163,
        0.002986415278416729,0.6043413125244935,4.569589314312426,
        0.0029864152784167225,0.6043413125244935,4.71238898038469,
        0.0029864152784167173,0.6043413125244935,4.855188646456953,
        0.00298641527841672,0.6043413125244935,4.997988312529216,
        0.0029864152784167286,0.6043413125244935,5.14078797860148,
        0.002986415278416727,0.6043413125244935,5.2835876446737435,
        0.0029864152784167134,0.6043413125244935,5.426387310746007,
        0.0029864152784167043,0.6043413125244935,5.569186976818269,
        0.0029864152784167073,0.6043413125244935,5.711986642890532,
        0.0029864152784167177,0.6043413125244935,5.854786308962796,
        0.0029864152784167246,0.6043413125244935,5.99758597503506,
        0.0029864152784167246,0.6043413125244935,6.140385641107323,
        0.0029864152784167186,0.7071067811865476,0.,0.0031014214407835815,
        0.7071067811865476,0.14279966607226333,0.0031014214407835824,
        0.7071067811865476,0.28559933214452665,0.003101421440783582,
        0.7071067811865476,0.42839899821678995,0.003101421440783585,
        0.7071067811865476,0.5711986642890533,0.003101421440783587,
        0.7071067811865476,0.7139983303613165,0.003101421440783583,
        0.7071067811865476,0.8567979964335799,0.0031014214407835746,
        0.7071067811865476,0.9995976625058433,0.00310142144078358,
        0.7071067811865476,1.1423973285781066,0.0031014214407835924,
        0.7071067811865476,1.28519699465037,0.003101421440783585,0.7071067811865476,
        1.427996660722633,0.0031014214407835785,0.7071067811865476,
        1.5707963267948966,0.003101421440783589,0.7071067811865476,
        1.7135959928671598,0.003101421440783592,0.7071067811865476,
        1.8563956589394233,0.0031014214407835846,0.7071067811865476,
        1.9991953250116865,0.0031014214407835807,0.7071067811865476,
        2.1419949910839495,0.003101421440783581,0.7071067811865476,
        2.284794657156213,0.00310142144078359,0.7071067811865476,2.4275943232284765,
        0.0031014214407835998,0.7071067811865476,2.57039398930074,
        0.0031014214407835924,0.7071067811865476,2.7131936553730034,
        0.003101421440783578,0.7071067811865476,2.855993321445266,
        0.0031014214407835924,0.7071067811865476,2.99879298751753,
        0.0031014214407835985,0.7071067811865476,3.141592653589793,
        0.0031014214407835802,0.7071067811865476,3.2843923196620564,
        0.003101421440783587,0.7071067811865476,3.4271919857343196,
        0.003101421440783603,0.7071067811865476,3.5699916518065833,
        0.0031014214407835933,0.7071067811865476,3.7127913178788465,
        0.0031014214407835885,0.7071067811865476,3.8555909839511098,
        0.003101421440783598,0.7071067811865476,3.998390650023373,
        0.003101421440783585,0.7071067811865476,4.141190316095636,
        0.0031014214407835763,0.7071067811865476,4.283989982167899,
        0.0031014214407835946,0.7071067811865476,4.426789648240163,
        0.0031014214407835937,0.7071067811865476,4.569589314312426,
        0.0031014214407835833,0.7071067811865476,4.71238898038469,
        0.0031014214407835833,0.7071067811865476,4.855188646456953,
        0.0031014214407835833,0.7071067811865476,4.997988312529216,
        0.003101421440783592,0.7071067811865476,5.14078797860148,
        0.0031014214407835937,0.7071067811865476,5.2835876446737435,
        0.0031014214407835776,0.7071067811865476,5.426387310746007,
        0.0031014214407835707,0.7071067811865476,5.569186976818269,
        0.0031014214407835737,0.7071067811865476,5.711986642890532,
        0.003101421440783583,0.7071067811865476,5.854786308962796,
        0.0031014214407835963,0.7071067811865476,5.99758597503506,
        0.0031014214407835954,0.7071067811865476,6.140385641107323,
        0.003101421440783587,0.796725534909088,0.,0.002986415278395917,
        0.796725534909088,0.14279966607226333,0.0029864152783959166,
        0.796725534909088,0.28559933214452665,0.002986415278395916,
        0.796725534909088,0.42839899821678995,0.0029864152783959253,
        0.796725534909088,0.5711986642890533,0.0029864152783959214,
        0.796725534909088,0.7139983303613165,0.0029864152783959192,
        0.796725534909088,0.8567979964335799,0.002986415278395919,0.796725534909088,
        0.9995976625058433,0.0029864152783959205,0.796725534909088,
        1.1423973285781066,0.0029864152783959388,0.796725534909088,1.28519699465037,
        0.002986415278395928,0.796725534909088,1.427996660722633,
        0.0029864152783959223,0.796725534909088,1.5707963267948966,
        0.002986415278395934,0.796725534909088,1.7135959928671598,
        0.002986415278395933,0.796725534909088,1.8563956589394233,
        0.002986415278395932,0.796725534909088,1.9991953250116865,
        0.0029864152783959223,0.796725534909088,2.1419949910839495,
        0.0029864152783959253,0.796725534909088,2.284794657156213,
        0.0029864152783959344,0.796725534909088,2.4275943232284765,
        0.002986415278395939,0.796725534909088,2.57039398930074,
        0.002986415278395939,0.796725534909088,2.7131936553730034,
        0.0029864152783959153,0.796725534909088,2.855993321445266,
        0.0029864152783959323,0.796725534909088,2.99879298751753,
        0.002986415278395942,0.796725534909088,3.141592653589793,
        0.002986415278395921,0.796725534909088,3.2843923196620564,
        0.0029864152783959275,0.796725534909088,3.4271919857343196,
        0.002986415278395941,0.796725534909088,3.5699916518065833,
        0.0029864152783959336,0.796725534909088,3.7127913178788465,
        0.0029864152783959314,0.796725534909088,3.8555909839511098,
        0.002986415278395938,0.796725534909088,3.998390650023373,
        0.002986415278395923,0.796725534909088,4.141190316095636,
        0.002986415278395913,0.796725534909088,4.283989982167899,
        0.0029864152783959396,0.796725534909088,4.426789648240163,
        0.0029864152783959327,0.796725534909088,4.569589314312426,
        0.002986415278395925,0.796725534909088,4.71238898038469,0.00298641527839593,
        0.796725534909088,4.855188646456953,0.002986415278395923,0.796725534909088,
        4.997988312529216,0.0029864152783959375,0.796725534909088,5.14078797860148,
        0.002986415278395937,0.796725534909088,5.2835876446737435,
        0.002986415278395917,0.796725534909088,5.426387310746007,
        0.0029864152783959127,0.796725534909088,5.569186976818269,
        0.0029864152783959123,0.796725534909088,5.711986642890532,
        0.002986415278395922,0.796725534909088,5.854786308962796,
        0.0029864152783959314,0.796725534909088,5.99758597503506,
        0.00298641527839593,0.796725534909088,6.140385641107323,
        0.002986415278395919,0.8715205474361496,0.,0.0026499291432083806,
        0.8715205474361496,0.14279966607226333,0.0026499291432083797,
        0.8715205474361496,0.28559933214452665,0.002649929143208377,
        0.8715205474361496,0.42839899821678995,0.002649929143208384,
        0.8715205474361496,0.5711986642890533,0.002649929143208381,
        0.8715205474361496,0.7139983303613165,0.0026499291432083775,
        0.8715205474361496,0.8567979964335799,0.002649929143208378,
        0.8715205474361496,0.9995976625058433,0.0026499291432083736,
        0.8715205474361496,1.1423973285781066,0.0026499291432083905,
        0.8715205474361496,1.28519699465037,0.002649929143208385,0.8715205474361496,
        1.427996660722633,0.002649929143208376,0.8715205474361496,
        1.5707963267948966,0.0026499291432083914,0.8715205474361496,
        1.7135959928671598,0.0026499291432083823,0.8715205474361496,
        1.8563956589394233,0.0026499291432083936,0.8715205474361496,
        1.9991953250116865,0.0026499291432083736,0.8715205474361496,
        2.1419949910839495,0.002649929143208384,0.8715205474361496,
        2.284794657156213,0.002649929143208395,0.8715205474361496,
        2.4275943232284765,0.00264992914320839,0.8715205474361496,2.57039398930074,
        0.0026499291432083992,0.8715205474361496,2.7131936553730034,
        0.0026499291432083745,0.8715205474361496,2.855993321445266,
        0.002649929143208395,0.8715205474361496,2.99879298751753,
        0.002649929143208396,0.8715205474361496,3.141592653589793,
        0.0026499291432083784,0.8715205474361496,3.2843923196620564,
        0.0026499291432083905,0.8715205474361496,3.4271919857343196,
        0.0026499291432083953,0.8715205474361496,3.5699916518065833,
        0.0026499291432083944,0.8715205474361496,3.7127913178788465,
        0.00264992914320839,0.8715205474361496,3.8555909839511098,
        0.002649929143208392,0.8715205474361496,3.998390650023373,
        0.0026499291432083875,0.8715205474361496,4.141190316095636,
        0.0026499291432083723,0.8715205474361496,4.283989982167899,
        0.0026499291432083966,0.8715205474361496,4.426789648240163,
        0.0026499291432083897,0.8715205474361496,4.569589314312426,
        0.0026499291432083827,0.8715205474361496,4.71238898038469,
        0.0026499291432083875,0.8715205474361496,4.855188646456953,
        0.0026499291432083736,0.8715205474361496,4.997988312529216,
        0.0026499291432083966,0.8715205474361496,5.14078797860148,
        0.0026499291432083875,0.8715205474361496,5.2835876446737435,
        0.0026499291432083736,0.8715205474361496,5.426387310746007,
        0.0026499291432083728,0.8715205474361496,5.569186976818269,
        0.0026499291432083706,0.8715205474361496,5.711986642890532,
        0.0026499291432083823,0.8715205474361496,5.854786308962796,
        0.002649929143208389,0.8715205474361496,5.99758597503506,
        0.002649929143208392,0.8715205474361496,6.140385641107323,
        0.0026499291432083797,0.9300946203408686,0.,0.0021169342149977527,
        0.9300946203408686,0.14279966607226333,0.002116934214997748,
        0.9300946203408686,0.28559933214452665,0.0021169342149977522,
        0.9300946203408686,0.42839899821678995,0.0021169342149977527,
        0.9300946203408686,0.5711986642890533,0.0021169342149977544,
        0.9300946203408686,0.7139983303613165,0.0021169342149977505,
        0.9300946203408686,0.8567979964335799,0.0021169342149977488,
        0.9300946203408686,0.9995976625058433,0.002116934214997751,
        0.9300946203408686,1.1423973285781066,0.002116934214997761,
        0.9300946203408686,1.28519699465037,0.0021169342149977566,
        0.9300946203408686,1.427996660722633,0.002116934214997746,
        0.9300946203408686,1.5707963267948966,0.0021169342149977657,
        0.9300946203408686,1.7135959928671598,0.002116934214997752,
        0.9300946203408686,1.8563956589394233,0.0021169342149977635,
        0.9300946203408686,1.9991953250116865,0.002116934214997746,
        0.9300946203408686,2.1419949910839495,0.0021169342149977553,
        0.9300946203408686,2.284794657156213,0.0021169342149977605,
        0.9300946203408686,2.4275943232284765,0.0021169342149977596,
        0.9300946203408686,2.57039398930074,0.0021169342149977683,
        0.9300946203408686,2.7131936553730034,0.002116934214997741,
        0.9300946203408686,2.855993321445266,0.002116934214997764,
        0.9300946203408686,2.99879298751753,0.0021169342149977635,
        0.9300946203408686,3.141592653589793,0.0021169342149977505,
        0.9300946203408686,3.2843923196620564,0.0021169342149977566,
        0.9300946203408686,3.4271919857343196,0.002116934214997763,
        0.9300946203408686,3.5699916518065833,0.0021169342149977605,
        0.9300946203408686,3.7127913178788465,0.0021169342149977583,
        0.9300946203408686,3.8555909839511098,0.00211693421499776,
        0.9300946203408686,3.998390650023373,0.0021169342149977566,
        0.9300946203408686,4.141190316095636,0.002116934214997745,
        0.9300946203408686,4.283989982167899,0.0021169342149977644,
        0.9300946203408686,4.426789648240163,0.0021169342149977627,
        0.9300946203408686,4.569589314312426,0.002116934214997752,
        0.9300946203408686,4.71238898038469,0.0021169342149977605,
        0.9300946203408686,4.855188646456953,0.002116934214997749,
        0.9300946203408686,4.997988312529216,0.002116934214997767,
        0.9300946203408686,5.14078797860148,0.0021169342149977566,
        0.9300946203408686,5.2835876446737435,0.002116934214997752,
        0.9300946203408686,5.426387310746007,0.002116934214997744,
        0.9300946203408686,5.569186976818269,0.002116934214997742,
        0.9300946203408686,5.711986642890532,0.002116934214997756,
        0.9300946203408686,5.854786308962796,0.002116934214997755,
        0.9300946203408686,5.99758597503506,0.002116934214997763,0.9300946203408686,
        6.140385641107323,0.0021169342149977475,0.971355393192444,0.,
        0.0014270496530629112,0.971355393192444,0.14279966607226333,
        0.001427049653062902,0.971355393192444,0.28559933214452665,
        0.001427049653062909,0.971355393192444,0.42839899821678995,
        0.0014270496530629068,0.971355393192444,0.5711986642890533,
        0.0014270496530629094,0.971355393192444,0.7139983303613165,
        0.0014270496530629066,0.971355393192444,0.8567979964335799,
        0.0014270496530629044,0.971355393192444,0.9995976625058433,
        0.0014270496530629086,0.971355393192444,1.1423973285781066,
        0.0014270496530629094,0.971355393192444,1.28519699465037,
        0.0014270496530629144,0.971355393192444,1.427996660722633,
        0.001427049653062901,0.971355393192444,1.5707963267948966,
        0.0014270496530629164,0.971355393192444,1.7135959928671598,
        0.0014270496530629096,0.971355393192444,1.8563956589394233,
        0.0014270496530629155,0.971355393192444,1.9991953250116865,
        0.0014270496530629055,0.971355393192444,2.1419949910839495,
        0.0014270496530629107,0.971355393192444,2.284794657156213,
        0.0014270496530629166,0.971355393192444,2.4275943232284765,
        0.0014270496530629153,0.971355393192444,2.57039398930074,
        0.0014270496530629185,0.971355393192444,2.7131936553730034,
        0.0014270496530629057,0.971355393192444,2.855993321445266,
        0.001427049653062917,0.971355393192444,2.99879298751753,
        0.0014270496530629138,0.971355393192444,3.141592653589793,
        0.0014270496530629107,0.971355393192444,3.2843923196620564,
        0.0014270496530629099,0.971355393192444,3.4271919857343196,
        0.0014270496530629183,0.971355393192444,3.5699916518065833,
        0.0014270496530629116,0.971355393192444,3.7127913178788465,
        0.0014270496530629125,0.971355393192444,3.8555909839511098,
        0.001427049653062915,0.971355393192444,3.998390650023373,
        0.0014270496530629092,0.971355393192444,4.141190316095636,
        0.0014270496530629033,0.971355393192444,4.283989982167899,
        0.0014270496530629135,0.971355393192444,4.426789648240163,
        0.001427049653062913,0.971355393192444,4.569589314312426,
        0.0014270496530629075,0.971355393192444,4.71238898038469,
        0.0014270496530629122,0.971355393192444,4.855188646456953,
        0.001427049653062902,0.971355393192444,4.997988312529216,
        0.0014270496530629168,0.971355393192444,5.14078797860148,
        0.0014270496530629103,0.971355393192444,5.2835876446737435,
        0.001427049653062906,0.971355393192444,5.426387310746007,
        0.0014270496530629012,0.971355393192444,5.569186976818269,
        0.0014270496530629038,0.971355393192444,5.711986642890532,
        0.0014270496530629068,0.971355393192444,5.854786308962796,
        0.0014270496530629125,0.971355393192444,5.99758597503506,
        0.001427049653062914,0.971355393192444,6.140385641107323,
        0.0014270496530629042,0.9945422711343287,0.,0.0006325973535766954,
        0.9945422711343287,0.14279966607226333,0.0006325973535766991,
        0.9945422711343287,0.28559933214452665,0.0006325973535766948,
        0.9945422711343287,0.42839899821678995,0.0006325973535767002,
        0.9945422711343287,0.5711986642890533,0.0006325973535766978,
        0.9945422711343287,0.7139983303613165,0.0006325973535766991,
        0.9945422711343287,0.8567979964335799,0.0006325973535766955,
        0.9945422711343287,0.9995976625058433,0.0006325973535766973,
        0.9945422711343287,1.1423973285781066,0.0006325973535767,0.9945422711343287,
        1.28519699465037,0.0006325973535766983,0.9945422711343287,1.427996660722633,
        0.0006325973535766979,0.9945422711343287,1.5707963267948966,
        0.0006325973535767014,0.9945422711343287,1.7135959928671598,
        0.0006325973535766988,0.9945422711343287,1.8563956589394233,
        0.0006325973535767017,0.9945422711343287,1.9991953250116865,
        0.0006325973535766966,0.9945422711343287,2.1419949910839495,
        0.0006325973535766989,0.9945422711343287,2.284794657156213,
        0.0006325973535767015,0.9945422711343287,2.4275943232284765,
        0.0006325973535767008,0.9945422711343287,2.57039398930074,
        0.0006325973535767033,0.9945422711343287,2.7131936553730034,
        0.0006325973535766953,0.9945422711343287,2.855993321445266,
        0.0006325973535767019,0.9945422711343287,2.99879298751753,
        0.0006325973535767017,0.9945422711343287,3.141592653589793,
        0.0006325973535766981,0.9945422711343287,3.2843923196620564,
        0.0006325973535766992,0.9945422711343287,3.4271919857343196,
        0.0006325973535767028,0.9945422711343287,3.5699916518065833,
        0.0006325973535767001,0.9945422711343287,3.7127913178788465,
        0.0006325973535767019,0.9945422711343287,3.8555909839511098,
        0.0006325973535767002,0.9945422711343287,3.998390650023373,
        0.0006325973535767011,0.9945422711343287,4.141190316095636,
        0.0006325973535766963,0.9945422711343287,4.283989982167899,
        0.0006325973535767034,0.9945422711343287,4.426789648240163,
        0.000632597353576701,0.9945422711343287,4.569589314312426,
        0.0006325973535766998,0.9945422711343287,4.71238898038469,
        0.0006325973535767001,0.9945422711343287,4.855188646456953,
        0.000632597353576699,0.9945422711343287,4.997988312529216,
        0.0006325973535767028,0.9945422711343287,5.14078797860148,
        0.000632597353576701,0.9945422711343287,5.2835876446737435,
        0.0006325973535766974,0.9945422711343287,5.426387310746007,
        0.0006325973535766974,0.9945422711343287,5.569186976818269,
        0.0006325973535766961,0.9945422711343287,5.711986642890532,
        0.0006325973535766979,0.9945422711343287,5.854786308962796,
        0.0006325973535767,0.9945422711343287,5.99758597503506,
        0.0006325973535767006,0.9945422711343287,6.140385641107323,
        0.0006325973535766981,0.,0.,0.00694444445359297,0.1589767920091494,0.,
        0.0009149145097321186,0.1589767920091494,0.13659098493868665,
        0.0009149145097320706,0.1589767920091494,0.2731819698773733,
        0.0009149145097321114,0.1589767920091494,0.40977295481605996,
        0.0009149145097321134,0.1589767920091494,0.5463639397547466,
        0.0009149145097321117,0.1589767920091494,0.6829549246934332,
        0.0009149145097321097,0.1589767920091494,0.8195459096321199,
        0.0009149145097321073,0.1589767920091494,0.9561368945708066,
        0.0009149145097321063,0.1589767920091494,1.0927278795094932,
        0.0009149145097321054,0.1589767920091494,1.22931886444818,
        0.0009149145097321041,0.1589767920091494,1.3659098493868664,
        0.0009149145097321032,0.1589767920091494,1.5025008343255533,
        0.0009149145097321039,0.1589767920091494,1.6390918192642399,
        0.0009149145097321051,0.1589767920091494,1.7756828042029265,
        0.0009149145097321041,0.1589767920091494,1.9122737891416133,
        0.0009149145097321066,0.1589767920091494,2.0488647740803,
        0.0009149145097321065,0.1589767920091494,2.1854557590189865,
        0.0009149145097321061,0.1589767920091494,2.322046743957673,
        0.000914914509732106,0.1589767920091494,2.45863772889636,
        0.0009149145097321067,0.1589767920091494,2.5952287138350467,
        0.0009149145097321074,0.1589767920091494,2.731819698773733,
        0.0009149145097321064,0.1589767920091494,2.8684106837124195,
        0.0009149145097321054,0.1589767920091494,3.0050016686511065,
        0.0009149145097321046,0.1589767920091494,3.141592653589793,
        0.0009149145097321054,0.1589767920091494,3.2781836385284797,
        0.0009149145097321047,0.1589767920091494,3.4147746234671663,
        0.0009149145097321038,0.1589767920091494,3.551365608405853,
        0.0009149145097321048,0.1589767920091494,3.68795659334454,
        0.0009149145097321052,0.1589767920091494,3.8245475782832266,
        0.0009149145097321059,0.1589767920091494,3.961138563221913,
        0.0009149145097321056,0.1589767920091494,4.0977295481606,
        0.0009149145097321073,0.1589767920091494,4.234320533099286,
        0.0009149145097321063,0.1589767920091494,4.370911518037973,
        0.0009149145097321062,0.1589767920091494,4.507502502976659,
        0.0009149145097321075,0.1589767920091494,4.644093487915346,
        0.0009149145097321043,0.1589767920091494,4.780684472854033,
        0.0009149145097321036,0.1589767920091494,4.91727545779272,
        0.0009149145097321041,0.1589767920091494,5.053866442731406,
        0.0009149145097321036,0.1589767920091494,5.190457427670093,
        0.000914914509732104,0.1589767920091494,5.32704841260878,
        0.0009149145097321043,0.1589767920091494,5.463639397547466,
        0.0009149145097321035,0.1589767920091494,5.600230382486153,
        0.0009149145097321061,0.1589767920091494,5.736821367424839,
        0.0009149145097321079,0.1589767920091494,5.873412352363527,
        0.0009149145097321103,0.1589767920091494,6.010003337302213,
        0.0009149145097321117,0.1589767920091494,6.1465943222409,
        0.0009149145097321135,0.28816941795999995,0.,0.0015822137924592513,
        0.28816941795999995,0.13659098493868665,0.001582213792459251,
        0.28816941795999995,0.2731819698773733,0.0015822137924592517,
        0.28816941795999995,0.40977295481605996,0.0015822137924592517,
        0.28816941795999995,0.5463639397547466,0.0015822137924592508,
        0.28816941795999995,0.6829549246934332,0.001582213792459249,
        0.28816941795999995,0.8195459096321199,0.0015822137924592498,
        0.28816941795999995,0.9561368945708066,0.001582213792459251,
        0.28816941795999995,1.0927278795094932,0.001582213792459251,
        0.28816941795999995,1.22931886444818,0.0015822137924592515,
        0.28816941795999995,1.3659098493868664,0.0015822137924592515,
        0.28816941795999995,1.5025008343255533,0.001582213792459251,
        0.28816941795999995,1.6390918192642399,0.0015822137924592513,
        0.28816941795999995,1.7756828042029265,0.00158221379245925,
        0.28816941795999995,1.9122737891416133,0.0015822137924592504,
        0.28816941795999995,2.0488647740803,0.0015822137924592506,
        0.28816941795999995,2.1854557590189865,0.0015822137924592493,
        0.28816941795999995,2.322046743957673,0.00158221379245925,
        0.28816941795999995,2.45863772889636,0.001582213792459249,
        0.28816941795999995,2.5952287138350467,0.00158221379245925,
        0.28816941795999995,2.731819698773733,0.00158221379245925,
        0.28816941795999995,2.8684106837124195,0.0015822137924592504,
        0.28816941795999995,3.0050016686511065,0.0015822137924592502,
        0.28816941795999995,3.141592653589793,0.0015822137924592504,
        0.28816941795999995,3.2781836385284797,0.0015822137924592515,
        0.28816941795999995,3.4147746234671663,0.001582213792459251,
        0.28816941795999995,3.551365608405853,0.0015822137924592515,
        0.28816941795999995,3.68795659334454,0.0015822137924592504,
        0.28816941795999995,3.8245475782832266,0.0015822137924592498,
        0.28816941795999995,3.961138563221913,0.0015822137924592478,
        0.28816941795999995,4.0977295481606,0.0015822137924592463,
        0.28816941795999995,4.234320533099286,0.001582213792459247,
        0.28816941795999995,4.370911518037973,0.0015822137924592491,
        0.28816941795999995,4.507502502976659,0.00158221379245925,
        0.28816941795999995,4.644093487915346,0.0015822137924592537,
        0.28816941795999995,4.780684472854033,0.0015822137924592539,
        0.28816941795999995,4.91727545779272,0.0015822137924592513,
        0.28816941795999995,5.053866442731406,0.0015822137924592506,
        0.28816941795999995,5.190457427670093,0.0015822137924592476,
        0.28816941795999995,5.32704841260878,0.0015822137924592476,
        0.28816941795999995,5.463639397547466,0.001582213792459248,
        0.28816941795999995,5.600230382486153,0.0015822137924592508,
        0.28816941795999995,5.736821367424839,0.0015822137924592506,
        0.28816941795999995,5.873412352363527,0.0015822137924592521,
        0.28816941795999995,6.010003337302213,0.0015822137924592515,
        0.28816941795999995,6.1465943222409,0.0015822137924592521,
        0.4113090083832123,0.,0.0021412884214397155,0.4113090083832123,
        0.13659098493868665,0.002141288421439718,0.4113090083832123,
        0.2731819698773733,0.0021412884214397202,0.4113090083832123,
        0.40977295481605996,0.0021412884214397185,0.4113090083832123,
        0.5463639397547466,0.0021412884214397168,0.4113090083832123,
        0.6829549246934332,0.002141288421439717,0.4113090083832123,
        0.8195459096321199,0.0021412884214397185,0.4113090083832123,
        0.9561368945708066,0.002141288421439721,0.4113090083832123,
        1.0927278795094932,0.002141288421439721,0.4113090083832123,1.22931886444818,
        0.002141288421439719,0.4113090083832123,1.3659098493868664,
        0.0021412884214397185,0.4113090083832123,1.5025008343255533,
        0.0021412884214397207,0.4113090083832123,1.6390918192642399,
        0.002141288421439722,0.4113090083832123,1.7756828042029265,
        0.0021412884214397202,0.4113090083832123,1.9122737891416133,
        0.0021412884214397185,0.4113090083832123,2.0488647740803,
        0.002141288421439719,0.4113090083832123,2.1854557590189865,
        0.0021412884214397207,0.4113090083832123,2.322046743957673,
        0.0021412884214397224,0.4113090083832123,2.45863772889636,
        0.0021412884214397194,0.4113090083832123,2.5952287138350467,
        0.0021412884214397176,0.4113090083832123,2.731819698773733,
        0.002141288421439716,0.4113090083832123,2.8684106837124195,
        0.0021412884214397168,0.4113090083832123,3.0050016686511065,
        0.0021412884214397202,0.4113090083832123,3.141592653589793,
        0.0021412884214397176,0.4113090083832123,3.2781836385284797,
        0.002141288421439715,0.4113090083832123,3.4147746234671663,
        0.002141288421439715,0.4113090083832123,3.551365608405853,
        0.002141288421439717,0.4113090083832123,3.68795659334454,
        0.002141288421439723,0.4113090083832123,3.8245475782832266,
        0.002141288421439721,0.4113090083832123,3.961138563221913,
        0.0021412884214397185,0.4113090083832123,4.0977295481606,
        0.002141288421439713,0.4113090083832123,4.234320533099286,
        0.002141288421439714,0.4113090083832123,4.370911518037973,
        0.00214128842143972,0.4113090083832123,4.507502502976659,
        0.0021412884214397233,0.4113090083832123,4.644093487915346,
        0.002141288421439725,0.4113090083832123,4.780684472854033,
        0.002141288421439722,0.4113090083832123,4.91727545779272,
        0.002141288421439719,0.4113090083832123,5.053866442731406,
        0.002141288421439717,0.4113090083832123,5.190457427670093,
        0.0021412884214397124,0.4113090083832123,5.32704841260878,
        0.002141288421439711,0.4113090083832123,5.463639397547466,
        0.0021412884214397146,0.4113090083832123,5.600230382486153,
        0.002141288421439722,0.4113090083832123,5.736821367424839,
        0.002141288421439725,0.4113090083832123,5.873412352363527,
        0.002141288421439724,0.4113090083832123,6.010003337302213,
        0.0021412884214397185,0.4113090083832123,6.1465943222409,
        0.0021412884214397133,0.5270642419184137,0.,0.0025543816869044826,
        0.5270642419184137,0.13659098493868665,0.0025543816869044874,
        0.5270642419184137,0.2731819698773733,0.0025543816869044883,
        0.5270642419184137,0.40977295481605996,0.002554381686904485,
        0.5270642419184137,0.5463639397547466,0.002554381686904482,
        0.5270642419184137,0.6829549246934332,0.002554381686904479,
        0.5270642419184137,0.8195459096321199,0.0025543816869044848,
        0.5270642419184137,0.9561368945708066,0.0025543816869044865,
        0.5270642419184137,1.0927278795094932,0.0025543816869044843,
        0.5270642419184137,1.22931886444818,0.0025543816869044796,
        0.5270642419184137,1.3659098493868664,0.00255438168690448,
        0.5270642419184137,1.5025008343255533,0.002554381686904485,
        0.5270642419184137,1.6390918192642399,0.002554381686904486,
        0.5270642419184137,1.7756828042029265,0.0025543816869044826,
        0.5270642419184137,1.9122737891416133,0.0025543816869044813,
        0.5270642419184137,2.0488647740803,0.002554381686904482,0.5270642419184137,
        2.1854557590189865,0.002554381686904485,0.5270642419184137,
        2.322046743957673,0.002554381686904488,0.5270642419184137,2.45863772889636,
        0.0025543816869044856,0.5270642419184137,2.5952287138350467,
        0.00255438168690448,0.5270642419184137,2.731819698773733,
        0.0025543816869044804,0.5270642419184137,2.8684106837124195,
        0.0025543816869044856,0.5270642419184137,3.0050016686511065,
        0.0025543816869044887,0.5270642419184137,3.141592653589793,
        0.002554381686904487,0.5270642419184137,3.2781836385284797,
        0.0025543816869044817,0.5270642419184137,3.4147746234671663,
        0.0025543816869044835,0.5270642419184137,3.551365608405853,
        0.002554381686904487,0.5270642419184137,3.68795659334454,
        0.0025543816869044874,0.5270642419184137,3.8245475782832266,
        0.002554381686904489,0.5270642419184137,3.961138563221913,
        0.002554381686904482,0.5270642419184137,4.0977295481606,
        0.0025543816869044765,0.5270642419184137,4.234320533099286,
        0.0025543816869044774,0.5270642419184137,4.370911518037973,
        0.0025543816869044835,0.5270642419184137,4.507502502976659,
        0.0025543816869044904,0.5270642419184137,4.644093487915346,
        0.00255438168690449,0.5270642419184137,4.780684472854033,
        0.0025543816869044848,0.5270642419184137,4.91727545779272,
        0.002554381686904483,0.5270642419184137,5.053866442731406,
        0.0025543816869044856,0.5270642419184137,5.190457427670093,
        0.0025543816869044817,0.5270642419184137,5.32704841260878,
        0.002554381686904475,0.5270642419184137,5.463639397547466,
        0.002554381686904477,0.5270642419184137,5.600230382486153,
        0.0025543816869044874,0.5270642419184137,5.736821367424839,
        0.002554381686904493,0.5270642419184137,5.873412352363527,
        0.002554381686904491,0.5270642419184137,6.010003337302213,
        0.0025543816869044843,0.5270642419184137,6.1465943222409,
        0.0025543816869044813,0.6336424230059575,0.,0.0027933841098745048,
        0.6336424230059575,0.13659098493868665,0.002793384109874506,
        0.6336424230059575,0.2731819698773733,0.0027933841098745117,
        0.6336424230059575,0.40977295481605996,0.0027933841098745117,
        0.6336424230059575,0.5463639397547466,0.002793384109874505,
        0.6336424230059575,0.6829549246934332,0.002793384109874502,
        0.6336424230059575,0.8195459096321199,0.002793384109874508,
        0.6336424230059575,0.9561368945708066,0.0027933841098745135,
        0.6336424230059575,1.0927278795094932,0.0027933841098745082,
        0.6336424230059575,1.22931886444818,0.0027933841098745035,
        0.6336424230059575,1.3659098493868664,0.0027933841098745056,
        0.6336424230059575,1.5025008343255533,0.002793384109874513,
        0.6336424230059575,1.6390918192642399,0.0027933841098745095,
        0.6336424230059575,1.7756828042029265,0.002793384109874504,
        0.6336424230059575,1.9122737891416133,0.0027933841098745065,
        0.6336424230059575,2.0488647740803,0.0027933841098745074,0.6336424230059575,
        2.1854557590189865,0.002793384109874505,0.6336424230059575,
        2.322046743957673,0.0027933841098745082,0.6336424230059575,2.45863772889636,
        0.0027933841098745117,0.6336424230059575,2.5952287138350467,
        0.002793384109874502,0.6336424230059575,2.731819698773733,
        0.0027933841098745,0.6336424230059575,2.8684106837124195,
        0.00279338410987451,0.6336424230059575,3.0050016686511065,
        0.0027933841098745095,0.6336424230059575,3.141592653589793,
        0.002793384109874504,0.6336424230059575,3.2781836385284797,
        0.002793384109874503,0.6336424230059575,3.4147746234671663,
        0.002793384109874506,0.6336424230059575,3.551365608405853,
        0.002793384109874506,0.6336424230059575,3.68795659334454,
        0.0027933841098745095,0.6336424230059575,3.8245475782832266,
        0.00279338410987451,0.6336424230059575,3.961138563221913,
        0.0027933841098745035,0.6336424230059575,4.0977295481606,
        0.002793384109874498,0.6336424230059575,4.234320533099286,
        0.002793384109874499,0.6336424230059575,4.370911518037973,
        0.0027933841098745056,0.6336424230059575,4.507502502976659,
        0.0027933841098745113,0.6336424230059575,4.644093487915346,
        0.0027933841098745165,0.6336424230059575,4.780684472854033,
        0.0027933841098745126,0.6336424230059575,4.91727545779272,
        0.0027933841098745026,0.6336424230059575,5.053866442731406,
        0.0027933841098745095,0.6336424230059575,5.190457427670093,
        0.002793384109874507,0.6336424230059575,5.32704841260878,
        0.0027933841098744952,0.6336424230059575,5.463639397547466,
        0.0027933841098744987,0.6336424230059575,5.600230382486153,
        0.002793384109874514,0.6336424230059575,5.736821367424839,
        0.0027933841098745182,0.6336424230059575,5.873412352363527,
        0.0027933841098745117,0.6336424230059575,6.010003337302213,
        0.0027933841098745074,0.6336424230059575,6.1465943222409,
        0.002793384109874508,0.7292889598166258,0.,0.0028420180498876196,
        0.7292889598166258,0.13659098493868665,0.0028420180498876188,
        0.7292889598166258,0.2731819698773733,0.002842018049887628,
        0.7292889598166258,0.40977295481605996,0.002842018049887624,
        0.7292889598166258,0.5463639397547466,0.0028420180498876157,
        0.7292889598166258,0.6829549246934332,0.0028420180498876196,
        0.7292889598166258,0.8195459096321199,0.002842018049887621,
        0.7292889598166258,0.9561368945708066,0.0028420180498876235,
        0.7292889598166258,1.0927278795094932,0.0028420180498876253,
        0.7292889598166258,1.22931886444818,0.002842018049887615,0.7292889598166258,
        1.3659098493868664,0.002842018049887616,0.7292889598166258,
        1.5025008343255533,0.0028420180498876266,0.7292889598166258,
        1.6390918192642399,0.0028420180498876227,0.7292889598166258,
        1.7756828042029265,0.0028420180498876157,0.7292889598166258,
        1.9122737891416133,0.002842018049887621,0.7292889598166258,2.0488647740803,
        0.0028420180498876214,0.7292889598166258,2.1854557590189865,
        0.002842018049887618,0.7292889598166258,2.322046743957673,
        0.0028420180498876205,0.7292889598166258,2.45863772889636,
        0.0028420180498876266,0.7292889598166258,2.5952287138350467,
        0.0028420180498876144,0.7292889598166258,2.731819698773733,
        0.0028420180498876066,0.7292889598166258,2.8684106837124195,
        0.002842018049887627,0.7292889598166258,3.0050016686511065,
        0.002842018049887624,0.7292889598166258,3.141592653589793,
        0.0028420180498876114,0.7292889598166258,3.2781836385284797,
        0.002842018049887619,0.7292889598166258,3.4147746234671663,
        0.0028420180498876174,0.7292889598166258,3.551365608405853,
        0.0028420180498876174,0.7292889598166258,3.68795659334454,
        0.002842018049887624,0.7292889598166258,3.8245475782832266,
        0.002842018049887625,0.7292889598166258,3.961138563221913,
        0.0028420180498876188,0.7292889598166258,4.0977295481606,
        0.002842018049887608,0.7292889598166258,4.234320533099286,
        0.0028420180498876153,0.7292889598166258,4.370911518037973,
        0.002842018049887623,0.7292889598166258,4.507502502976659,
        0.0028420180498876183,0.7292889598166258,4.644093487915346,
        0.002842018049887633,0.7292889598166258,4.780684472854033,
        0.0028420180498876274,0.7292889598166258,4.91727545779272,
        0.00284201804988761,0.7292889598166258,5.053866442731406,
        0.0028420180498876283,0.7292889598166258,5.190457427670093,
        0.0028420180498876214,0.7292889598166258,5.32704841260878,
        0.002842018049887606,0.7292889598166258,5.463639397547466,
        0.0028420180498876196,0.7292889598166258,5.600230382486153,
        0.0028420180498876266,0.7292889598166258,5.736821367424839,
        0.002842018049887631,0.7292889598166258,5.873412352363527,
        0.0028420180498876283,0.7292889598166258,6.010003337302213,
        0.00284201804988762,0.7292889598166258,6.1465943222409,
        0.0028420180498876214,0.8123988195986838,0.,0.0026969734866615054,
        0.8123988195986838,0.13659098493868665,0.002696973486661503,
        0.8123988195986838,0.2731819698773733,0.0026969734866615154,
        0.8123988195986838,0.40977295481605996,0.002696973486661509,
        0.8123988195986838,0.5463639397547466,0.0026969734866615024,
        0.8123988195986838,0.6829549246934332,0.0026969734866615076,
        0.8123988195986838,0.8195459096321199,0.002696973486661508,
        0.8123988195986838,0.9561368945708066,0.0026969734866615098,
        0.8123988195986838,1.0927278795094932,0.0026969734866615133,
        0.8123988195986838,1.22931886444818,0.0026969734866615046,
        0.8123988195986838,1.3659098493868664,0.0026969734866615024,
        0.8123988195986838,1.5025008343255533,0.0026969734866615137,
        0.8123988195986838,1.6390918192642399,0.0026969734866615106,
        0.8123988195986838,1.7756828042029265,0.002696973486661502,
        0.8123988195986838,1.9122737891416133,0.0026969734866615093,
        0.8123988195986838,2.0488647740803,0.0026969734866615046,0.8123988195986838,
        2.1854557590189865,0.002696973486661508,0.8123988195986838,
        2.322046743957673,0.0026969734866615063,0.8123988195986838,2.45863772889636,
        0.002696973486661511,0.8123988195986838,2.5952287138350467,
        0.0026969734866615063,0.8123988195986838,2.731819698773733,
        0.0026969734866614963,0.8123988195986838,2.8684106837124195,
        0.0026969734866615154,0.8123988195986838,3.0050016686511065,
        0.0026969734866615115,0.8123988195986838,3.141592653589793,
        0.0026969734866615002,0.8123988195986838,3.2781836385284797,
        0.0026969734866615124,0.8123988195986838,3.4147746234671663,
        0.0026969734866615015,0.8123988195986838,3.551365608405853,
        0.0026969734866615093,0.8123988195986838,3.68795659334454,
        0.002696973486661516,0.8123988195986838,3.8245475782832266,
        0.0026969734866615063,0.8123988195986838,3.961138563221913,
        0.002696973486661512,0.8123988195986838,4.0977295481606,
        0.0026969734866614968,0.8123988195986838,4.234320533099286,
        0.0026969734866615,0.8123988195986838,4.370911518037973,
        0.0026969734866615163,0.8123988195986838,4.507502502976659,
        0.0026969734866615037,0.8123988195986838,4.644093487915346,
        0.0026969734866615206,0.8123988195986838,4.780684472854033,
        0.0026969734866615185,0.8123988195986838,4.91727545779272,
        0.0026969734866614955,0.8123988195986838,5.053866442731406,
        0.0026969734866615176,0.8123988195986838,5.190457427670093,
        0.0026969734866615085,0.8123988195986838,5.32704841260878,
        0.0026969734866614877,0.8123988195986838,5.463639397547466,
        0.0026969734866615146,0.8123988195986838,5.600230382486153,
        0.002696973486661508,0.8123988195986838,5.736821367424839,
        0.002696973486661518,0.8123988195986838,5.873412352363527,
        0.002696973486661521,0.8123988195986838,6.010003337302213,
        0.0026969734866615002,0.8123988195986838,6.1465943222409,
        0.0026969734866615115,0.8815664427348412,0.,0.0023681399896880472,
        0.8815664427348412,0.13659098493868665,0.00236813998968806,
        0.8815664427348412,0.2731819698773733,0.002368139989688059,
        0.8815664427348412,0.40977295481605996,0.00236813998968806,
        0.8815664427348412,0.5463639397547466,0.0023681399896880537,
        0.8815664427348412,0.6829549246934332,0.0023681399896880524,
        0.8815664427348412,0.8195459096321199,0.002368139989688058,
        0.8815664427348412,0.9561368945708066,0.002368139989688059,
        0.8815664427348412,1.0927278795094932,0.0023681399896880576,
        0.8815664427348412,1.22931886444818,0.0023681399896880537,
        0.8815664427348412,1.3659098493868664,0.002368139989688053,
        0.8815664427348412,1.5025008343255533,0.0023681399896880594,
        0.8815664427348412,1.6390918192642399,0.0023681399896880624,
        0.8815664427348412,1.7756828042029265,0.002368139989688047,
        0.8815664427348412,1.9122737891416133,0.002368139989688064,
        0.8815664427348412,2.0488647740803,0.002368139989688051,0.8815664427348412,
        2.1854557590189865,0.002368139989688057,0.8815664427348412,
        2.322046743957673,0.0023681399896880594,0.8815664427348412,2.45863772889636,
        0.002368139989688057,0.8815664427348412,2.5952287138350467,
        0.0023681399896880585,0.8815664427348412,2.731819698773733,
        0.0023681399896880438,0.8815664427348412,2.8684106837124195,
        0.002368139989688066,0.8815664427348412,3.0050016686511065,
        0.0023681399896880624,0.8815664427348412,3.141592653589793,
        0.002368139989688051,0.8815664427348412,3.2781836385284797,
        0.0023681399896880602,0.8815664427348412,3.4147746234671663,
        0.002368139989688053,0.8815664427348412,3.551365608405853,
        0.002368139989688058,0.8815664427348412,3.68795659334454,
        0.002368139989688065,0.8815664427348412,3.8245475782832266,
        0.002368139989688054,0.8815664427348412,3.961138563221913,
        0.0023681399896880624,0.8815664427348412,4.0977295481606,
        0.002368139989688045,0.8815664427348412,4.234320533099286,
        0.002368139989688049,0.8815664427348412,4.370911518037973,
        0.0023681399896880633,0.8815664427348412,4.507502502976659,
        0.0023681399896880533,0.8815664427348412,4.644093487915346,
        0.0023681399896880668,0.8815664427348412,4.780684472854033,
        0.002368139989688065,0.8815664427348412,4.91727545779272,
        0.002368139989688046,0.8815664427348412,5.053866442731406,
        0.002368139989688062,0.8815664427348412,5.190457427670093,
        0.002368139989688061,0.8815664427348412,5.32704841260878,
        0.002368139989688033,0.8815664427348412,5.463639397547466,
        0.0023681399896880654,0.8815664427348412,5.600230382486153,
        0.00236813998968805,0.8815664427348412,5.736821367424839,
        0.0023681399896880702,0.8815664427348412,5.873412352363527,
        0.0023681399896880654,0.8815664427348412,6.010003337302213,
        0.002368139989688047,0.8815664427348412,6.1465943222409,
        0.002368139989688067,0.9356178572769744,0.,0.0018779417314650402,
        0.9356178572769744,0.13659098493868665,0.001877941731465064,
        0.9356178572769744,0.2731819698773733,0.0018779417314650473,
        0.9356178572769744,0.40977295481605996,0.0018779417314650625,
        0.9356178572769744,0.5463639397547466,0.0018779417314650456,
        0.9356178572769744,0.6829549246934332,0.0018779417314650564,
        0.9356178572769744,0.8195459096321199,0.001877941731465052,
        0.9356178572769744,0.9561368945708066,0.001877941731465056,
        0.9356178572769744,1.0927278795094932,0.0018779417314650575,
        0.9356178572769744,1.22931886444818,0.0018779417314650504,
        0.9356178572769744,1.3659098493868664,0.001877941731465053,
        0.9356178572769744,1.5025008343255533,0.0018779417314650527,
        0.9356178572769744,1.6390918192642399,0.0018779417314650634,
        0.9356178572769744,1.7756828042029265,0.0018779417314650428,
        0.9356178572769744,1.9122737891416133,0.0018779417314650619,
        0.9356178572769744,2.0488647740803,0.0018779417314650506,0.9356178572769744,
        2.1854557590189865,0.0018779417314650554,0.9356178572769744,
        2.322046743957673,0.0018779417314650564,0.9356178572769744,2.45863772889636,
        0.0018779417314650536,0.9356178572769744,2.5952287138350467,
        0.0018779417314650562,0.9356178572769744,2.731819698773733,
        0.0018779417314650415,0.9356178572769744,2.8684106837124195,
        0.00187794173146506,0.9356178572769744,3.0050016686511065,
        0.0018779417314650569,0.9356178572769744,3.141592653589793,
        0.0018779417314650467,0.9356178572769744,3.2781836385284797,
        0.0018779417314650556,0.9356178572769744,3.4147746234671663,
        0.001877941731465051,0.9356178572769744,3.551365608405853,
        0.00187794173146505,0.9356178572769744,3.68795659334454,
        0.001877941731465061,0.9356178572769744,3.8245475782832266,
        0.0018779417314650512,0.9356178572769744,3.961138563221913,
        0.0018779417314650586,0.9356178572769744,4.0977295481606,
        0.0018779417314650426,0.9356178572769744,4.234320533099286,
        0.001877941731465053,0.9356178572769744,4.370911518037973,
        0.0018779417314650547,0.9356178572769744,4.507502502976659,
        0.001877941731465053,0.9356178572769744,4.644093487915346,
        0.0018779417314650638,0.9356178572769744,4.780684472854033,
        0.0018779417314650569,0.9356178572769744,4.91727545779272,
        0.001877941731465052,0.9356178572769744,5.053866442731406,
        0.0018779417314650517,0.9356178572769744,5.190457427670093,
        0.0018779417314650645,0.9356178572769744,5.32704841260878,
        0.0018779417314650313,0.9356178572769744,5.463639397547466,
        0.0018779417314650662,0.9356178572769744,5.600230382486153,
        0.0018779417314650465,0.9356178572769744,5.736821367424839,
        0.0018779417314650666,0.9356178572769744,5.873412352363527,
        0.0018779417314650588,0.9356178572769744,6.010003337302213,
        0.0018779417314650482,0.9356178572769744,6.1465943222409,
        0.001877941731465063,0.9736347101828382,0.,0.001259863916333002,
        0.9736347101828382,0.13659098493868665,0.001259863916333017,
        0.9736347101828382,0.2731819698773733,0.0012598639163330049,
        0.9736347101828382,0.40977295481605996,0.0012598639163330211,
        0.9736347101828382,0.5463639397547466,0.001259863916332999,
        0.9736347101828382,0.6829549246934332,0.0012598639163330161,
        0.9736347101828382,0.8195459096321199,0.0012598639163330077,
        0.9736347101828382,0.9561368945708066,0.0012598639163330122,
        0.9736347101828382,1.0927278795094932,0.001259863916333014,
        0.9736347101828382,1.22931886444818,0.0012598639163330053,
        0.9736347101828382,1.3659098493868664,0.0012598639163330146,
        0.9736347101828382,1.5025008343255533,0.0012598639163330099,
        0.9736347101828382,1.6390918192642399,0.0012598639163330164,
        0.9736347101828382,1.7756828042029265,0.0012598639163330053,
        0.9736347101828382,1.9122737891416133,0.0012598639163330148,
        0.9736347101828382,2.0488647740803,0.0012598639163330092,0.9736347101828382,
        2.1854557590189865,0.0012598639163330116,0.9736347101828382,
        2.322046743957673,0.0012598639163330118,0.9736347101828382,2.45863772889636,
        0.0012598639163330116,0.9736347101828382,2.5952287138350467,
        0.0012598639163330118,0.9736347101828382,2.731819698773733,
        0.0012598639163330038,0.9736347101828382,2.8684106837124195,
        0.0012598639163330148,0.9736347101828382,3.0050016686511065,
        0.0012598639163330107,0.9736347101828382,3.141592653589793,
        0.0012598639163330103,0.9736347101828382,3.2781836385284797,
        0.0012598639163330107,0.9736347101828382,3.4147746234671663,
        0.0012598639163330107,0.9736347101828382,3.551365608405853,
        0.0012598639163330107,0.9736347101828382,3.68795659334454,
        0.0012598639163330164,0.9736347101828382,3.8245475782832266,
        0.0012598639163330094,0.9736347101828382,3.961138563221913,
        0.001259863916333016,0.9736347101828382,4.0977295481606,
        0.0012598639163330038,0.9736347101828382,4.234320533099286,
        0.0012598639163330086,0.9736347101828382,4.370911518037973,
        0.0012598639163330155,0.9736347101828382,4.507502502976659,
        0.0012598639163330073,0.9736347101828382,4.644093487915346,
        0.0012598639163330196,0.9736347101828382,4.780684472854033,
        0.0012598639163330107,0.9736347101828382,4.91727545779272,
        0.0012598639163330116,0.9736347101828382,5.053866442731406,
        0.0012598639163330066,0.9736347101828382,5.190457427670093,
        0.0012598639163330207,0.9736347101828382,5.32704841260878,
        0.0012598639163329927,0.9736347101828382,5.463639397547466,
        0.0012598639163330196,0.9736347101828382,5.600230382486153,
        0.001259863916333005,0.9736347101828382,5.736821367424839,
        0.0012598639163330172,0.9736347101828382,5.873412352363527,
        0.0012598639163330161,0.9736347101828382,6.010003337302213,
        0.0012598639163330036,0.9736347101828382,6.1465943222409,
        0.001259863916333017,0.9949782507865785,0.,0.0005570445565635635,
        0.9949782507865785,0.13659098493868665,0.0005570445565635682,
        0.9949782507865785,0.2731819698773733,0.0005570445565635645,
        0.9949782507865785,0.40977295481605996,0.0005570445565635672,
        0.9949782507865785,0.5463639397547466,0.0005570445565635645,
        0.9949782507865785,0.6829549246934332,0.0005570445565635685,
        0.9949782507865785,0.8195459096321199,0.0005570445565635641,
        0.9949782507865785,0.9561368945708066,0.0005570445565635702,
        0.9949782507865785,1.0927278795094932,0.0005570445565635626,
        0.9949782507865785,1.22931886444818,0.0005570445565635708,
        0.9949782507865785,1.3659098493868664,0.0005570445565635607,
        0.9949782507865785,1.5025008343255533,0.0005570445565635712,
        0.9949782507865785,1.6390918192642399,0.0005570445565635644,
        0.9949782507865785,1.7756828042029265,0.0005570445565635674,
        0.9949782507865785,1.9122737891416133,0.0005570445565635651,
        0.9949782507865785,2.0488647740803,0.0005570445565635696,0.9949782507865785,
        2.1854557590189865,0.0005570445565635658,0.9949782507865785,
        2.322046743957673,0.0005570445565635693,0.9949782507865785,2.45863772889636,
        0.0005570445565635652,0.9949782507865785,2.5952287138350467,
        0.0005570445565635689,0.9949782507865785,2.731819698773733,
        0.0005570445565635636,0.9949782507865785,2.8684106837124195,
        0.0005570445565635691,0.9949782507865785,3.0050016686511065,
        0.0005570445565635699,0.9949782507865785,3.141592653589793,
        0.0005570445565635653,0.9949782507865785,3.2781836385284797,
        0.0005570445565635703,0.9949782507865785,3.4147746234671663,
        0.0005570445565635643,0.9949782507865785,3.551365608405853,
        0.0005570445565635678,0.9949782507865785,3.68795659334454,
        0.0005570445565635663,0.9949782507865785,3.8245475782832266,
        0.0005570445565635686,0.9949782507865785,3.961138563221913,
        0.0005570445565635641,0.9949782507865785,4.0977295481606,
        0.0005570445565635669,0.9949782507865785,4.234320533099286,
        0.0005570445565635621,0.9949782507865785,4.370911518037973,
        0.0005570445565635697,0.9949782507865785,4.507502502976659,
        0.0005570445565635631,0.9949782507865785,4.644093487915346,
        0.0005570445565635718,0.9949782507865785,4.780684472854033,
        0.0005570445565635652,0.9949782507865785,4.91727545779272,
        0.0005570445565635656,0.9949782507865785,5.053866442731406,
        0.0005570445565635639,0.9949782507865785,5.190457427670093,
        0.0005570445565635679,0.9949782507865785,5.32704841260878,
        0.0005570445565635586,0.9949782507865785,5.463639397547466,
        0.000557044556563569,0.9949782507865785,5.600230382486153,
        0.0005570445565635638,0.9949782507865785,5.736821367424839,
        0.0005570445565635697,0.9949782507865785,5.873412352363527,
        0.0005570445565635658,0.9949782507865785,6.010003337302213,
        0.0005570445565635644,0.9949782507865785,6.1465943222409,
        0.0005570445565635673,0.09601917973321986,0.,0.0004914097539995704,
        0.09601917973321986,0.1308996938995747,0.0004914097539995973,
        0.09601917973321986,0.2617993877991494,0.0004914097539995995,
        0.09601917973321986,0.39269908169872414,0.0004914097539996009,
        0.09601917973321986,0.5235987755982988,0.0004914097539995996,
        0.09601917973321986,0.6544984694978736,0.0004914097539995985,
        0.09601917973321986,0.7853981633974483,0.0004914097539995978,
        0.09601917973321986,0.9162978572970231,0.000491409753999597,
        0.09601917973321986,1.0471975511965976,0.0004914097539995963,
        0.09601917973321986,1.1780972450961724,0.0004914097539995966,
        0.09601917973321986,1.3089969389957472,0.0004914097539995955,
        0.09601917973321986,1.4398966328953218,0.0004914097539995952,
        0.09601917973321986,1.5707963267948966,0.0004914097539995959,
        0.09601917973321986,1.7016960206944711,0.0004914097539995951,
        0.09601917973321986,1.8325957145940461,0.0004914097539995953,
        0.09601917973321986,1.9634954084936207,0.000491409753999596,
        0.09601917973321986,2.0943951023931953,0.000491409753999596,
        0.09601917973321986,2.2252947962927703,0.0004914097539995966,
        0.09601917973321986,2.356194490192345,0.0004914097539995969,
        0.09601917973321986,2.4870941840919194,0.0004914097539995982,
        0.09601917973321986,2.6179938779914944,0.0004914097539995977,
        0.09601917973321986,2.748893571891069,0.000491409753999598,
        0.09601917973321986,2.8797932657906435,0.0004914097539995986,
        0.09601917973321986,3.0106929596902186,0.0004914097539995991,
        0.09601917973321986,3.141592653589793,0.0004914097539995997,
        0.09601917973321986,3.272492347489368,0.0004914097539995991,
        0.09601917973321986,3.4033920413889422,0.0004914097539995989,
        0.09601917973321986,3.5342917352885173,0.0004914097539995983,
        0.09601917973321986,3.6651914291880923,0.000491409753999598,
        0.09601917973321986,3.7960911230876664,0.0004914097539995974,
        0.09601917973321986,3.9269908169872414,0.0004914097539995973,
        0.09601917973321986,4.057890510886816,0.000491409753999597,
        0.09601917973321986,4.1887902047863905,0.0004914097539995966,
        0.09601917973321986,4.319689898685965,0.0004914097539995961,
        0.09601917973321986,4.4505895925855405,0.0004914097539995963,
        0.09601917973321986,4.581489286485115,0.0004914097539995957,
        0.09601917973321986,4.71238898038469,0.0004914097539995945,
        0.09601917973321986,4.843288674284264,0.0004914097539995957,
        0.09601917973321986,4.974188368183839,0.0004914097539995953,
        0.09601917973321986,5.105088062083414,0.0004914097539995962,
        0.09601917973321986,5.235987755982989,0.0004914097539995966,
        0.09601917973321986,5.366887449882563,0.0004914097539995971,
        0.09601917973321986,5.497787143782138,0.000491409753999598,
        0.09601917973321986,5.6286868376817125,0.000491409753999599,
        0.09601917973321986,5.759586531581287,0.0004914097539995998,
        0.09601917973321986,5.890486225480862,0.0004914097539996005,
        0.09601917973321986,6.021385919380437,0.0004914097539996008,
        0.09601917973321986,6.152285613280012,0.0004914097539996009,
        0.21895518220577137,0.,0.0011139513125403948,0.21895518220577137,
        0.1308996938995747,0.0011139513125403946,0.21895518220577137,
        0.2617993877991494,0.0011139513125403937,0.21895518220577137,
        0.39269908169872414,0.0011139513125403935,0.21895518220577137,
        0.5235987755982988,0.001113951312540393,0.21895518220577137,
        0.6544984694978736,0.001113951312540393,0.21895518220577137,
        0.7853981633974483,0.0011139513125403922,0.21895518220577137,
        0.9162978572970231,0.0011139513125403924,0.21895518220577137,
        1.0471975511965976,0.0011139513125403924,0.21895518220577137,
        1.1780972450961724,0.001113951312540393,0.21895518220577137,
        1.3089969389957472,0.0011139513125403922,0.21895518220577137,
        1.4398966328953218,0.0011139513125403924,0.21895518220577137,
        1.5707963267948966,0.001113951312540393,0.21895518220577137,
        1.7016960206944711,0.001113951312540393,0.21895518220577137,
        1.8325957145940461,0.001113951312540393,0.21895518220577137,
        1.9634954084936207,0.001113951312540393,0.21895518220577137,
        2.0943951023931953,0.0011139513125403926,0.21895518220577137,
        2.2252947962927703,0.0011139513125403924,0.21895518220577137,
        2.356194490192345,0.0011139513125403924,0.21895518220577137,
        2.4870941840919194,0.0011139513125403928,0.21895518220577137,
        2.6179938779914944,0.001113951312540393,0.21895518220577137,
        2.748893571891069,0.0011139513125403933,0.21895518220577137,
        2.8797932657906435,0.0011139513125403933,0.21895518220577137,
        3.0106929596902186,0.0011139513125403928,0.21895518220577137,
        3.141592653589793,0.001113951312540393,0.21895518220577137,
        3.272492347489368,0.0011139513125403928,0.21895518220577137,
        3.4033920413889422,0.0011139513125403924,0.21895518220577137,
        3.5342917352885173,0.0011139513125403926,0.21895518220577137,
        3.6651914291880923,0.0011139513125403926,0.21895518220577137,
        3.7960911230876664,0.0011139513125403933,0.21895518220577137,
        3.9269908169872414,0.001113951312540393,0.21895518220577137,
        4.057890510886816,0.001113951312540393,0.21895518220577137,
        4.1887902047863905,0.0011139513125403928,0.21895518220577137,
        4.319689898685965,0.0011139513125403935,0.21895518220577137,
        4.4505895925855405,0.0011139513125403933,0.21895518220577137,
        4.581489286485115,0.001113951312540393,0.21895518220577137,4.71238898038469,
        0.001113951312540393,0.21895518220577137,4.843288674284264,
        0.0011139513125403926,0.21895518220577137,4.974188368183839,
        0.0011139513125403926,0.21895518220577137,5.105088062083414,
        0.0011139513125403913,0.21895518220577137,5.235987755982989,
        0.0011139513125403907,0.21895518220577137,5.366887449882563,
        0.00111395131254039,0.21895518220577137,5.497787143782138,
        0.0011139513125403902,0.21895518220577137,5.6286868376817125,
        0.0011139513125403909,0.21895518220577137,5.759586531581287,
        0.0011139513125403926,0.21895518220577137,5.890486225480862,
        0.0011139513125403933,0.21895518220577137,6.021385919380437,
        0.0011139513125403941,0.21895518220577137,6.152285613280012,
        0.001113951312540395,0.3391882411034434,0.,0.001667482588828787,
        0.3391882411034434,0.1308996938995747,0.0016674825888287855,
        0.3391882411034434,0.2617993877991494,0.0016674825888287862,
        0.3391882411034434,0.39269908169872414,0.001667482588828787,
        0.3391882411034434,0.5235987755982988,0.0016674825888287883,
        0.3391882411034434,0.6544984694978736,0.0016674825888287879,
        0.3391882411034434,0.7853981633974483,0.001667482588828787,
        0.3391882411034434,0.9162978572970231,0.0016674825888287864,
        0.3391882411034434,1.0471975511965976,0.0016674825888287864,
        0.3391882411034434,1.1780972450961724,0.0016674825888287866,
        0.3391882411034434,1.3089969389957472,0.0016674825888287862,
        0.3391882411034434,1.4398966328953218,0.0016674825888287855,
        0.3391882411034434,1.5707963267948966,0.0016674825888287862,
        0.3391882411034434,1.7016960206944711,0.0016674825888287862,
        0.3391882411034434,1.8325957145940461,0.0016674825888287868,
        0.3391882411034434,1.9634954084936207,0.0016674825888287866,
        0.3391882411034434,2.0943951023931953,0.0016674825888287862,
        0.3391882411034434,2.2252947962927703,0.001667482588828785,
        0.3391882411034434,2.356194490192345,0.001667482588828785,
        0.3391882411034434,2.4870941840919194,0.001667482588828786,
        0.3391882411034434,2.6179938779914944,0.0016674825888287862,
        0.3391882411034434,2.748893571891069,0.0016674825888287872,
        0.3391882411034434,2.8797932657906435,0.0016674825888287879,
        0.3391882411034434,3.0106929596902186,0.0016674825888287877,
        0.3391882411034434,3.141592653589793,0.0016674825888287866,
        0.3391882411034434,3.272492347489368,0.0016674825888287853,
        0.3391882411034434,3.4033920413889422,0.0016674825888287844,
        0.3391882411034434,3.5342917352885173,0.0016674825888287849,
        0.3391882411034434,3.6651914291880923,0.0016674825888287864,
        0.3391882411034434,3.7960911230876664,0.0016674825888287868,
        0.3391882411034434,3.9269908169872414,0.0016674825888287864,
        0.3391882411034434,4.057890510886816,0.0016674825888287857,
        0.3391882411034434,4.1887902047863905,0.0016674825888287868,
        0.3391882411034434,4.319689898685965,0.0016674825888287866,
        0.3391882411034434,4.4505895925855405,0.0016674825888287864,
        0.3391882411034434,4.581489286485115,0.0016674825888287846,
        0.3391882411034434,4.71238898038469,0.0016674825888287849,
        0.3391882411034434,4.843288674284264,0.001667482588828787,
        0.3391882411034434,4.974188368183839,0.0016674825888287896,
        0.3391882411034434,5.105088062083414,0.0016674825888287896,
        0.3391882411034434,5.235987755982989,0.0016674825888287879,
        0.3391882411034434,5.366887449882563,0.0016674825888287842,
        0.3391882411034434,5.497787143782138,0.001667482588828784,
        0.3391882411034434,5.6286868376817125,0.001667482588828785,
        0.3391882411034434,5.759586531581287,0.001667482588828788,
        0.3391882411034434,5.890486225480862,0.0016674825888287892,
        0.3391882411034434,6.021385919380437,0.0016674825888287911,
        0.3391882411034434,6.152285613280012,0.0016674825888287894,
        0.45424775492751895,0.,0.00211632736194162,0.45424775492751895,
        0.1308996938995747,0.0021163273619416167,0.45424775492751895,
        0.2617993877991494,0.002116327361941617,0.45424775492751895,
        0.39269908169872414,0.002116327361941622,0.45424775492751895,
        0.5235987755982988,0.002116327361941624,0.45424775492751895,
        0.6544984694978736,0.0021163273619416207,0.45424775492751895,
        0.7853981633974483,0.0021163273619416176,0.45424775492751895,
        0.9162978572970231,0.0021163273619416185,0.45424775492751895,
        1.0471975511965976,0.002116327361941621,0.45424775492751895,
        1.1780972450961724,0.0021163273619416237,0.45424775492751895,
        1.3089969389957472,0.002116327361941621,0.45424775492751895,
        1.4398966328953218,0.0021163273619416176,0.45424775492751895,
        1.5707963267948966,0.0021163273619416207,0.45424775492751895,
        1.7016960206944711,0.0021163273619416224,0.45424775492751895,
        1.8325957145940461,0.0021163273619416224,0.45424775492751895,
        1.9634954084936207,0.00211632736194162,0.45424775492751895,
        2.0943951023931953,0.0021163273619416185,0.45424775492751895,
        2.2252947962927703,0.0021163273619416193,0.45424775492751895,
        2.356194490192345,0.00211632736194162,0.45424775492751895,
        2.4870941840919194,0.0021163273619416198,0.45424775492751895,
        2.6179938779914944,0.002116327361941621,0.45424775492751895,
        2.748893571891069,0.0021163273619416198,0.45424775492751895,
        2.8797932657906435,0.0021163273619416207,0.45424775492751895,
        3.0106929596902186,0.0021163273619416215,0.45424775492751895,
        3.141592653589793,0.002116327361941621,0.45424775492751895,
        3.272492347489368,0.002116327361941618,0.45424775492751895,
        3.4033920413889422,0.0021163273619416154,0.45424775492751895,
        3.5342917352885173,0.0021163273619416163,0.45424775492751895,
        3.6651914291880923,0.002116327361941621,0.45424775492751895,
        3.7960911230876664,0.002116327361941622,0.45424775492751895,
        3.9269908169872414,0.0021163273619416198,0.45424775492751895,
        4.057890510886816,0.0021163273619416167,0.45424775492751895,
        4.1887902047863905,0.002116327361941619,0.45424775492751895,
        4.319689898685965,0.002116327361941626,0.45424775492751895,
        4.4505895925855405,0.0021163273619416267,0.45424775492751895,
        4.581489286485115,0.0021163273619416193,0.45424775492751895,
        4.71238898038469,0.0021163273619416146,0.45424775492751895,
        4.843288674284264,0.002116327361941621,0.45424775492751895,
        4.974188368183839,0.002116327361941628,0.45424775492751895,
        5.105088062083414,0.002116327361941626,0.45424775492751895,
        5.235987755982989,0.0021163273619416185,0.45424775492751895,
        5.366887449882563,0.002116327361941614,0.45424775492751895,
        5.497787143782138,0.002116327361941615,0.45424775492751895,
        5.6286868376817125,0.002116327361941619,0.45424775492751895,
        5.759586531581287,0.0021163273619416198,0.45424775492751895,
        5.890486225480862,0.002116327361941622,0.45424775492751895,
        6.021385919380437,0.002116327361941624,0.45424775492751895,
        6.152285613280012,0.0021163273619416233,0.5622137053655931,0.,
        0.0024322139219563896,0.5622137053655931,0.1308996938995747,
        0.0024322139219563853,0.5622137053655931,0.2617993877991494,
        0.0024322139219563844,0.5622137053655931,0.39269908169872414,
        0.0024322139219563883,0.5622137053655931,0.5235987755982988,
        0.0024322139219563913,0.5622137053655931,0.6544984694978736,
        0.0024322139219563883,0.5622137053655931,0.7853981633974483,
        0.002432213921956383,0.5622137053655931,0.9162978572970231,
        0.002432213921956382,0.5622137053655931,1.0471975511965976,
        0.002432213921956388,0.5622137053655931,1.1780972450961724,
        0.0024322139219563927,0.5622137053655931,1.3089969389957472,
        0.002432213921956385,0.5622137053655931,1.4398966328953218,
        0.0024322139219563805,0.5622137053655931,1.5707963267948966,
        0.0024322139219563857,0.5622137053655931,1.7016960206944711,
        0.002432213921956391,0.5622137053655931,1.8325957145940461,
        0.002432213921956388,0.5622137053655931,1.9634954084936207,
        0.0024322139219563857,0.5622137053655931,2.0943951023931953,
        0.002432213921956387,0.5622137053655931,2.2252947962927703,
        0.002432213921956387,0.5622137053655931,2.356194490192345,
        0.002432213921956387,0.5622137053655931,2.4870941840919194,
        0.002432213921956388,0.5622137053655931,2.6179938779914944,
        0.002432213921956387,0.5622137053655931,2.748893571891069,
        0.0024322139219563857,0.5622137053655931,2.8797932657906435,
        0.0024322139219563857,0.5622137053655931,3.0106929596902186,
        0.00243221392195639,0.5622137053655931,3.141592653589793,
        0.0024322139219563918,0.5622137053655931,3.272492347489368,
        0.0024322139219563866,0.5622137053655931,3.4033920413889422,
        0.0024322139219563822,0.5622137053655931,3.5342917352885173,
        0.002432213921956385,0.5622137053655931,3.6651914291880923,
        0.002432213921956388,0.5622137053655931,3.7960911230876664,
        0.002432213921956391,0.5622137053655931,3.9269908169872414,
        0.00243221392195639,0.5622137053655931,4.057890510886816,
        0.002432213921956383,0.5622137053655931,4.1887902047863905,
        0.0024322139219563814,0.5622137053655931,4.319689898685965,
        0.0024322139219563913,0.5622137053655931,4.4505895925855405,
        0.0024322139219563966,0.5622137053655931,4.581489286485115,
        0.002432213921956385,0.5622137053655931,4.71238898038469,
        0.0024322139219563744,0.5622137053655931,4.843288674284264,
        0.002432213921956385,0.5622137053655931,4.974188368183839,
        0.0024322139219563996,0.5622137053655931,5.105088062083414,
        0.0024322139219563935,0.5622137053655931,5.235987755982989,
        0.0024322139219563783,0.5622137053655931,5.366887449882563,
        0.0024322139219563783,0.5622137053655931,5.497787143782138,
        0.002432213921956386,0.5622137053655931,5.6286868376817125,
        0.0024322139219563857,0.5622137053655931,5.759586531581287,
        0.002432213921956385,0.5622137053655931,5.890486225480862,
        0.0024322139219563896,0.5622137053655931,6.021385919380437,
        0.002432213921956394,0.5622137053655931,6.152285613280012,
        0.0024322139219563927,0.6613496017570931,0.,0.002595281727601005,
        0.6613496017570931,0.1308996938995747,0.0025952817276010016,
        0.6613496017570931,0.2617993877991494,0.0025952817276010016,
        0.6613496017570931,0.39269908169872414,0.0025952817276010056,
        0.6613496017570931,0.5235987755982988,0.0025952817276010073,
        0.6613496017570931,0.6544984694978736,0.0025952817276010073,
        0.6613496017570931,0.7853981633974483,0.0025952817276010034,
        0.6613496017570931,0.9162978572970231,0.0025952817276009995,
        0.6613496017570931,1.0471975511965976,0.002595281727601006,
        0.6613496017570931,1.1780972450961724,0.0025952817276010125,
        0.6613496017570931,1.3089969389957472,0.002595281727601002,
        0.6613496017570931,1.4398966328953218,0.0025952817276009947,
        0.6613496017570931,1.5707963267948966,0.002595281727601007,
        0.6613496017570931,1.7016960206944711,0.0025952817276010108,
        0.6613496017570931,1.8325957145940461,0.002595281727601001,
        0.6613496017570931,1.9634954084936207,0.0025952817276010008,
        0.6613496017570931,2.0943951023931953,0.0025952817276010073,
        0.6613496017570931,2.2252947962927703,0.002595281727601004,
        0.6613496017570931,2.356194490192345,0.0025952817276009973,
        0.6613496017570931,2.4870941840919194,0.002595281727601003,
        0.6613496017570931,2.6179938779914944,0.002595281727601006,
        0.6613496017570931,2.748893571891069,0.002595281727601001,
        0.6613496017570931,2.8797932657906435,0.002595281727601001,
        0.6613496017570931,3.0106929596902186,0.0025952817276010056,
        0.6613496017570931,3.141592653589793,0.0025952817276010064,
        0.6613496017570931,3.272492347489368,0.002595281727601,0.6613496017570931,
        3.4033920413889422,0.0025952817276009964,0.6613496017570931,
        3.5342917352885173,0.0025952817276010025,0.6613496017570931,
        3.6651914291880923,0.002595281727601004,0.6613496017570931,
        3.7960911230876664,0.002595281727601001,0.6613496017570931,
        3.9269908169872414,0.0025952817276010064,0.6613496017570931,
        4.057890510886816,0.0025952817276010034,0.6613496017570931,
        4.1887902047863905,0.0025952817276009964,0.6613496017570931,
        4.319689898685965,0.0025952817276010064,0.6613496017570931,
        4.4505895925855405,0.002595281727601016,0.6613496017570931,
        4.581489286485115,0.0025952817276010042,0.6613496017570931,4.71238898038469,
        0.002595281727600991,0.6613496017570931,4.843288674284264,
        0.0025952817276010016,0.6613496017570931,4.974188368183839,
        0.002595281727601021,0.6613496017570931,5.105088062083414,
        0.002595281727601014,0.6613496017570931,5.235987755982989,
        0.0025952817276009934,0.6613496017570931,5.366887449882563,
        0.002595281727601001,0.6613496017570931,5.497787143782138,
        0.002595281727601008,0.6613496017570931,5.6286868376817125,
        0.0025952817276010003,0.6613496017570931,5.759586531581287,
        0.002595281727601001,0.6613496017570931,5.890486225480862,
        0.002595281727601011,0.6613496017570931,6.021385919380437,
        0.0025952817276010103,0.6613496017570931,6.152285613280012,
        0.0025952817276010047,0.7500777988020538,0.,0.002595281726817958,
        0.7500777988020538,0.1308996938995747,0.0025952817268179475,
        0.7500777988020538,0.2617993877991494,0.0025952817268179496,
        0.7500777988020538,0.39269908169872414,0.002595281726817955,
        0.7500777988020538,0.5235987755982988,0.002595281726817955,
        0.7500777988020538,0.6544984694978736,0.0025952817268179557,
        0.7500777988020538,0.7853981633974483,0.002595281726817952,
        0.7500777988020538,0.9162978572970231,0.0025952817268179483,
        0.7500777988020538,1.0471975511965976,0.0025952817268179514,
        0.7500777988020538,1.1780972450961724,0.0025952817268179626,
        0.7500777988020538,1.3089969389957472,0.002595281726817951,
        0.7500777988020538,1.4398966328953218,0.0025952817268179414,
        0.7500777988020538,1.5707963267948966,0.002595281726817956,
        0.7500777988020538,1.7016960206944711,0.0025952817268179605,
        0.7500777988020538,1.8325957145940461,0.002595281726817952,
        0.7500777988020538,1.9634954084936207,0.0025952817268179514,
        0.7500777988020538,2.0943951023931953,0.002595281726817955,
        0.7500777988020538,2.2252947962927703,0.0025952817268179505,
        0.7500777988020538,2.356194490192345,0.002595281726817948,
        0.7500777988020538,2.4870941840919194,0.002595281726817957,
        0.7500777988020538,2.6179938779914944,0.0025952817268179535,
        0.7500777988020538,2.748893571891069,0.002595281726817948,
        0.7500777988020538,2.8797932657906435,0.002595281726817955,
        0.7500777988020538,3.0106929596902186,0.002595281726817954,
        0.7500777988020538,3.141592653589793,0.002595281726817958,
        0.7500777988020538,3.272492347489368,0.002595281726817953,
        0.7500777988020538,3.4033920413889422,0.002595281726817945,
        0.7500777988020538,3.5342917352885173,0.002595281726817955,
        0.7500777988020538,3.6651914291880923,0.0025952817268179566,
        0.7500777988020538,3.7960911230876664,0.0025952817268179522,
        0.7500777988020538,3.9269908169872414,0.0025952817268179574,
        0.7500777988020538,4.057890510886816,0.0025952817268179527,
        0.7500777988020538,4.1887902047863905,0.0025952817268179453,
        0.7500777988020538,4.319689898685965,0.002595281726817959,
        0.7500777988020538,4.4505895925855405,0.002595281726817964,
        0.7500777988020538,4.581489286485115,0.0025952817268179488,
        0.7500777988020538,4.71238898038469,0.0025952817268179427,
        0.7500777988020538,4.843288674284264,0.0025952817268179475,
        0.7500777988020538,4.974188368183839,0.002595281726817966,
        0.7500777988020538,5.105088062083414,0.0025952817268179644,
        0.7500777988020538,5.235987755982989,0.002595281726817937,
        0.7500777988020538,5.366887449882563,0.0025952817268179475,
        0.7500777988020538,5.497787143782138,0.0025952817268179566,
        0.7500777988020538,5.6286868376817125,0.002595281726817945,
        0.7500777988020538,5.759586531581287,0.002595281726817952,
        0.7500777988020538,5.890486225480862,0.0025952817268179613,
        0.7500777988020538,6.021385919380437,0.0025952817268179535,
        0.7500777988020538,6.152285613280012,0.0025952817268179574,
        0.8269919887756411,0.,0.0024322139226584205,0.8269919887756411,
        0.1308996938995747,0.0024322139226584075,0.8269919887756411,
        0.2617993877991494,0.002432213922658418,0.8269919887756411,
        0.39269908169872414,0.0024322139226584157,0.8269919887756411,
        0.5235987755982988,0.002432213922658418,0.8269919887756411,
        0.6544984694978736,0.002432213922658419,0.8269919887756411,
        0.7853981633974483,0.0024322139226584114,0.8269919887756411,
        0.9162978572970231,0.0024322139226584123,0.8269919887756411,
        1.0471975511965976,0.002432213922658414,0.8269919887756411,
        1.1780972450961724,0.0024322139226584214,0.8269919887756411,
        1.3089969389957472,0.0024322139226584153,0.8269919887756411,
        1.4398966328953218,0.002432213922658403,0.8269919887756411,
        1.5707963267948966,0.0024322139226584188,0.8269919887756411,
        1.7016960206944711,0.002432213922658419,0.8269919887756411,
        1.8325957145940461,0.0024322139226584144,0.8269919887756411,
        1.9634954084936207,0.0024322139226584144,0.8269919887756411,
        2.0943951023931953,0.002432213922658416,0.8269919887756411,
        2.2252947962927703,0.0024322139226584183,0.8269919887756411,
        2.356194490192345,0.0024322139226584066,0.8269919887756411,
        2.4870941840919194,0.0024322139226584196,0.8269919887756411,
        2.6179938779914944,0.002432213922658417,0.8269919887756411,
        2.748893571891069,0.002432213922658408,0.8269919887756411,
        2.8797932657906435,0.002432213922658422,0.8269919887756411,
        3.0106929596902186,0.00243221392265841,0.8269919887756411,3.141592653589793,
        0.0024322139226584183,0.8269919887756411,3.272492347489368,
        0.002432213922658418,0.8269919887756411,3.4033920413889422,
        0.0024322139226584023,0.8269919887756411,3.5342917352885173,
        0.002432213922658417,0.8269919887756411,3.6651914291880923,
        0.002432213922658414,0.8269919887756411,3.7960911230876664,
        0.0024322139226584136,0.8269919887756411,3.9269908169872414,
        0.002432213922658417,0.8269919887756411,4.057890510886816,
        0.002432213922658414,0.8269919887756411,4.1887902047863905,
        0.0024322139226584075,0.8269919887756411,4.319689898685965,
        0.0024322139226584188,0.8269919887756411,4.4505895925855405,
        0.002432213922658428,0.8269919887756411,4.581489286485115,
        0.0024322139226584084,0.8269919887756411,4.71238898038469,
        0.0024322139226584097,0.8269919887756411,4.843288674284264,
        0.0024322139226584097,0.8269919887756411,4.974188368183839,
        0.0024322139226584283,0.8269919887756411,5.105088062083414,
        0.0024322139226584305,0.8269919887756411,5.235987755982989,
        0.0024322139226584,0.8269919887756411,5.366887449882563,
        0.0024322139226584114,0.8269919887756411,5.497787143782138,
        0.002432213922658421,0.8269919887756411,5.6286868376817125,
        0.0024322139226584066,0.8269919887756411,5.759586531581287,
        0.0024322139226584157,0.8269919887756411,5.890486225480862,
        0.0024322139226584253,0.8269919887756411,6.021385919380437,
        0.002432213922658416,0.8269919887756411,6.152285613280012,
        0.0024322139226584227,0.890875399336691,0.,0.0021163273613839144,
        0.890875399336691,0.1308996938995747,0.0021163273613839014,
        0.890875399336691,0.2617993877991494,0.0021163273613839144,
        0.890875399336691,0.39269908169872414,0.0021163273613839066,
        0.890875399336691,0.5235987755982988,0.002116327361383915,0.890875399336691,
        0.6544984694978736,0.0021163273613839153,0.890875399336691,
        0.7853981633974483,0.002116327361383906,0.890875399336691,
        0.9162978572970231,0.002116327361383909,0.890875399336691,
        1.0471975511965976,0.002116327361383908,0.890875399336691,
        1.1780972450961724,0.0021163273613839188,0.890875399336691,
        1.3089969389957472,0.0021163273613839097,0.890875399336691,
        1.4398966328953218,0.0021163273613838984,0.890875399336691,
        1.5707963267948966,0.0021163273613839157,0.890875399336691,
        1.7016960206944711,0.002116327361383914,0.890875399336691,
        1.8325957145940461,0.002116327361383909,0.890875399336691,
        1.9634954084936207,0.00211632736138391,0.890875399336691,2.0943951023931953,
        0.0021163273613839084,0.890875399336691,2.2252947962927703,
        0.0021163273613839144,0.890875399336691,2.356194490192345,
        0.0021163273613839014,0.890875399336691,2.4870941840919194,
        0.0021163273613839136,0.890875399336691,2.6179938779914944,
        0.002116327361383916,0.890875399336691,2.748893571891069,
        0.0021163273613838992,0.890875399336691,2.8797932657906435,
        0.0021163273613839196,0.890875399336691,3.0106929596902186,
        0.0021163273613839053,0.890875399336691,3.141592653589793,
        0.002116327361383916,0.890875399336691,3.272492347489368,
        0.0021163273613839114,0.890875399336691,3.4033920413889422,
        0.0021163273613838966,0.890875399336691,3.5342917352885173,
        0.002116327361383918,0.890875399336691,3.6651914291880923,
        0.002116327361383904,0.890875399336691,3.7960911230876664,
        0.002116327361383912,0.890875399336691,3.9269908169872414,
        0.0021163273613839105,0.890875399336691,4.057890510886816,
        0.002116327361383909,0.890875399336691,4.1887902047863905,
        0.0021163273613839053,0.890875399336691,4.319689898685965,
        0.0021163273613839066,0.890875399336691,4.4505895925855405,
        0.002116327361383927,0.890875399336691,4.581489286485115,
        0.0021163273613839014,0.890875399336691,4.71238898038469,
        0.002116327361383905,0.890875399336691,4.843288674284264,
        0.002116327361383904,0.890875399336691,4.974188368183839,
        0.002116327361383922,0.890875399336691,5.105088062083414,
        0.002116327361383923,0.890875399336691,5.235987755982989,
        0.002116327361383895,0.890875399336691,5.366887449882563,
        0.0021163273613839084,0.890875399336691,5.497787143782138,
        0.0021163273613839127,0.890875399336691,5.6286868376817125,
        0.0021163273613839058,0.890875399336691,5.759586531581287,
        0.002116327361383906,0.890875399336691,5.890486225480862,
        0.0021163273613839188,0.890875399336691,6.021385919380437,
        0.00211632736138391,0.890875399336691,6.152285613280012,
        0.002116327361383914,0.9407185217147329,0.,0.0016674825892089985,
        0.9407185217147329,0.1308996938995747,0.0016674825892089835,
        0.9407185217147329,0.2617993877991494,0.0016674825892089972,
        0.9407185217147329,0.39269908169872414,0.0016674825892089898,
        0.9407185217147329,0.5235987755982988,0.001667482589208997,
        0.9407185217147329,0.6544984694978736,0.001667482589208991,
        0.9407185217147329,0.7853981633974483,0.0016674825892089903,
        0.9407185217147329,0.9162978572970231,0.0016674825892089918,
        0.9407185217147329,1.0471975511965976,0.0016674825892089879,
        0.9407185217147329,1.1780972450961724,0.0016674825892089983,
        0.9407185217147329,1.3089969389957472,0.001667482589208989,
        0.9407185217147329,1.4398966328953218,0.0016674825892089846,
        0.9407185217147329,1.5707963267948966,0.0016674825892089922,
        0.9407185217147329,1.7016960206944711,0.001667482589208995,
        0.9407185217147329,1.8325957145940461,0.0016674825892089879,
        0.9407185217147329,1.9634954084936207,0.0016674825892089927,
        0.9407185217147329,2.0943951023931953,0.0016674825892089896,
        0.9407185217147329,2.2252947962927703,0.0016674825892089924,
        0.9407185217147329,2.356194490192345,0.0016674825892089875,
        0.9407185217147329,2.4870941840919194,0.0016674825892089905,
        0.9407185217147329,2.6179938779914944,0.0016674825892089955,
        0.9407185217147329,2.748893571891069,0.0016674825892089831,
        0.9407185217147329,2.8797932657906435,0.0016674825892089996,
        0.9407185217147329,3.0106929596902186,0.0016674825892089864,
        0.9407185217147329,3.141592653589793,0.001667482589208993,
        0.9407185217147329,3.272492347489368,0.0016674825892089946,
        0.9407185217147329,3.4033920413889422,0.0016674825892089792,
        0.9407185217147329,3.5342917352885173,0.0016674825892089985,
        0.9407185217147329,3.6651914291880923,0.0016674825892089848,
        0.9407185217147329,3.7960911230876664,0.0016674825892089972,
        0.9407185217147329,3.9269908169872414,0.0016674825892089911,
        0.9407185217147329,4.057890510886816,0.001667482589208989,
        0.9407185217147329,4.1887902047863905,0.0016674825892089914,
        0.9407185217147329,4.319689898685965,0.0016674825892089872,
        0.9407185217147329,4.4505895925855405,0.0016674825892090059,
        0.9407185217147329,4.581489286485115,0.001667482589208982,
        0.9407185217147329,4.71238898038469,0.0016674825892089903,
        0.9407185217147329,4.843288674284264,0.0016674825892089846,
        0.9407185217147329,4.974188368183839,0.0016674825892090013,
        0.9407185217147329,5.105088062083414,0.0016674825892090002,
        0.9407185217147329,5.235987755982989,0.00166748258920898,0.9407185217147329,
        5.366887449882563,0.00166748258920899,0.9407185217147329,5.497787143782138,
        0.0016674825892089905,0.9407185217147329,5.6286868376817125,
        0.00166748258920899,0.9407185217147329,5.759586531581287,
        0.0016674825892089879,0.9407185217147329,5.890486225480862,
        0.001667482589209,0.9407185217147329,6.021385919380437,0.001667482589208992,
        0.9407185217147329,6.152285613280012,0.0016674825892089948,
        0.9757349169652777,0.,0.0011139513123372606,0.9757349169652777,
        0.1308996938995747,0.0011139513123372517,0.9757349169652777,
        0.2617993877991494,0.0011139513123372615,0.9757349169652777,
        0.39269908169872414,0.0011139513123372537,0.9757349169652777,
        0.5235987755982988,0.0011139513123372621,0.9757349169652777,
        0.6544984694978736,0.0011139513123372576,0.9757349169652777,
        0.7853981633974483,0.0011139513123372576,0.9757349169652777,
        0.9162978572970231,0.0011139513123372565,0.9757349169652777,
        1.0471975511965976,0.0011139513123372574,0.9757349169652777,
        1.1780972450961724,0.0011139513123372634,0.9757349169652777,
        1.3089969389957472,0.0011139513123372535,0.9757349169652777,
        1.4398966328953218,0.0011139513123372574,0.9757349169652777,
        1.5707963267948966,0.0011139513123372541,0.9757349169652777,
        1.7016960206944711,0.0011139513123372639,0.9757349169652777,
        1.8325957145940461,0.0011139513123372548,0.9757349169652777,
        1.9634954084936207,0.0011139513123372576,0.9757349169652777,
        2.0943951023931953,0.0011139513123372582,0.9757349169652777,
        2.2252947962927703,0.0011139513123372565,0.9757349169652777,
        2.356194490192345,0.0011139513123372563,0.9757349169652777,
        2.4870941840919194,0.001113951312337256,0.9757349169652777,
        2.6179938779914944,0.0011139513123372608,0.9757349169652777,
        2.748893571891069,0.0011139513123372513,0.9757349169652777,
        2.8797932657906435,0.00111395131233726,0.9757349169652777,
        3.0106929596902186,0.001113951312337257,0.9757349169652777,
        3.141592653589793,0.0011139513123372574,0.9757349169652777,
        3.272492347489368,0.00111395131233726,0.9757349169652777,3.4033920413889422,
        0.0011139513123372478,0.9757349169652777,3.5342917352885173,
        0.0011139513123372613,0.9757349169652777,3.6651914291880923,
        0.0011139513123372548,0.9757349169652777,3.7960911230876664,
        0.0011139513123372578,0.9757349169652777,3.9269908169872414,
        0.0011139513123372578,0.9757349169652777,4.057890510886816,
        0.001113951312337258,0.9757349169652777,4.1887902047863905,
        0.0011139513123372541,0.9757349169652777,4.319689898685965,
        0.0011139513123372565,0.9757349169652777,4.4505895925855405,
        0.0011139513123372676,0.9757349169652777,4.581489286485115,
        0.00111395131233725,0.9757349169652777,4.71238898038469,
        0.0011139513123372593,0.9757349169652777,4.843288674284264,
        0.001113951312337251,0.9757349169652777,4.974188368183839,
        0.0011139513123372665,0.9757349169652777,5.105088062083414,
        0.0011139513123372634,0.9757349169652777,5.235987755982989,
        0.0011139513123372506,0.9757349169652777,5.366887449882563,
        0.001113951312337257,0.9757349169652777,5.497787143782138,
        0.0011139513123372578,0.9757349169652777,5.6286868376817125,
        0.0011139513123372565,0.9757349169652777,5.759586531581287,
        0.0011139513123372552,0.9757349169652777,5.890486225480862,
        0.0011139513123372637,0.9757349169652777,6.021385919380437,
        0.0011139513123372576,0.9757349169652777,6.152285613280012,
        0.0011139513123372604,0.9953794839775228,0.,0.0004914097540590246,
        0.9953794839775228,0.1308996938995747,0.0004914097540590192,
        0.9953794839775228,0.2617993877991494,0.0004914097540590222,
        0.9953794839775228,0.39269908169872414,0.0004914097540590208,
        0.9953794839775228,0.5235987755982988,0.0004914097540590225,
        0.9953794839775228,0.6544984694978736,0.0004914097540590221,
        0.9953794839775228,0.7853981633974483,0.0004914097540590199,
        0.9953794839775228,0.9162978572970231,0.0004914097540590214,
        0.9953794839775228,1.0471975511965976,0.0004914097540590202,
        0.9953794839775228,1.1780972450961724,0.0004914097540590247,
        0.9953794839775228,1.3089969389957472,0.0004914097540590199,
        0.9953794839775228,1.4398966328953218,0.0004914097540590186,
        0.9953794839775228,1.5707963267948966,0.0004914097540590217,
        0.9953794839775228,1.7016960206944711,0.0004914097540590224,
        0.9953794839775228,1.8325957145940461,0.0004914097540590207,
        0.9953794839775228,1.9634954084936207,0.0004914097540590233,
        0.9953794839775228,2.0943951023931953,0.0004914097540590188,
        0.9953794839775228,2.2252947962927703,0.0004914097540590255,
        0.9953794839775228,2.356194490192345,0.0004914097540590182,
        0.9953794839775228,2.4870941840919194,0.0004914097540590247,
        0.9953794839775228,2.6179938779914944,0.0004914097540590206,
        0.9953794839775228,2.748893571891069,0.0004914097540590215,
        0.9953794839775228,2.8797932657906435,0.0004914097540590224,
        0.9953794839775228,3.0106929596902186,0.0004914097540590208,
        0.9953794839775228,3.141592653589793,0.000491409754059023,
        0.9953794839775228,3.272492347489368,0.0004914097540590221,
        0.9953794839775228,3.4033920413889422,0.0004914097540590173,
        0.9953794839775228,3.5342917352885173,0.0004914097540590225,
        0.9953794839775228,3.6651914291880923,0.0004914097540590182,
        0.9953794839775228,3.7960911230876664,0.0004914097540590227,
        0.9953794839775228,3.9269908169872414,0.0004914097540590214,
        0.9953794839775228,4.057890510886816,0.00049140975405902,0.9953794839775228,
        4.1887902047863905,0.0004914097540590211,0.9953794839775228,
        4.319689898685965,0.0004914097540590201,0.9953794839775228,
        4.4505895925855405,0.0004914097540590246,0.9953794839775228,
        4.581489286485115,0.0004914097540590189,0.9953794839775228,4.71238898038469,
        0.0004914097540590197,0.9953794839775228,4.843288674284264,
        0.0004914097540590207,0.9953794839775228,4.974188368183839,
        0.0004914097540590248,0.9953794839775228,5.105088062083414,
        0.0004914097540590221,0.9953794839775228,5.235987755982989,
        0.0004914097540590209,0.9953794839775228,5.366887449882563,
        0.0004914097540590194,0.9953794839775228,5.497787143782138,
        0.0004914097540590245,0.9953794839775228,5.6286868376817125,
        0.0004914097540590187,0.9953794839775228,5.759586531581287,
        0.0004914097540590223,0.9953794839775228,5.890486225480862,
        0.0004914097540590226,0.9953794839775228,6.021385919380437,
        0.0004914097540590238,0.9953794839775228,6.152285613280012,
        0.0004914097540590215,0.,0.,0.005917159693430448,0.14684026411665965,0.,
        0.0007190241662303936,0.14684026411665965,0.12566370614359174,
        0.0007190241662303773,0.14684026411665965,0.25132741228718347,
        0.000719024166230392,0.14684026411665965,0.37699111843077515,
        0.0007190241662303923,0.14684026411665965,0.5026548245743669,
        0.0007190241662303919,0.14684026411665965,0.6283185307179586,
        0.0007190241662303924,0.14684026411665965,0.7539822368615503,
        0.0007190241662303916,0.14684026411665965,0.8796459430051422,
        0.000719024166230391,0.14684026411665965,1.0053096491487339,
        0.0007190241662303904,0.14684026411665965,1.1309733552923256,
        0.0007190241662303903,0.14684026411665965,1.2566370614359172,
        0.000719024166230391,0.14684026411665965,1.382300767579509,
        0.0007190241662303896,0.14684026411665965,1.5079644737231006,
        0.0007190241662303902,0.14684026411665965,1.6336281798666925,
        0.0007190241662303907,0.14684026411665965,1.7592918860102844,
        0.0007190241662303904,0.14684026411665965,1.8849555921538759,
        0.0007190241662303909,0.14684026411665965,2.0106192982974678,
        0.0007190241662303909,0.14684026411665965,2.1362830044410597,
        0.0007190241662303901,0.14684026411665965,2.261946710584651,
        0.0007190241662303911,0.14684026411665965,2.3876104167282426,
        0.0007190241662303903,0.14684026411665965,2.5132741228718345,
        0.0007190241662303916,0.14684026411665965,2.638937829015426,
        0.0007190241662303911,0.14684026411665965,2.764601535159018,
        0.0007190241662303911,0.14684026411665965,2.8902652413026098,
        0.0007190241662303916,0.14684026411665965,3.015928947446201,
        0.0007190241662303922,0.14684026411665965,3.141592653589793,
        0.0007190241662303912,0.14684026411665965,3.267256359733385,
        0.0007190241662303913,0.14684026411665965,3.392920065876977,
        0.000719024166230392,0.14684026411665965,3.518583772020569,
        0.0007190241662303923,0.14684026411665965,3.64424747816416,
        0.0007190241662303919,0.14684026411665965,3.7699111843077517,
        0.0007190241662303915,0.14684026411665965,3.8955748904513436,
        0.0007190241662303924,0.14684026411665965,4.0212385965949355,
        0.000719024166230391,0.14684026411665965,4.1469023027385274,
        0.0007190241662303906,0.14684026411665965,4.272566008882119,
        0.00071902416623039,0.14684026411665965,4.39822971502571,
        0.0007190241662303903,0.14684026411665965,4.523893421169302,
        0.0007190241662303891,0.14684026411665965,4.649557127312894,
        0.0007190241662303897,0.14684026411665965,4.775220833456485,
        0.0007190241662303891,0.14684026411665965,4.900884539600077,
        0.0007190241662303887,0.14684026411665965,5.026548245743669,
        0.0007190241662303881,0.14684026411665965,5.15221195188726,
        0.0007190241662303897,0.14684026411665965,5.277875658030852,
        0.000719024166230391,0.14684026411665965,5.403539364174444,
        0.0007190241662303889,0.14684026411665965,5.529203070318036,
        0.0007190241662303902,0.14684026411665965,5.654866776461628,
        0.0007190241662303911,0.14684026411665965,5.7805304826052195,
        0.0007190241662303922,0.14684026411665965,5.9061941887488105,
        0.0007190241662303918,0.14684026411665965,6.031857894892402,
        0.0007190241662303935,0.14684026411665965,6.157521601035994,
        0.0007190241662303944,0.26656687479052793,0.,0.0012510383393376534,
        0.26656687479052793,0.12566370614359174,0.0012510383393376534,
        0.26656687479052793,0.25132741228718347,0.001251038339337653,
        0.26656687479052793,0.37699111843077515,0.001251038339337652,
        0.26656687479052793,0.5026548245743669,0.0012510383393376525,
        0.26656687479052793,0.6283185307179586,0.0012510383393376536,
        0.26656687479052793,0.7539822368615503,0.0012510383393376525,
        0.26656687479052793,0.8796459430051422,0.0012510383393376531,
        0.26656687479052793,1.0053096491487339,0.001251038339337652,
        0.26656687479052793,1.1309733552923256,0.0012510383393376518,
        0.26656687479052793,1.2566370614359172,0.0012510383393376523,
        0.26656687479052793,1.382300767579509,0.0012510383393376516,
        0.26656687479052793,1.5079644737231006,0.0012510383393376534,
        0.26656687479052793,1.6336281798666925,0.0012510383393376536,
        0.26656687479052793,1.7592918860102844,0.0012510383393376544,
        0.26656687479052793,1.8849555921538759,0.0012510383393376538,
        0.26656687479052793,2.0106192982974678,0.001251038339337654,
        0.26656687479052793,2.1362830044410597,0.0012510383393376518,
        0.26656687479052793,2.261946710584651,0.00125103833933765,
        0.26656687479052793,2.3876104167282426,0.0012510383393376497,
        0.26656687479052793,2.5132741228718345,0.0012510383393376508,
        0.26656687479052793,2.638937829015426,0.001251038339337651,
        0.26656687479052793,2.764601535159018,0.00125103833933765,
        0.26656687479052793,2.8902652413026098,0.0012510383393376516,
        0.26656687479052793,3.015928947446201,0.001251038339337653,
        0.26656687479052793,3.141592653589793,0.0012510383393376534,
        0.26656687479052793,3.267256359733385,0.001251038339337652,
        0.26656687479052793,3.392920065876977,0.001251038339337652,
        0.26656687479052793,3.518583772020569,0.001251038339337651,
        0.26656687479052793,3.64424747816416,0.0012510383393376494,
        0.26656687479052793,3.7699111843077517,0.0012510383393376508,
        0.26656687479052793,3.8955748904513436,0.0012510383393376518,
        0.26656687479052793,4.0212385965949355,0.0012510383393376536,
        0.26656687479052793,4.1469023027385274,0.0012510383393376542,
        0.26656687479052793,4.272566008882119,0.0012510383393376542,
        0.26656687479052793,4.39822971502571,0.0012510383393376518,
        0.26656687479052793,4.523893421169302,0.0012510383393376514,
        0.26656687479052793,4.649557127312894,0.001251038339337652,
        0.26656687479052793,4.775220833456485,0.001251038339337651,
        0.26656687479052793,4.900884539600077,0.001251038339337652,
        0.26656687479052793,5.026548245743669,0.001251038339337652,
        0.26656687479052793,5.15221195188726,0.0012510383393376527,
        0.26656687479052793,5.277875658030852,0.0012510383393376536,
        0.26656687479052793,5.403539364174444,0.0012510383393376538,
        0.26656687479052793,5.529203070318036,0.0012510383393376534,
        0.26656687479052793,5.654866776461628,0.0012510383393376523,
        0.26656687479052793,5.7805304826052195,0.001251038339337652,
        0.26656687479052793,5.9061941887488105,0.0012510383393376512,
        0.26656687479052793,6.031857894892402,0.0012510383393376525,
        0.26656687479052793,6.157521601035994,0.001251038339337653,
        0.38137574153984166,0.,0.0017100346087660586,0.38137574153984166,
        0.12566370614359174,0.0017100346087660552,0.38137574153984166,
        0.25132741228718347,0.001710034608766051,0.38137574153984166,
        0.37699111843077515,0.0017100346087660506,0.38137574153984166,
        0.5026548245743669,0.0017100346087660524,0.38137574153984166,
        0.6283185307179586,0.0017100346087660547,0.38137574153984166,
        0.7539822368615503,0.0017100346087660547,0.38137574153984166,
        0.8796459430051422,0.0017100346087660552,0.38137574153984166,
        1.0053096491487339,0.0017100346087660528,0.38137574153984166,
        1.1309733552923256,0.0017100346087660513,0.38137574153984166,
        1.2566370614359172,0.0017100346087660502,0.38137574153984166,
        1.382300767579509,0.001710034608766052,0.38137574153984166,
        1.5079644737231006,0.0017100346087660524,0.38137574153984166,
        1.6336281798666925,0.0017100346087660537,0.38137574153984166,
        1.7592918860102844,0.0017100346087660537,0.38137574153984166,
        1.8849555921538759,0.0017100346087660534,0.38137574153984166,
        2.0106192982974678,0.0017100346087660547,0.38137574153984166,
        2.1362830044410597,0.0017100346087660543,0.38137574153984166,
        2.261946710584651,0.0017100346087660508,0.38137574153984166,
        2.3876104167282426,0.0017100346087660513,0.38137574153984166,
        2.5132741228718345,0.0017100346087660502,0.38137574153984166,
        2.638937829015426,0.0017100346087660526,0.38137574153984166,
        2.764601535159018,0.0017100346087660534,0.38137574153984166,
        2.8902652413026098,0.0017100346087660534,0.38137574153984166,
        3.015928947446201,0.0017100346087660547,0.38137574153984166,
        3.141592653589793,0.0017100346087660576,0.38137574153984166,
        3.267256359733385,0.001710034608766057,0.38137574153984166,
        3.392920065876977,0.0017100346087660558,0.38137574153984166,
        3.518583772020569,0.0017100346087660524,0.38137574153984166,
        3.64424747816416,0.0017100346087660495,0.38137574153984166,
        3.7699111843077517,0.001710034608766051,0.38137574153984166,
        3.8955748904513436,0.0017100346087660537,0.38137574153984166,
        4.0212385965949355,0.0017100346087660565,0.38137574153984166,
        4.1469023027385274,0.0017100346087660554,0.38137574153984166,
        4.272566008882119,0.0017100346087660528,0.38137574153984166,
        4.39822971502571,0.001710034608766049,0.38137574153984166,4.523893421169302,
        0.0017100346087660493,0.38137574153984166,4.649557127312894,
        0.0017100346087660502,0.38137574153984166,4.775220833456485,
        0.00171003460876605,0.38137574153984166,4.900884539600077,
        0.0017100346087660493,0.38137574153984166,5.026548245743669,
        0.0017100346087660493,0.38137574153984166,5.15221195188726,
        0.001710034608766052,0.38137574153984166,5.277875658030852,
        0.0017100346087660543,0.38137574153984166,5.403539364174444,
        0.0017100346087660576,0.38137574153984166,5.529203070318036,
        0.001710034608766057,0.38137574153984166,5.654866776461628,
        0.0017100346087660526,0.38137574153984166,5.7805304826052195,
        0.0017100346087660506,0.38137574153984166,5.9061941887488105,
        0.0017100346087660515,0.38137574153984166,6.031857894892402,
        0.001710034608766055,0.38137574153984166,6.157521601035994,
        0.0017100346087660586,0.49030715931421287,0.,0.0020696061107830154,
        0.49030715931421287,0.12566370614359174,0.0020696061107830107,
        0.49030715931421287,0.25132741228718347,0.0020696061107830068,
        0.49030715931421287,0.37699111843077515,0.002069606110783009,
        0.49030715931421287,0.5026548245743669,0.002069606110783011,
        0.49030715931421287,0.6283185307179586,0.0020696061107830102,
        0.49030715931421287,0.7539822368615503,0.0020696061107830094,
        0.49030715931421287,0.8796459430051422,0.002069606110783012,
        0.49030715931421287,1.0053096491487339,0.0020696061107830102,
        0.49030715931421287,1.1309733552923256,0.0020696061107830055,
        0.49030715931421287,1.2566370614359172,0.0020696061107830024,
        0.49030715931421287,1.382300767579509,0.0020696061107830076,
        0.49030715931421287,1.5079644737231006,0.002069606110783013,
        0.49030715931421287,1.6336281798666925,0.002069606110783012,
        0.49030715931421287,1.7592918860102844,0.0020696061107830063,
        0.49030715931421287,1.8849555921538759,0.0020696061107830068,
        0.49030715931421287,2.0106192982974678,0.002069606110783012,
        0.49030715931421287,2.1362830044410597,0.0020696061107830133,
        0.49030715931421287,2.261946710584651,0.002069606110783009,
        0.49030715931421287,2.3876104167282426,0.0020696061107830024,
        0.49030715931421287,2.5132741228718345,0.002069606110783005,
        0.49030715931421287,2.638937829015426,0.0020696061107830124,
        0.49030715931421287,2.764601535159018,0.002069606110783012,
        0.49030715931421287,2.8902652413026098,0.0020696061107830068,
        0.49030715931421287,3.015928947446201,0.002069606110783004,
        0.49030715931421287,3.141592653589793,0.0020696061107830107,
        0.49030715931421287,3.267256359733385,0.0020696061107830133,
        0.49030715931421287,3.392920065876977,0.002069606110783011,
        0.49030715931421287,3.518583772020569,0.002069606110783006,
        0.49030715931421287,3.64424747816416,0.0020696061107830024,
        0.49030715931421287,3.7699111843077517,0.0020696061107830033,
        0.49030715931421287,3.8955748904513436,0.00206960611078301,
        0.49030715931421287,4.0212385965949355,0.002069606110783014,
        0.49030715931421287,4.1469023027385274,0.0020696061107830124,
        0.49030715931421287,4.272566008882119,0.0020696061107830055,
        0.49030715931421287,4.39822971502571,0.0020696061107830024,
        0.49030715931421287,4.523893421169302,0.002069606110783006,
        0.49030715931421287,4.649557127312894,0.002069606110783007,
        0.49030715931421287,4.775220833456485,0.0020696061107830076,
        0.49030715931421287,4.900884539600077,0.002069606110783004,
        0.49030715931421287,5.026548245743669,0.0020696061107830033,
        0.49030715931421287,5.15221195188726,0.002069606110783006,
        0.49030715931421287,5.277875658030852,0.00206960611078301,
        0.49030715931421287,5.403539364174444,0.0020696061107830137,
        0.49030715931421287,5.529203070318036,0.0020696061107830146,
        0.49030715931421287,5.654866776461628,0.00206960611078301,
        0.49030715931421287,5.7805304826052195,0.002069606110783005,
        0.49030715931421287,5.9061941887488105,0.0020696061107830055,
        0.49030715931421287,6.031857894892402,0.0020696061107830115,
        0.49030715931421287,6.157521601035994,0.002069606110783017,
        0.5919453942068854,0.,0.00230888863214336,0.5919453942068854,
        0.12566370614359174,0.00230888863214335,0.5919453942068854,
        0.25132741228718347,0.0023088886321433505,0.5919453942068854,
        0.37699111843077515,0.002308888632143355,0.5919453942068854,
        0.5026548245743669,0.002308888632143355,0.5919453942068854,
        0.6283185307179586,0.0023088886321433527,0.5919453942068854,
        0.7539822368615503,0.0023088886321433553,0.5919453942068854,
        0.8796459430051422,0.0023088886321433588,0.5919453942068854,
        1.0053096491487339,0.0023088886321433588,0.5919453942068854,
        1.1309733552923256,0.0023088886321433535,0.5919453942068854,
        1.2566370614359172,0.002308888632143348,0.5919453942068854,
        1.382300767579509,0.0023088886321433505,0.5919453942068854,
        1.5079644737231006,0.0023088886321433605,0.5919453942068854,
        1.6336281798666925,0.0023088886321433622,0.5919453942068854,
        1.7592918860102844,0.0023088886321433514,0.5919453942068854,
        1.8849555921538759,0.002308888632143347,0.5919453942068854,
        2.0106192982974678,0.0023088886321433588,0.5919453942068854,
        2.1362830044410597,0.0023088886321433596,0.5919453942068854,
        2.261946710584651,0.0023088886321433496,0.5919453942068854,
        2.3876104167282426,0.0023088886321433427,0.5919453942068854,
        2.5132741228718345,0.002308888632143347,0.5919453942068854,
        2.638937829015426,0.0023088886321433566,0.5919453942068854,
        2.764601535159018,0.0023088886321433557,0.5919453942068854,
        2.8902652413026098,0.002308888632143347,0.5919453942068854,
        3.015928947446201,0.0023088886321433496,0.5919453942068854,
        3.141592653589793,0.002308888632143358,0.5919453942068854,3.267256359733385,
        0.0023088886321433566,0.5919453942068854,3.392920065876977,
        0.002308888632143353,0.5919453942068854,3.518583772020569,
        0.0023088886321433496,0.5919453942068854,3.64424747816416,
        0.0023088886321433483,0.5919453942068854,3.7699111843077517,
        0.0023088886321433475,0.5919453942068854,3.8955748904513436,
        0.0023088886321433514,0.5919453942068854,4.0212385965949355,
        0.00230888863214336,0.5919453942068854,4.1469023027385274,
        0.002308888632143359,0.5919453942068854,4.272566008882119,
        0.0023088886321433488,0.5919453942068854,4.39822971502571,
        0.002308888632143348,0.5919453942068854,4.523893421169302,
        0.002308888632143355,0.5919453942068854,4.649557127312894,
        0.0023088886321433522,0.5919453942068854,4.775220833456485,
        0.002308888632143351,0.5919453942068854,4.900884539600077,
        0.0023088886321433514,0.5919453942068854,5.026548245743669,
        0.0023088886321433483,0.5919453942068854,5.15221195188726,
        0.0023088886321433514,0.5919453942068854,5.277875658030852,
        0.00230888863214336,0.5919453942068854,5.403539364174444,
        0.0023088886321433575,0.5919453942068854,5.529203070318036,
        0.002308888632143354,0.5919453942068854,5.654866776461628,
        0.002308888632143356,0.5919453942068854,5.7805304826052195,
        0.0023088886321433514,0.5919453942068854,5.9061941887488105,
        0.0023088886321433453,0.5919453942068854,6.031857894892402,
        0.0023088886321433544,0.5919453942068854,6.157521601035994,
        0.0023088886321433635,0.6848716308091483,0.,0.0024139834202227873,
        0.6848716308091483,0.12566370614359174,0.0024139834202227804,
        0.6848716308091483,0.25132741228718347,0.002413983420222779,
        0.6848716308091483,0.37699111843077515,0.0024139834202227834,
        0.6848716308091483,0.5026548245743669,0.002413983420222782,
        0.6848716308091483,0.6283185307179586,0.0024139834202227817,
        0.6848716308091483,0.7539822368615503,0.0024139834202227847,
        0.6848716308091483,0.8796459430051422,0.002413983420222786,
        0.6848716308091483,1.0053096491487339,0.002413983420222781,
        0.6848716308091483,1.1309733552923256,0.0024139834202227765,
        0.6848716308091483,1.2566370614359172,0.002413983420222779,
        0.6848716308091483,1.382300767579509,0.002413983420222776,
        0.6848716308091483,1.5079644737231006,0.0024139834202227804,
        0.6848716308091483,1.6336281798666925,0.0024139834202227895,
        0.6848716308091483,1.7592918860102844,0.0024139834202227747,
        0.6848716308091483,1.8849555921538759,0.002413983420222771,
        0.6848716308091483,2.0106192982974678,0.002413983420222788,
        0.6848716308091483,2.1362830044410597,0.0024139834202227834,
        0.6848716308091483,2.261946710584651,0.002413983420222773,
        0.6848716308091483,2.3876104167282426,0.002413983420222775,
        0.6848716308091483,2.5132741228718345,0.002413983420222773,
        0.6848716308091483,2.638937829015426,0.0024139834202227812,
        0.6848716308091483,2.764601535159018,0.0024139834202227864,
        0.6848716308091483,2.8902652413026098,0.0024139834202227717,
        0.6848716308091483,3.015928947446201,0.002413983420222776,
        0.6848716308091483,3.141592653589793,0.0024139834202227856,
        0.6848716308091483,3.267256359733385,0.00241398342022278,0.6848716308091483,
        3.392920065876977,0.0024139834202227804,0.6848716308091483,
        3.518583772020569,0.0024139834202227778,0.6848716308091483,3.64424747816416,
        0.002413983420222772,0.6848716308091483,3.7699111843077517,
        0.0024139834202227747,0.6848716308091483,3.8955748904513436,
        0.0024139834202227778,0.6848716308091483,4.0212385965949355,
        0.0024139834202227856,0.6848716308091483,4.1469023027385274,
        0.00241398342022279,0.6848716308091483,4.272566008882119,
        0.002413983420222772,0.6848716308091483,4.39822971502571,
        0.002413983420222771,0.6848716308091483,4.523893421169302,
        0.002413983420222785,0.6848716308091483,4.649557127312894,
        0.0024139834202227743,0.6848716308091483,4.775220833456485,
        0.0024139834202227743,0.6848716308091483,4.900884539600077,
        0.002413983420222786,0.6848716308091483,5.026548245743669,
        0.0024139834202227713,0.6848716308091483,5.15221195188726,
        0.0024139834202227713,0.6848716308091483,5.277875658030852,
        0.0024139834202227942,0.6848716308091483,5.403539364174444,
        0.0024139834202227843,0.6848716308091483,5.529203070318036,
        0.0024139834202227778,0.6848716308091483,5.654866776461628,
        0.00241398342022279,0.6848716308091483,5.7805304826052195,
        0.0024139834202227786,0.6848716308091483,5.9061941887488105,
        0.00241398342022277,0.6848716308091483,6.031857894892402,
        0.0024139834202227856,0.6848716308091483,6.157521601035994,
        0.002413983420222792,0.7677596751578858,0.,0.002378785478597558,
        0.7677596751578858,0.12566370614359174,0.00237878547859755,
        0.7677596751578858,0.25132741228718347,0.0023787854785975483,
        0.7677596751578858,0.37699111843077515,0.0023787854785975522,
        0.7677596751578858,0.5026548245743669,0.002378785478597551,
        0.7677596751578858,0.6283185307179586,0.002378785478597552,
        0.7677596751578858,0.7539822368615503,0.002378785478597553,
        0.7677596751578858,0.8796459430051422,0.002378785478597556,
        0.7677596751578858,1.0053096491487339,0.002378785478597557,
        0.7677596751578858,1.1309733552923256,0.002378785478597545,
        0.7677596751578858,1.2566370614359172,0.002378785478597549,
        0.7677596751578858,1.382300767579509,0.0023787854785975514,
        0.7677596751578858,1.5079644737231006,0.0023787854785975488,
        0.7677596751578858,1.6336281798666925,0.002378785478597564,
        0.7677596751578858,1.7592918860102844,0.0023787854785975483,
        0.7677596751578858,1.8849555921538759,0.0023787854785975366,
        0.7677596751578858,2.0106192982974678,0.0023787854785975657,
        0.7677596751578858,2.1362830044410597,0.002378785478597554,
        0.7677596751578858,2.261946710584651,0.0023787854785975405,
        0.7677596751578858,2.3876104167282426,0.002378785478597551,
        0.7677596751578858,2.5132741228718345,0.0023787854785975384,
        0.7677596751578858,2.638937829015426,0.0023787854785975514,
        0.7677596751578858,2.764601535159018,0.0023787854785975605,
        0.7677596751578858,2.8902652413026098,0.0023787854785975384,
        0.7677596751578858,3.015928947446201,0.002378785478597549,
        0.7677596751578858,3.141592653589793,0.0023787854785975574,
        0.7677596751578858,3.267256359733385,0.0023787854785975483,
        0.7677596751578858,3.392920065876977,0.002378785478597555,
        0.7677596751578858,3.518583772020569,0.0023787854785975505,
        0.7677596751578858,3.64424747816416,0.002378785478597539,0.7677596751578858,
        3.7699111843077517,0.0023787854785975488,0.7677596751578858,
        3.8955748904513436,0.00237878547859755,0.7677596751578858,
        4.0212385965949355,0.0023787854785975514,0.7677596751578858,
        4.1469023027385274,0.0023787854785975635,0.7677596751578858,
        4.272566008882119,0.0023787854785975466,0.7677596751578858,4.39822971502571,
        0.0023787854785975375,0.7677596751578858,4.523893421169302,
        0.002378785478597562,0.7677596751578858,4.649557127312894,
        0.0023787854785975444,0.7677596751578858,4.775220833456485,
        0.0023787854785975392,0.7677596751578858,4.900884539600077,
        0.002378785478597562,0.7677596751578858,5.026548245743669,
        0.0023787854785975405,0.7677596751578858,5.15221195188726,
        0.00237878547859754,0.7677596751578858,5.277875658030852,
        0.00237878547859757,0.7677596751578858,5.403539364174444,
        0.002378785478597551,0.7677596751578858,5.529203070318036,
        0.0023787854785975457,0.7677596751578858,5.654866776461628,
        0.002378785478597567,0.7677596751578858,5.7805304826052195,
        0.0023787854785975453,0.7677596751578858,5.9061941887488105,
        0.0023787854785975414,0.7677596751578858,6.031857894892402,
        0.0023787854785975596,0.7677596751578858,6.157521601035994,
        0.0023787854785975587,0.839415937266752,0.,0.002205342291534775,
        0.839415937266752,0.12566370614359174,0.0022053422915347563,
        0.839415937266752,0.25132741228718347,0.0022053422915347567,
        0.839415937266752,0.37699111843077515,0.002205342291534766,
        0.839415937266752,0.5026548245743669,0.002205342291534758,0.839415937266752,
        0.6283185307179586,0.0022053422915347624,0.839415937266752,
        0.7539822368615503,0.0022053422915347632,0.839415937266752,
        0.8796459430051422,0.0022053422915347598,0.839415937266752,
        1.0053096491487339,0.0022053422915347663,0.839415937266752,
        1.1309733552923256,0.0022053422915347537,0.839415937266752,
        1.2566370614359172,0.0022053422915347502,0.839415937266752,
        1.382300767579509,0.0022053422915347637,0.839415937266752,
        1.5079644737231006,0.0022053422915347524,0.839415937266752,
        1.6336281798666925,0.0022053422915347667,0.839415937266752,
        1.7592918860102844,0.002205342291534762,0.839415937266752,
        1.8849555921538759,0.0022053422915347403,0.839415937266752,
        2.0106192982974678,0.0022053422915347736,0.839415937266752,
        2.1362830044410597,0.002205342291534764,0.839415937266752,2.261946710584651,
        0.002205342291534746,0.839415937266752,2.3876104167282426,
        0.0022053422915347645,0.839415937266752,2.5132741228718345,
        0.002205342291534746,0.839415937266752,2.638937829015426,
        0.002205342291534761,0.839415937266752,2.764601535159018,
        0.002205342291534771,0.839415937266752,2.8902652413026098,
        0.0022053422915347433,0.839415937266752,3.015928947446201,
        0.0022053422915347624,0.839415937266752,3.141592653589793,
        0.002205342291534766,0.839415937266752,3.267256359733385,
        0.0022053422915347554,0.839415937266752,3.392920065876977,
        0.0022053422915347637,0.839415937266752,3.518583772020569,
        0.002205342291534757,0.839415937266752,3.64424747816416,
        0.002205342291534751,0.839415937266752,3.7699111843077517,
        0.002205342291534755,0.839415937266752,3.8955748904513436,
        0.00220534229153476,0.839415937266752,4.0212385965949355,
        0.0022053422915347585,0.839415937266752,4.1469023027385274,
        0.0022053422915347706,0.839415937266752,4.272566008882119,
        0.0022053422915347554,0.839415937266752,4.39822971502571,
        0.002205342291534742,0.839415937266752,4.523893421169302,
        0.0022053422915347693,0.839415937266752,4.649557127312894,
        0.002205342291534755,0.839415937266752,4.775220833456485,
        0.0022053422915347494,0.839415937266752,4.900884539600077,
        0.0022053422915347697,0.839415937266752,5.026548245743669,
        0.002205342291534748,0.839415937266752,5.15221195188726,
        0.0022053422915347507,0.839415937266752,5.277875658030852,
        0.0022053422915347754,0.839415937266752,5.403539364174444,
        0.0022053422915347576,0.839415937266752,5.529203070318036,
        0.002205342291534757,0.839415937266752,5.654866776461628,
        0.0022053422915347745,0.839415937266752,5.7805304826052195,
        0.0022053422915347502,0.839415937266752,5.9061941887488105,
        0.002205342291534756,0.839415937266752,6.031857894892402,
        0.0022053422915347676,0.839415937266752,6.157521601035994,
        0.002205342291534763,0.8988041752629691,0.,0.0019037371563964012,
        0.8988041752629691,0.12566370614359174,0.0019037371563963793,
        0.8988041752629691,0.25132741228718347,0.0019037371563963921,
        0.8988041752629691,0.37699111843077515,0.0019037371563963897,
        0.8988041752629691,0.5026548245743669,0.0019037371563963889,
        0.8988041752629691,0.6283185307179586,0.0019037371563963878,
        0.8988041752629691,0.7539822368615503,0.001903737156396392,
        0.8988041752629691,0.8796459430051422,0.0019037371563963917,
        0.8988041752629691,1.0053096491487339,0.0019037371563963904,
        0.8988041752629691,1.1309733552923256,0.001903737156396391,
        0.8988041752629691,1.2566370614359172,0.0019037371563963815,
        0.8988041752629691,1.382300767579509,0.0019037371563963923,
        0.8988041752629691,1.5079644737231006,0.0019037371563963878,
        0.8988041752629691,1.6336281798666925,0.0019037371563963964,
        0.8988041752629691,1.7592918860102844,0.0019037371563963917,
        0.8988041752629691,1.8849555921538759,0.0019037371563963737,
        0.8988041752629691,2.0106192982974678,0.0019037371563963995,
        0.8988041752629691,2.1362830044410597,0.0019037371563963936,
        0.8988041752629691,2.261946710584651,0.0019037371563963765,
        0.8988041752629691,2.3876104167282426,0.001903737156396393,
        0.8988041752629691,2.5132741228718345,0.0019037371563963767,
        0.8988041752629691,2.638937829015426,0.0019037371563963904,
        0.8988041752629691,2.764601535159018,0.001903737156396397,
        0.8988041752629691,2.8902652413026098,0.001903737156396377,
        0.8988041752629691,3.015928947446201,0.0019037371563963902,
        0.8988041752629691,3.141592653589793,0.0019037371563963912,
        0.8988041752629691,3.267256359733385,0.0019037371563963895,
        0.8988041752629691,3.392920065876977,0.0019037371563963917,
        0.8988041752629691,3.518583772020569,0.0019037371563963852,
        0.8988041752629691,3.64424747816416,0.0019037371563963837,
        0.8988041752629691,3.7699111843077517,0.0019037371563963828,
        0.8988041752629691,3.8955748904513436,0.0019037371563963904,
        0.8988041752629691,4.0212385965949355,0.0019037371563963928,
        0.8988041752629691,4.1469023027385274,0.0019037371563963945,
        0.8988041752629691,4.272566008882119,0.001903737156396389,
        0.8988041752629691,4.39822971502571,0.001903737156396376,0.8988041752629691,
        4.523893421169302,0.001903737156396402,0.8988041752629691,4.649557127312894,
        0.0019037371563963817,0.8988041752629691,4.775220833456485,
        0.0019037371563963843,0.8988041752629691,4.900884539600077,
        0.0019037371563963995,0.8988041752629691,5.026548245743669,
        0.0019037371563963776,0.8988041752629691,5.15221195188726,
        0.001903737156396387,0.8988041752629691,5.277875658030852,
        0.0019037371563964004,0.8988041752629691,5.403539364174444,
        0.0019037371563963945,0.8988041752629691,5.529203070318036,
        0.0019037371563963847,0.8988041752629691,5.654866776461628,
        0.001903737156396401,0.8988041752629691,5.7805304826052195,
        0.0019037371563963813,0.8988041752629691,5.9061941887488105,
        0.001903737156396385,0.8988041752629691,6.031857894892402,
        0.0019037371563963943,0.8988041752629691,6.157521601035994,
        0.0019037371563963932,0.9450637592863899,0.,0.001491509500505126,
        0.9450637592863899,0.12566370614359174,0.0014915095005051124,
        0.9450637592863899,0.25132741228718347,0.0014915095005051202,
        0.9450637592863899,0.37699111843077515,0.001491509500505111,
        0.9450637592863899,0.5026548245743669,0.0014915095005051237,
        0.9450637592863899,0.6283185307179586,0.0014915095005051135,
        0.9450637592863899,0.7539822368615503,0.0014915095005051168,
        0.9450637592863899,0.8796459430051422,0.0014915095005051215,
        0.9450637592863899,1.0053096491487339,0.0014915095005051163,
        0.9450637592863899,1.1309733552923256,0.0014915095005051159,
        0.9450637592863899,1.2566370614359172,0.00149150950050511,
        0.9450637592863899,1.382300767579509,0.0014915095005051172,
        0.9450637592863899,1.5079644737231006,0.0014915095005051118,
        0.9450637592863899,1.6336281798666925,0.0014915095005051237,
        0.9450637592863899,1.7592918860102844,0.0014915095005051148,
        0.9450637592863899,1.8849555921538759,0.0014915095005051055,
        0.9450637592863899,2.0106192982974678,0.0014915095005051243,
        0.9450637592863899,2.1362830044410597,0.0014915095005051176,
        0.9450637592863899,2.261946710584651,0.0014915095005051098,
        0.9450637592863899,2.3876104167282426,0.001491509500505116,
        0.9450637592863899,2.5132741228718345,0.0014915095005051083,
        0.9450637592863899,2.638937829015426,0.0014915095005051168,
        0.9450637592863899,2.764601535159018,0.0014915095005051209,
        0.9450637592863899,2.8902652413026098,0.0014915095005051085,
        0.9450637592863899,3.015928947446201,0.0014915095005051159,
        0.9450637592863899,3.141592653589793,0.001491509500505121,
        0.9450637592863899,3.267256359733385,0.0014915095005051137,
        0.9450637592863899,3.392920065876977,0.00149150950050512,0.9450637592863899,
        3.518583772020569,0.0014915095005051135,0.9450637592863899,3.64424747816416,
        0.0014915095005051107,0.9450637592863899,3.7699111843077517,
        0.001491509500505113,0.9450637592863899,3.8955748904513436,
        0.001491509500505115,0.9450637592863899,4.0212385965949355,
        0.0014915095005051165,0.9450637592863899,4.1469023027385274,
        0.0014915095005051209,0.9450637592863899,4.272566008882119,
        0.0014915095005051163,0.9450637592863899,4.39822971502571,
        0.0014915095005050994,0.9450637592863899,4.523893421169302,
        0.0014915095005051248,0.9450637592863899,4.649557127312894,
        0.0014915095005051111,0.9450637592863899,4.775220833456485,
        0.001491509500505108,0.9450637592863899,4.900884539600077,
        0.0014915095005051228,0.9450637592863899,5.026548245743669,
        0.0014915095005051061,0.9450637592863899,5.15221195188726,
        0.0014915095005051129,0.9450637592863899,5.277875658030852,
        0.0014915095005051215,0.9450637592863899,5.403539364174444,
        0.0014915095005051213,0.9450637592863899,5.529203070318036,
        0.0014915095005051083,0.9450637592863899,5.654866776461628,
        0.0014915095005051291,0.9450637592863899,5.7805304826052195,
        0.0014915095005051107,0.9450637592863899,5.9061941887488105,
        0.0014915095005051094,0.9450637592863899,6.031857894892402,
        0.0014915095005051252,0.9450637592863899,6.157521601035994,
        0.0014915095005051168,0.9775241873450459,0.,0.0009926780689681848,
        0.9775241873450459,0.12566370614359174,0.0009926780689681657,
        0.9775241873450459,0.25132741228718347,0.0009926780689681785,
        0.9775241873450459,0.37699111843077515,0.000992678068968174,
        0.9775241873450459,0.5026548245743669,0.000992678068968175,
        0.9775241873450459,0.6283185307179586,0.0009926780689681728,
        0.9775241873450459,0.7539822368615503,0.000992678068968178,
        0.9775241873450459,0.8796459430051422,0.0009926780689681726,
        0.9775241873450459,1.0053096491487339,0.0009926780689681759,
        0.9775241873450459,1.1309733552923256,0.0009926780689681737,
        0.9775241873450459,1.2566370614359172,0.000992678068968167,
        0.9775241873450459,1.382300767579509,0.0009926780689681787,
        0.9775241873450459,1.5079644737231006,0.0009926780689681687,
        0.9775241873450459,1.6336281798666925,0.0009926780689681794,
        0.9775241873450459,1.7592918860102844,0.0009926780689681728,
        0.9775241873450459,1.8849555921538759,0.0009926780689681666,
        0.9775241873450459,2.0106192982974678,0.0009926780689681783,
        0.9775241873450459,2.1362830044410597,0.0009926780689681752,
        0.9775241873450459,2.261946710584651,0.0009926780689681666,
        0.9775241873450459,2.3876104167282426,0.0009926780689681744,
        0.9775241873450459,2.5132741228718345,0.0009926780689681668,
        0.9775241873450459,2.638937829015426,0.0009926780689681733,
        0.9775241873450459,2.764601535159018,0.0009926780689681794,
        0.9775241873450459,2.8902652413026098,0.0009926780689681674,
        0.9775241873450459,3.015928947446201,0.0009926780689681728,
        0.9775241873450459,3.141592653589793,0.0009926780689681783,
        0.9775241873450459,3.267256359733385,0.0009926780689681702,
        0.9775241873450459,3.392920065876977,0.0009926780689681763,
        0.9775241873450459,3.518583772020569,0.000992678068968171,
        0.9775241873450459,3.64424747816416,0.0009926780689681694,
        0.9775241873450459,3.7699111843077517,0.0009926780689681715,
        0.9775241873450459,3.8955748904513436,0.0009926780689681726,
        0.9775241873450459,4.0212385965949355,0.0009926780689681763,
        0.9775241873450459,4.1469023027385274,0.0009926780689681754,
        0.9775241873450459,4.272566008882119,0.0009926780689681733,
        0.9775241873450459,4.39822971502571,0.0009926780689681642,
        0.9775241873450459,4.523893421169302,0.0009926780689681785,
        0.9775241873450459,4.649557127312894,0.0009926780689681687,
        0.9775241873450459,4.775220833456485,0.000992678068968169,
        0.9775241873450459,4.900884539600077,0.0009926780689681787,
        0.9775241873450459,5.026548245743669,0.0009926780689681657,
        0.9775241873450459,5.15221195188726,0.0009926780689681726,
        0.9775241873450459,5.277875658030852,0.0009926780689681772,
        0.9775241873450459,5.403539364174444,0.0009926780689681772,
        0.9775241873450459,5.529203070318036,0.00099267806896817,0.9775241873450459,
        5.654866776461628,0.0009926780689681815,0.9775241873450459,
        5.7805304826052195,0.0009926780689681687,0.9775241873450459,
        5.9061941887488105,0.0009926780689681728,0.9775241873450459,
        6.031857894892402,0.0009926780689681765,0.9775241873450459,
        6.157521601035994,0.0009926780689681726,0.9957213189500226,0.,
        0.00043702903264614324,0.9957213189500226,0.12566370614359174,
        0.0004370290326461388,0.9957213189500226,0.25132741228718347,
        0.0004370290326461416,0.9957213189500226,0.37699111843077515,
        0.0004370290326461383,0.9957213189500226,0.5026548245743669,
        0.00043702903264614183,0.9957213189500226,0.6283185307179586,
        0.00043702903264613777,0.9957213189500226,0.7539822368615503,
        0.00043702903264613956,0.9957213189500226,0.8796459430051422,
        0.00043702903264613993,0.9957213189500226,1.0053096491487339,
        0.00043702903264613945,0.9957213189500226,1.1309733552923256,
        0.0004370290326461383,0.9957213189500226,1.2566370614359172,
        0.0004370290326461404,0.9957213189500226,1.382300767579509,
        0.0004370290326461384,0.9957213189500226,1.5079644737231006,
        0.00043702903264613874,0.9957213189500226,1.6336281798666925,
        0.00043702903264614075,0.9957213189500226,1.7592918860102844,
        0.0004370290326461387,0.9957213189500226,1.8849555921538759,
        0.0004370290326461362,0.9957213189500226,2.0106192982974678,
        0.00043702903264614134,0.9957213189500226,2.1362830044410597,
        0.0004370290326461413,0.9957213189500226,2.261946710584651,
        0.00043702903264613495,0.9957213189500226,2.3876104167282426,
        0.0004370290326461417,0.9957213189500226,2.5132741228718345,
        0.0004370290326461354,0.9957213189500226,2.638937829015426,
        0.00043702903264614134,0.9957213189500226,2.764601535159018,
        0.0004370290326461395,0.9957213189500226,2.8902652413026098,
        0.0004370290326461364,0.9957213189500226,3.015928947446201,
        0.00043702903264613934,0.9957213189500226,3.141592653589793,
        0.00043702903264614167,0.9957213189500226,3.267256359733385,
        0.0004370290326461379,0.9957213189500226,3.392920065876977,
        0.0004370290326461428,0.9957213189500226,3.518583772020569,
        0.00043702903264613755,0.9957213189500226,3.64424747816416,
        0.0004370290326461397,0.9957213189500226,3.7699111843077517,
        0.00043702903264613663,0.9957213189500226,3.8955748904513436,
        0.0004370290326461407,0.9957213189500226,4.0212385965949355,
        0.0004370290326461387,0.9957213189500226,4.1469023027385274,
        0.00043702903264614346,0.9957213189500226,4.272566008882119,
        0.00043702903264613836,0.9957213189500226,4.39822971502571,
        0.00043702903264613766,0.9957213189500226,4.523893421169302,
        0.00043702903264614216,0.9957213189500226,4.649557127312894,
        0.0004370290326461383,0.9957213189500226,4.775220833456485,
        0.000437029032646138,0.9957213189500226,4.900884539600077,
        0.0004370290326461402,0.9957213189500226,5.026548245743669,
        0.0004370290326461384,0.9957213189500226,5.15221195188726,
        0.00043702903264613684,0.9957213189500226,5.277875658030852,
        0.00043702903264614254,0.9957213189500226,5.403539364174444,
        0.0004370290326461395,0.9957213189500226,5.529203070318036,
        0.00043702903264614004,0.9957213189500226,5.654866776461628,
        0.00043702903264614075,0.9957213189500226,5.7805304826052195,
        0.0004370290326461409,0.9957213189500226,5.9061941887488105,
        0.0004370290326461373,0.9957213189500226,6.031857894892402,
        0.00043702903264614124,0.9957213189500226,6.157521601035994,
        0.0004370290326461402
    };
}

